<?php

namespace App\Exceptions;

use App\Jobs\ErrorLogJob;
use App\Models\ErrorLog;
use App\RabbitMQService;
use Throwable;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Request;
use Illuminate\Foundation\Exceptions\Handler as ExceptionHandler;
use Sentry\State\HubInterface;

class Handler extends ExceptionHandler
{
    /**
     * The list of the inputs that are never flashed to the session on validation exceptions.
     *
     * @var array<int, string>
     */
    protected $dontFlash = [
        'current_password',
        'password',
        'password_confirmation',
    ];

    /**
     * Register the exception handling callbacks for the application.
     */
    public function register(): void
    {
        $this->reportable(function (Throwable $e) {
            //
        });
    }
    public function report(Throwable $exception)
    {
        try {
            if ($this->shouldReport($exception)) {
                $user = Auth::user();
                $data = [
                    'user_id' => $user ? $user->username : null,
                    'profile_id' => $user ? $user->role->user_profile_id : null,
                    'user_agent' => Request::userAgent(),
                    'time' => now()->toDateTimeString(),
                    'error_message' => $exception->getMessage(),
                    'exception' => $exception->getTraceAsString(),
                ];
                $rabbit_request_param = ['data' => json_encode($data), 'url' => RABBIT_MQ_ERROR_LOG_URL, 'name' => 'error_log'];
                $rabbitMQService = new RabbitMQService('error_exchange', 'error_log', 'error_routing_key');
                $rabbitMQService->publish(json_encode($rabbit_request_param));
            }
        } catch (\Exception $exception) {
            Log::error($exception->getMessage());
        }
        parent::report($exception);
    }
}
