<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Exception;

class AuthController extends Controller
{
    public function login(Request $request)
    {
        $credentials = $request->only('username', 'password');
        try {
            $token = Auth::guard('api')->attempt($credentials);
            if (!$token) {
                return $this->respondUnauthorized(__('Unauthorized'));
            }
        } catch (Exception $e) {
            return $this->responseInternalError($e->getMessage(), []);
        }
        return $this->responseWithData(['token' => $token, 'type' => API_TOKEN_TYPE], __('Access Token'));
    }

    public function logout()
    {
        try {
            Auth::guard('api')->logout();
            return $this->responseSuccess(__('Successfully logged out'));
        } catch (Exception $e) {
            return $this->responseInternalError($e->getMessage(), []);
        }
    }

    public function refresh()
    {
        try {
            $refresh_token = Auth::guard('api')->refresh();
        } catch (Exception $e) {
            return $this->responseInternalError($e->getMessage(), []);
        }
        return $this->responseWithData(['token' => $refresh_token, 'type' => API_TOKEN_TYPE], __('Refresh Access Token'));
    }

    public function me()
    {
        try {
            $token_validation = $this->tokenValidation();
            if ($token_validation->original['status'] == RESPONSE_STATUS_ERROR) {
                return $token_validation;
            }
            $user = $token_validation->original['data'];
            $user->load('profile');
            $user->makeHidden(['password']);
        } catch (Exception $e) {
            return $this->responseInternalError($e->getMessage(), []);
        }
        return $this->responseWithData($user, __('Authorized user'));
    }
}
