<?php

namespace App\Http\Controllers;

use App\Models\ErrorLog;
use App\Models\LoginLog;
use App\Models\EntityType;
use App\Models\ActivityLog;
use Illuminate\Http\Request;
use App\Models\EntityTypeRole;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;

class ApplicationConfigurationController extends Controller
{
    /** User Role */
    public function viewUserRoles(Request $request)
    {
        $page_title = __("User Role List");
        $is_filter_enabled = true;
        $is_action_enabled = true;
        $is_submit_enabled = false;
        return view('ApplicationConfiguration.userRoles.index', compact('page_title', 'is_filter_enabled', 'is_action_enabled', 'is_submit_enabled'));
    }
    public function apiUserRoleList(Request $request)
    {
        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 10;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $m_entityTypeRole = new EntityTypeRole();
        return response()->json($m_entityTypeRole->getEntityTypeRoleList($page, $limit, $start, $search));
    }
    public function setupUserRole(Request $request)
    {
        $_id = $request->get('type');
        if ($request->isMethod('post')) {
            //save data
            $response = ['status' => 'error', 'code' => 500, 'message' => "Invalid request"];
            $data = $request->all();
            if (empty($data)) {
                return response()->json($response, $response['code'], []);
            }
            $response = new EntityTypeRole();
            $response = $response->saveOrUpdate(setAuthInfoToData($data, Auth::user()));
            return response()->json($response, $response['code'], []);
        } else {
            //add/edit view
            $entity_type_role = [];
            if (intval($_id) == 0) {
                $page_title = __("Add User Role");
            } else {
                $entity_type_role = EntityTypeRole::findOrFail($_id);
                $page_title = __("Edit User Role: :name", ['name' => $entity_type_role->role_name]);
            }
            $is_submit_enabled = true;
            return view('ApplicationConfiguration.userRoles.setup', compact('entity_type_role', 'page_title', 'is_submit_enabled'));
        }
    }
    public function deleteUserRole($id)
    {
        try {
            $entity_type_role = new EntityTypeRole();
            return response()->json($entity_type_role->deleteEntityTypeRole($id), 200);
        } catch (\Exception $e) {
            return response()->json(['error' => 'An error occurred while deleting the role'], 500);
        }
    }
    /** Business Type */
    public function viewBusinessTypes(Request $request)
    {
        $page_title = __("Business Type List");
        $is_filter_enabled = true;
        $is_action_enabled = false;
        $is_submit_enabled = false;
        return view('ApplicationConfiguration.businessTypes.index', compact('page_title', 'is_filter_enabled', 'is_action_enabled', 'is_submit_enabled'));
    }
    public function apiBusinessTypeList(Request $request)
    {
        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 10;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $m_entityType = new EntityType();
        return response()->json($m_entityType->getEntityTypeList($page, $limit, $start, $search));
    }
    public function setupBusinessType(Request $request)
    {
        $_id = $request->get('type');
        if ($request->isMethod('post')) {
            //save data
            $response = ['status' => 'error', 'code' => 500, 'message' => "Invalid request"];
            $data = $request->all();
            if (empty($data)) {
                return response()->json($response, $response['code'], []);
            }
            $response = new EntityType();
            $response = $response->saveOrUpdate(setAuthInfoToData($data, Auth::user()));
            return response()->json($response, $response['code'], []);
        } else {
            //add/edit view
            $entity_type = [];
            if (intval($_id) == 0) {
                $page_title = __("Add Business Type");
            } else {
                $entity_type = EntityType::findOrFail($_id);
                $page_title = __("Edit Business Type: :name", ['name' => $entity_type->name]);
            }
            $is_submit_enabled = true;
            return view('ApplicationConfiguration.businessTypes.setup', compact('entity_type', 'page_title', 'is_submit_enabled'));
        }
    }
    public function deleteBusinessType($id)
    {
        try {
            $entity_type = new EntityType();
            return response()->json($entity_type->deleteEntityType($id), 200);
        } catch (\Exception $e) {
            return response()->json(['error' => 'An error occurred while deleting the type'], 500);
        }
    }

    /** Application Log */
    public function applicationLog()
    {
        $page_title = __("Application Logs");
        return view('ApplicationConfiguration.logs.application_logs', compact('page_title'));
    }

    public function viewLogs(Request $request)
    {
        $data = $request->all();
        if ($data['action'] == 'login') {
            return view('element.application_configuration.logs._login_log');
        }
        if ($data['action'] == 'error') {
            return view('element.application_configuration.logs._error_log');
        }
        if ($data['action'] == 'activity') {
            return view('element.application_configuration.logs._recent_activity_log');
        }
    }

    public function getLoginLog(Request $request)
    {
        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 5;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $filter_options = $request->has('filter_options') ? $request->get('filter_options') : [];
        $profile_id = isset($filter_options['profile_id']) ? $filter_options['profile_id'] : 0;
        $login_log = new LoginLog();
        return response()->json($login_log->getLoginLog($page, $limit, $start, $search, $profile_id));
    }

    public function getRecentActivity(Request $request)
    {
        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 5;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $filter_options = $request->has('filter_options') ? $request->get('filter_options') : [];
        $profile_id = isset($filter_options['profile_id']) ? $filter_options['profile_id'] : 0;
        $log = new ActivityLog();
        return response()->json($log->getActivityLog($page, $limit, $start, $search, $profile_id));
    }

    public function getErrorLog(Request $request)
    {
        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 5;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $error_log = new ErrorLog();
        return response()->json($error_log->getErrorLog($page, $limit, $start, $search));
    }

    public function voiceCommand()
    {
        $page_title = __('Voice Command Configuration List');
        return view('ApplicationConfiguration.command.voice', compact('page_title'));
    }
}
