<?php

namespace App\Http\Controllers;

use App\Traits\RequestResponse;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Config;
use Illuminate\Routing\Controller as BaseController;
use Illuminate\Foundation\Validation\ValidatesRequests;
use Illuminate\Foundation\Auth\Access\AuthorizesRequests;

class Controller extends BaseController
{
    use AuthorizesRequests, ValidatesRequests, RequestResponse;

    public $auth_user;
    public $role_display_name;

    public function __construct()
    {
        $auth_user = [];
        if (Auth::check() || Auth::guard("api")->check()) {

            if (Auth::guard('api')->check()) {
                $auth_user = Auth::guard("api")->user()->load(['role', 'role.entity_type']);
            } else {
                $auth_user = Auth::user();
            }
            $user_role = strtolower($auth_user->role->entity_type->role_name);
            $role_display_title = $auth_user->role->entity_type->role_title;
            if ($user_role == strtolower(CLIENT_ROLE_NAME_ADMIN) && $auth_user->role->entity_type_id != SYSTEM_ENTITY_TYPE_ID) {
                $auth_user['current_role'] = ROLE_CLIENT;
            } else if ($user_role == ROLE_MANAGER && $auth_user->role->is_admin == 1) {
                $auth_user['current_role'] = ROLE_ADMIN;
            } else {
                $auth_user['current_role'] = $user_role;
            }
            $role_display_name = $auth_user['current_role'] ? ucfirst($auth_user['current_role']) : "";
            $is_search_enabled = $is_submit_enabled = $is_back_enabled = $is_action_enabled = $is_filter_enabled  = $is_export_enabled = false;
            $is_div_enabled = [];
            $this->auth_user = $auth_user;
            view()->share('auth_user', $auth_user);
            view()->share('role_display_name', $role_display_name);
            view()->share('role_display_title', $role_display_title);
            view()->share('is_filter_enabled', $is_filter_enabled);
            view()->share('is_action_enabled', $is_action_enabled);
            view()->share('is_back_enabled', $is_back_enabled);
            view()->share('is_submit_enabled', $is_submit_enabled);
            view()->share('is_search_enabled', $is_search_enabled);
            view()->share('is_export_enabled', $is_export_enabled);
            view()->share('is_div_enabled', $is_div_enabled);
        }
    }
    public function switchDatabase($connection_name, $database, $username, $password, $host = '127.0.0.1', $port = '3306')
    {
        Config::set('database.default', $connection_name);
        Config::set("database.connections.{$connection_name}.database", $database);
        Config::set("database.connections.{$connection_name}.username", $username);
        Config::set("database.connections.{$connection_name}.password", $password);
        Config::set("database.connections.{$connection_name}.host", $host);
        Config::set("database.connections.{$connection_name}.port", $port);

        DB::purge($connection_name);
        DB::reconnect($connection_name);
    }

    public function tokenValidation()
    {
        $user = Auth::guard('api')->user();
        if (!$user) {
            return $this->respondUnauthorized(__('Unauthorized or invalid token'));
        }
        return $this->responseWithData($user, __('Authorized'));
    }
}
