<?php

namespace App\Http\Controllers;

use App\Models\Customer;
use Illuminate\Http\Request;

class CustomerController extends Controller
{

    public function index()
    {
        $page_title = __("Customer List");
        $is_action_enabled = false;
        $is_back_enabled = true;

        return view('customers.index',compact('page_title','is_action_enabled','is_back_enabled'));
    }

    public function data(Request $request)
    {

        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 10;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $customerModel = new Customer();
        return response()->json($customerModel->getList($page, $limit, $start, $search));
    }

    public function store(Request $request)
    {
        $request->validate([
            'customer_name' => 'required|string',
            'ac_number' => 'required|string|unique:customers',
            'branch_name' => 'required|string',
            'acc_status' => 'required|in:active,dormant,closed',
            'nid' => 'required|string|unique:customers',
        ]);

        Customer::create($request->all());

        return response()->json(['success' => 'Customer added successfully.']);
    }

    public function edit($id)
    {
        $customer = Customer::findOrFail($id);
        return response()->json($customer);
    }

    public function update(Request $request, $id)
    {
        $customer = Customer::findOrFail($id);

        $request->validate([
            'customer_name' => 'required|string',
            'ac_number' => "required|string|unique:customers,ac_number,{$id}",
            'branch_name' => 'required|string',
            'acc_status' => 'required|in:active,dormant,closed',
            'nid' => "required|string|unique:customers,nid,{$id}",
        ]);

        $customer->update($request->all());

        return response()->json(['success' => 'Customer updated successfully.']);
    }

    public function show(Request $request)
    {
        $data = $request->all();
        $model_customer = new Customer();
        $response_customer = $model_customer->getShowCustomer(setAuthInfoToData($data, $this->auth_user));
        if ($response_customer['status'] == RESPONSE_STATUS_ERROR) {
            return $response_customer;
        }
        $customer = $response_customer['data'];
        $is_back_enabled = true;
        return view('customers.show', compact('customer','is_back_enabled'));
    }

    public function seachCustomer(){
        $page_title = __("Customer Seaching");

        return view('search.search_customer',compact('page_title'));
    }


    public function customerStaticView($id){
        $page_title = __("Customer Profile");
        $customer =   Customer::find($id);
        $is_back_enabled = true;
        return view('customers.customer_static_view',compact('page_title','customer','is_back_enabled'));

      }
}
