<?php

namespace App\Http\Controllers;

use App\Models\EmailService;
use App\Models\EmailTemplate;
use App\Models\FileAttachment;
use Illuminate\Http\Request;
use Symfony\Component\HttpKernel\Exception\MethodNotAllowedHttpException;

class EmailsController extends Controller
{
    public function index(Request $request)
    {
        $page_title = __("All Email Templates");
        $is_filter_enabled = false;
        $is_action_enabled = true;
        $is_submit_enabled = false;
        return view('emails.index', compact(['page_title', 'is_filter_enabled', 'is_action_enabled', 'is_submit_enabled']));
    }
    public function dashboard()
    {
        $page_title = 'Email Dashboard';
        return view('emails.dashboard', compact('page_title'));
    }
    public function reSend($id, Request $request)
    {
        if (!$request->isMethod('post')) {
            throw new MethodNotAllowedHttpException(['post'], 'Method Not Allowed');
        }
        try {
            $response = [
                'status' => 'error',
                'message' => "Invalid request",
            ];
            if (!empty($id)) {
                $email = new EmailService();
                $response = $email->prepareSendEmailData([], $id);
                if ($response['status'] == 'success') {
                    return $this->responseSuccess('Email successfully send.');
                }
            }
            return $this->responseWithError($response['message']);
        } catch (\Exception $e) {
            return $this->responseWithError($e->getMessage());
        }
    }
    public function viewTemplate(Request $request)
    {
        $m_et = new EmailTemplate();
        $template = $m_et->getTemplate($request->email_template_id ?? 0);
        return view('emails.view_email_template', compact('template'));
    }
    public function prepareTemplateData(Request $request)
    {
        $data = $request->all();
        $m_email_template = new EmailTemplate();
        return $m_email_template->prepareTemplateData(setAuthInfoToData($data, $this->auth_user));
    }
    public function viewMailBoxes(Request $request)
    {
        $email['type'] = $request->type;
        $page_title = $email['type'] == 'inbox' ? __("Email Inbox") : __("Email Outbox");
        $is_filter_enabled = false;
        $is_action_enabled = false;
        $is_submit_enabled = false;
        $email['profile_id'] = $this->auth_user->profile->id ?? 0;
        $email['client_profile_id'] = $request->client_profile_id ?? 0;
        if ($email['client_profile_id'] > 0) {
            return view('emails.partials.mail', compact(['page_title', 'email']));
        } else {
            return view('emails.email', compact(['page_title', 'email', 'is_filter_enabled', 'is_action_enabled', 'is_submit_enabled']));
        }
    }
    public function apiMailBoxList(Request $request)
    {
        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 10;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $m_emailService = new EmailService();
        return response()->json($m_emailService->getList($page, $limit, $start, $search));
    }
    public function viewMailBox(Request $request)
    {
        $email = new EmailService();
        $email = $email->getEmailService($request->id)->toArray();
        $attachments = new FileAttachment();
        $type = $request->type;
        $conditions = [
            ['table_name', '=', EMAIL_SERVICE_TABLE_NAME],
            ['table_row_id', '=', $request->id],
        ];
        $attachments = $attachments->getConditionWiseAttachments($conditions)->toArray();
        return view('emails.view', compact('email', 'attachments', 'type'));
    }
    public function emailServiceResponse(Request $request)
    {
        $data = $request->all();
        $m_email_service = new EmailService();
        $response = $m_email_service->emailServiceResponseUpdate($data);
        return $response;
    }
}
