<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\News;
use App\Helpers\JaroWinkler;
use App\Models\Customer;
use App\Models\NewsData;

class MatchController extends Controller
{
    public function match(Request $request)
    {
        $page_title = __('Adverse Media Search Result');

        $validated = $request->validate([
            'customer_name' => 'required|string',
            'matching_degree_customer' => 'required|numeric|min:0|max:100',
            'father_name' => 'nullable|string',
            'matching_degree_father' => 'nullable|numeric|min:0|max:100',
            'mother_name' => 'nullable|string',
            'matching_degree_mother' => 'nullable|numeric|min:0|max:100',
            'spouse_name' => 'nullable|string',
            'matching_degree_spouse' => 'nullable|numeric|min:0|max:100',
            'nid' => 'nullable|string',
            'matching_degree_nid' => 'nullable|numeric|min:0|max:100',

        ]);

        $results = [];
        $newsList = NewsData::all();
        $jarwikler = new JaroWinkler();

        foreach ($newsList as $news) {
            $totalMatch = 0;
            $fieldsMatched = 0;
            $nameMatch = 0;
            $matchKeyworkWithPercentage = '';

            if (!empty($validated['customer_name'])) {
                $score = $jarwikler->getSimilarity($validated['customer_name'], $news->Nameofperson_English) * 100;
                $nameMatch = $score;
                if ($score >= $validated['matching_degree_customer']) {
                    $totalMatch += $score;
                    $fieldsMatched++;
                    $matchKeyworkWithPercentage = " Person/Entity Name: $score% <br>";

                }else{
                    continue;
                }
            }else{
                continue;
            }


            if (!empty($validated['father_name'])) {
                $score = $jarwikler->getSimilarity($validated['father_name'], $news->FatherName) * 100;
                if ($score >= $validated['matching_degree_father']) {
                    $totalMatch += $score;
                    $fieldsMatched++;
                    $matchKeyworkWithPercentage =  $matchKeyworkWithPercentage .  " Father Name: $score% <br>";
                }
            }

            if (!empty($validated['mother_name'])) {
                $score = $jarwikler->getSimilarity($validated['mother_name'], $news->MotherName) * 100;
                if ($score >= $validated['matching_degree_mother']) {
                    $totalMatch += $score;
                    $fieldsMatched++;
                    $matchKeyworkWithPercentage =  $matchKeyworkWithPercentage .  " Mother Name: $score% <br>";
                }
            }

            if (!empty($validated['nid'])) {
                $score = $jarwikler->getSimilarity(bnToEn($validated['nid']), $news->NID) * 100;
                if ($score >= $validated['matching_degree_nid']) {
                    $totalMatch += $score;
                    $fieldsMatched++;
                    $matchKeyworkWithPercentage =  $matchKeyworkWithPercentage .  " NID: $score% <br>";
                    $dynamicColumns['NID'] = $news->nid;

                }
            }

            if (!empty($validated['spouse_name'])) {
                $score = $jarwikler->getSimilarity($validated['spouse_name'], $news->SpouceName) * 100;
                if ($score >= $validated['matching_degree_spouse']) {
                    $totalMatch += $score;
                    $fieldsMatched++;
                    $matchKeyworkWithPercentage =  $matchKeyworkWithPercentage .  " Spouse: $score% <br>";

                }
            }

            if ($fieldsMatched > 0) {
                $averageMatch = $totalMatch / $fieldsMatched;
                $results[] = [
                    'customer_name' => $news->Nameofperson_English ,
                    'match_percentage' => round($averageMatch, 2),
                    'summery_percentage' => $matchKeyworkWithPercentage,
                    'name_match' => round($nameMatch, 2),
                    'news_title' => $news->News_Title_English,
                    'news_link' => $news->NewsLink,
                    'id' => $news->id,
                    'published_date' => $news->PublishDate,
                    'news_source' => $news->News_Source_English,
                    'profile_link' => route('customer.profile', ['id' => $news->id]),
                ];
            }
        }

        usort($results, function ($a, $b) {
            return $b['name_match'] <=> $a['name_match'];
        });
        $results = array_slice($results, 0, 20);
        return view('search.results', compact('results','page_title'));
    }


    public function customerSearchMatch(Request $request)
    {
        $page_title = __('Customer Search Result');

        $validated = $request->validate([
            'customer_name' => 'required|string',
            'matching_degree_customer' => 'required|numeric|min:0|max:100',
            'father_name' => 'nullable|string',
            'matching_degree_father' => 'nullable|numeric|min:0|max:100',
            'mother_name' => 'nullable|string',
            'matching_degree_mother' => 'nullable|numeric|min:0|max:100',
            'spouse_name' => 'nullable|string',
            'matching_degree_spouse' => 'nullable|numeric|min:0|max:100',

            'nid' => 'nullable|string',
            'matching_degree_nid' => 'nullable|numeric|min:0|max:100',


        ]);

        $results = [];
        $customerList = Customer::all();
        $jarwikler = new JaroWinkler();


        foreach ($customerList as $item) {
            $totalMatch = 0;
            $fieldsMatched = 0;
            $matchKeyworkWithPercentage = '';
            $dynamicColumns = [];
            $nameMatch = 0;

            if (!empty($validated['customer_name'])) {
                $score = $jarwikler->getSimilarity(bnToEn($validated['customer_name']), $item->ac_name) * 100;
                // $score = $jarwikler->getSimilarity($validated['customer_name'], $news->news_title) * 100;
                $nameMatch = $score;
                if ($score >= $validated['matching_degree_customer']) {
                    $totalMatch += $score;
                    $fieldsMatched++;
                    $matchKeyworkWithPercentage = " Person/Entity Name: $score% <br>";
                }else{
                    continue;
                }
            }else{
                continue;
            }


            if (!empty($validated['father_name'])) {
                $score = $jarwikler->getSimilarity(bnToEn($validated['father_name']), $item->father_name) * 100;
                if ($score >= $validated['matching_degree_father']) {
                    $totalMatch += $score;
                    $fieldsMatched++;
                    $matchKeyworkWithPercentage =  $matchKeyworkWithPercentage .  " Father Name: $score% <br>";
                    $dynamicColumns['Father Name'] = $item->father_name;

                }
            }

            if (!empty($validated['mother_name'])) {
                $score = $jarwikler->getSimilarity(bnToEn($validated['mother_name']), $item->mother_name) * 100;
                if ($score >= $validated['matching_degree_mother']) {
                    $totalMatch += $score;
                    $fieldsMatched++;
                    $matchKeyworkWithPercentage =  $matchKeyworkWithPercentage .  " Mother Name: $score% <br>";
                    $dynamicColumns['Mother Name'] = $item->mother_name;

                }
            }

            if (!empty($validated['nid'])) {
                $score = $jarwikler->getSimilarity(bnToEn($validated['nid']), $item->nid) * 100;
                if ($score >= $validated['matching_degree_nid']) {
                    $totalMatch += $score;
                    $fieldsMatched++;
                    $matchKeyworkWithPercentage =  $matchKeyworkWithPercentage .  " NID: $score% <br>";
                    $dynamicColumns['NID'] = $item->nid;

                }
            }

            if ($fieldsMatched > 0) {
                $averageMatch = $totalMatch / $fieldsMatched;
                $results[] = [
                    'customer_name' => $item->ac_name,
                    'father_name' => $item->father_name,
                    'match_percentage' => round($averageMatch, 2),
                    'name_match' => round($nameMatch , 2),
                    'summery_percentage' => $matchKeyworkWithPercentage,
                    'dynamicColumns' => $dynamicColumns,
                    'profile_link' => route('customer.profile', ['id' => $item->id]),
                ];
            }
        }

        usort($results, function ($a, $b) {
            return $b['name_match'] <=> $a['name_match'];
        });
        $results = array_slice($results, 0, 20);

        $is_back_enabled = true;
        return view('search.customer-results', compact('results','page_title','is_back_enabled'));
    }


    public function customerSearch(){
        $page_title = __('Customer Search');

        return view('search.customer-search',compact('page_title'));
    }


    public function customerSearchFromNews(){
        $page_title = __('Customer Search From Adverse News');

        return view('search.customer-search-from-news',compact('page_title'));
    }
}



