<?php

namespace App\Http\Controllers;

use App\Models\News;
use App\Models\NewsData;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use Symfony\Component\DomCrawler\Crawler;
use Barryvdh\DomPDF\Facade\Pdf;
use Mpdf\Mpdf;
use Dompdf\Dompdf;
use Dompdf\Options;


class NewsController extends Controller
{

    public function index()
    {
        $page_title = __("News List");
        $is_action_enabled = false;
        $is_back_enabled = true;

        return view('news.index',compact('page_title','is_action_enabled','is_back_enabled'));
    }



    public function data(Request $request)
    {

        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 10;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $customerModel = new NewsData();
        return response()->json($customerModel->getList($page, $limit, $start, $search));
    }

    public function newsBn()
    {
        $page_title = __("সংবাদ তালিকা");
        $is_action_enabled = false;
        $is_back_enabled = true;

        return view('news.index-bn',compact('page_title','is_action_enabled','is_back_enabled'));
    }

    public function dataBn(Request $request)
    {

        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 10;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $customerModel = new NewsData();
        return response()->json($customerModel->getListBn($page, $limit, $start, $search));
    }


    public function downloadNewsAsPdf($id)
    {
        $news = NewsData::find($id);
        $url = $news->NewsLink;
        $identifyClass = "";

        if (strtolower($news->News_Source_English) == 'prothom alo') {
            $identifyClass = ".story-content";
        }

        // Validate the URL
        if (!filter_var($url, FILTER_VALIDATE_URL)) {
            return response()->json(['error' => 'Invalid URL'], 400);
        }

        // Fetch the webpage content
        try {
            $response = Http::get($url);

            if ($response->failed()) {
                return response()->json(['error' => 'Unable to fetch the webpage content'], 400);
            }

            $htmlContent = $response->body();
        } catch (\Exception $e) {
            return response()->json(['error' => 'Failed to retrieve webpage content'], 500);
        }

        // Parse the HTML content
        try {
            $crawler = new Crawler($htmlContent);

            // Adjust these selectors based on the news source
            $title = $crawler->filter('h1')->text(); // Example: Title selector
            $body = $crawler->filter($identifyClass)->html(); // Example: Article body selector
            $data = [
                'title' => $title,
                'body' => $body,
            ];
        } catch (\Exception $e) {
            return response()->json(['error' => 'Error parsing webpage content'], 500);
        }

        // Generate PDF using mPDF
        try {

            $defaultConfig = (new \Mpdf\Config\ConfigVariables())->getDefaults();
            $fontDirs = $defaultConfig['fontDir'];

            $defaultFontConfig = (new \Mpdf\Config\FontVariables())->getDefaults();
            $fontData = $defaultFontConfig['fontdata'];

            $path = public_path() . "/fonts";

            $mpdf = new \Mpdf\Mpdf([
                'format' => 'A4',
                'orientation' => 'P',
                'fontDir' => array_merge($fontDirs, [$path]),
                'fontdata' => $fontData + [
                    'solaimanlipi' => [
                        'R' => 'SolaimanLipi.ttf',
                        'useOTL' => 0xFF,
                    ]
                ],
                'default_font' => 'solaimanlipi',
            ]);

            $mpdf->WriteHTML(view('pdf/newspdf',compact('data')));
            $mpdf->Output('news.pdf', 'D');

        } catch (\Exception $e) {
            return response()->json(['error' => 'Error generating PDF'], 500);
        }
    }

}
