<?php

namespace App\Http\Controllers;

use App\Models\EmailTemplate;
use App\Models\NotificationEvent;
use App\Models\NotificationMessage;
use App\Models\PushNotification;
use App\Models\UserProfile;
use Illuminate\Http\Request;
use App\Models\UserNotificationConfiguration;
use App\Models\UserRegisteredDevice;
use Illuminate\Support\Facades\Auth;

class NotificationController extends Controller
{
    public function index()
    {
        $page_title = __("Notification List");
        $is_filter_enabled = true;
        $is_action_enabled = true;
        $is_submit_enabled = false;
        $profile_id = \request()->profile_id;
        $client_id = \request()->client_id;
        $action = 'global_list';
        return view('notification.index', compact('page_title', 'client_id', 'profile_id', 'is_filter_enabled', 'is_action_enabled', 'is_submit_enabled', 'action'));
    }
    public function apiNotificationList(Request $request)
    {
        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 10;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $m_notification_message = new NotificationMessage();
        return response()->json($m_notification_message->getList($page, $limit, $start, $search, $this->auth_user));
    }
    public function typeNotification()
    {
        $profile_id = \request()->profile_id ?? 0;
        $client_profile_id = \request()->client_profile_id ?? 0;
        return view('notification.type', compact('profile_id', 'client_profile_id'));
    }
    public function sendNotification(Request $request)
    {
        $data = $request->all();
        $notify_type = $data['notify_type'];
        if ($request->isMethod('post')) {
            try {
                $data = $request->all();
                $m_push_notification = new PushNotification();
                if ($notify_type == NOTIFICATION_TYPE_SMS) {
                    return $m_push_notification->sendSms($data);
                } elseif ($notify_type == NOTIFICATION_TYPE_EMAIL || $notify_type == NOTIFICATION_TYPE_COURTESY) {
                    return $m_push_notification->sendEmail(setAuthInfoToData($data, $this->auth_user));
                } else {
                    return $m_push_notification->sendPushNotification(setAuthInfoToData($data, $this->auth_user));
                }
            } catch (\Exception $e) {
                return $this->responseWithError($e->getMessage());
            }
        }
        $notify['profile_id'] = $data['profile_id'] ?? 0;
        $notify['client_profile_id'] = $data['client_profile_id'] ?? 0;
        $emailTemplates = [];
        if ($notify_type == NOTIFICATION_TYPE_EMAIL) {
            $m_email_template = new EmailTemplate();
            $emailTemplates = $m_email_template->getOptions();
            if ($notify['profile_id'] > 0) {
                $m_user_profile = new UserProfile();
                $userProfile = $m_user_profile->getProfile($notify['profile_id']);
                $notify['email'] = $userProfile['email'] ?? '';
                $notify['phone'] = $userProfile['mobile'] ?? '';
            }
        }
        return view('element.notification.' . $notify_type ?? NOTIFICATION_TYPE_PUSH, compact('notify_type', 'notify', 'emailTemplates'));
    }
    public function viewNotification()
    {
        $page_title = __("My Profile");
        $is_filter_enabled = true;
        $is_action_enabled = true;
        $is_submit_enabled = false;
        $profile_id = \request()->profile_id;
        $client_id = \request()->client_id;
        $action = 'profile_profile';
        return view('notification.index', compact('page_title', 'client_id', 'profile_id', 'is_filter_enabled', 'is_action_enabled', 'is_submit_enabled', 'action'));
    }
    public function apiNotificationNotifier(Request $request)
    {
        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 20;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $m_notification_message = new NotificationMessage();
        if (NOTIFY_ENABLE) {
            $notifications = $m_notification_message->getPushNotificationList($page, $limit, $start, $search);
            if ($request->ajax() && $request->wantsJson()) {
                return response()->json($notifications);
            }
            return view('notification.notifier', compact('notifications'));
        } elseif (FIREBASE_NOTIFICATION_ENABLE) {
            $notifications = $m_notification_message->getNotificationMessage($page, $limit, $start, $search);
            return view('notification.notification_list', compact('notifications'));
        }
    }
    public function configurationNotification(Request $request)
    {
        $profile_id = $request->profile_id ?? 0;
        $user_id = 0;
        if ($profile_id > 0) {
            $m_up = new UserProfile();
            $profile = $m_up->getProfile($profile_id);
            $user_id = $profile['user_id'] ?? 0;
        }
        $m_user_notification_configuration = new UserNotificationConfiguration();
        if ($request->isMethod('post')) {
            if (!isset($request->notification_ids)) {
                return $this->responseWithError("Please checked an item.");
            }
            $data['id'] = $request->id ?? 0;
            $data['user_id'] = $user_id;
            $data['notification_events'] = json_encode($request->notification_ids);
            $response = $m_user_notification_configuration->saveOrUpdate(setAuthInfoToData($data, Auth::user()));
            return response()->json($response, $response['code'], []);
        } else {
            $configuration = $m_user_notification_configuration->getConfiguration($user_id);
            $m_notification_event = new NotificationEvent();
            $notificationEvents = $m_notification_event->getEvents($user_id);
            return view('notification.configuration', compact('configuration', 'notificationEvents', 'profile_id'));
        }
    }
    public function seenNotification(Request $request)
    {
        $data = $request->all();
        $m_notification_message = new NotificationMessage();
        $response = $m_notification_message->seenNotification($data);
        return $response;
    }
    // Firebase Web Token
    public function storeToken(Request $request)
    {
        $data = $request->all();
        $data['device'] = getBrowser($request->header('User-Agent'));
        $m_user_registered_device = new UserRegisteredDevice();
        $response = $m_user_registered_device->storeWebToken(setAuthInfoToData($data, $this->auth_user));
        return $response;
    }

    public function checkDeviceToken(Request $request)
    {
        $data['device'] = getBrowser($request->header('User-Agent'));
        $m_user_registered_device = new UserRegisteredDevice();
        $response = $m_user_registered_device->checkDeviceToken(setAuthInfoToData($data, $this->auth_user));
        return $response;
    }
}
