<?php

namespace App\Http\Controllers;

use App\Models\NotificationEvent;
use App\Models\NotificationType;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class NotificationEventController extends Controller
{
    public function viewNotificationEvent(Request $request)
    {
        $page_title = __("Notification Event List");
        $is_filter_enabled = false;
        $is_action_enabled = true;
        $is_submit_enabled = false;
        return view('notificationEvent.index', compact('page_title', 'is_filter_enabled', 'is_action_enabled', 'is_submit_enabled'));
    }
    public function apiNotificationEventList(Request $request)
    {
        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 10;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $m_notification_event = new NotificationEvent();
        return response()->json($m_notification_event->getList($page, $limit, $start, $search));
    }

    public function setupNotificationEvent(Request $request)
    {
        $_id = $request->get('type');
        $m_notification_type = new NotificationType();
        $notificationTypeOptions = $m_notification_type->getOptions()->toArray();
        if ($request->isMethod('post')) {
            //save data
            $response = ['status' => 'error', 'code' => 500, 'message' => "Invalid request"];
            $data = $request->all();
            if (empty($data)) {
                return response()->json($response, $response['code'], []);
            }
            $response = new NotificationEvent();
            $response = $response->saveOrUpdate(setAuthInfoToData($data, Auth::user()));
            return response()->json($response, $response['code'], []);
        } else {
            //add/edit view
            $notificationEvent = [];
            $messages = [];
            if (intval($_id) == 0) {
                $page_title = __("Add Notification Event");
            } else {
                $notificationEvent = NotificationEvent::findOrFail($_id);
                $messages = $notificationEvent->entity_type_role_ids;
                $page_title = __("Edit Notification Event: :name", ['name' => $notificationEvent->name]);
            }
            $is_submit_enabled = true;
            return view('notificationEvent.setup', compact('notificationEvent', 'messages','notificationTypeOptions', 'page_title', 'is_submit_enabled'));
        }
    }
    public function deleteNotificationEvent($id)
    {
        try {
            $notificationEvent = new NotificationEvent();
            return response()->json($notificationEvent->deleteNotificationEvent($id), 200);
        } catch (\Exception $e) {
            return response()->json(['error' => 'An error occurred while updating the event of notification'], 500);
        }
    }
}
