<?php

// app/Http/Controllers/PdfController.php
namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Smalot\PdfParser\Parser;
use Illuminate\Support\Facades\Validator;

class PdfController extends Controller
{
    // Show upload form
    public function showUploadForm()
    {
        $page_title = __("PDF Searching");
        return view('pdf.upload_pdf',compact('page_title'));
    }

    // Handle PDF upload and extraction
    public function uploadPdf(Request $request)
    {
        // Validate the file upload
        $validator = Validator::make($request->all(), [
            'pdf_file' => 'required|mimes:pdf|max:10240', // Max file size 10MB
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        // Get the uploaded file
        $file = $request->file('pdf_file');

        // Use pdfparser to extract text
        $parser = new Parser();
        $pdf = $parser->parseFile($file->getRealPath());
        $text = $pdf->getText();

        // Extract data from the text (name, father's name, mother's name, company name)
        $data = $this->extractData($text);
        $request->merge([
            'customer_name' => $data['name'],
            'matching_degree_customer' => 80,
            'mother_name' => $data['mother_name'],
            'matching_degree_mother' => 80,
            'father_name' => $data['father_name'],
            'matching_degree_father' => 80,
            'company_name' => $data['company_name'],
        ]);
        // return redirect()->route('customersearch.submit')->withInput($request->all());
        $matchController = new MatchController();
        return $matchController->customerSearchMatch($request);
    }

    // Function to extract name, father's name, mother's name, company name
    public function extractData($text)
    {
        $data = [];

        // Define patterns for name extraction (supporting both English and Bangla)
        $namePattern = '/(?:Name(?: \(Individual\/Entity\))?:|নাম(?: \(ব্যক্তি\/প্রতিষ্ঠান\))?:)[\s]*([a-zA-Z.\s]+|[^\x00-\x7F]+)/i'; // Matches Bangladeshi names
        $fatherNamePattern = '/(?:Father’s Name:|পিতার নাম:)[\s]*([a-zA-Z.\s]+|[^\x00-\x7F]+)/i'; // Matches father's name
        $motherNamePattern = '/(?:Mother’s Name:|মায়ের নাম:)[\s]*([a-zA-Z.\s]+|[^\x00-\x7F]+)/i'; // Matches mother's name
        $companyNamePattern = '/(?:Organization Name \(if applicable\):|প্রতিষ্ঠানের নাম \(যদি প্রযোজ্য হয়\):)[\s]*([a-zA-Z.\s]+|[^\x00-\x7F]+)/i'; // Matches company name

        // Extract data using regex
        preg_match($namePattern, $text, $nameMatches);
        preg_match($fatherNamePattern, $text, $fatherNameMatches);
        preg_match($motherNamePattern, $text, $motherNameMatches);
        preg_match($companyNamePattern, $text, $companyNameMatches);

        // Store the extracted values
        $data['name'] = isset($nameMatches[1]) ? $nameMatches[1] : null;
        $data['father_name'] = isset($fatherNameMatches[1]) ? $fatherNameMatches[1] : null;
        $data['mother_name'] = isset($motherNameMatches[1]) ? $motherNameMatches[1] : null;
        $data['company_name'] = isset($companyNameMatches[1]) ? $companyNameMatches[1] : null;

        return $data;
    }
}
