<?php

namespace App\Http\Controllers;

use App\Models\XService;
use Illuminate\Http\Request;
use App\Models\EntityTypeRole;
use App\Models\XDocument;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;

class ServiceConfigurationController extends Controller
{
    public function viewDocuments()
    {
        $page_title = "Document List";
        $is_filter_enabled = true;
        $is_action_enabled = true;
        $is_submit_enabled = false;
        return view('xServiceDocuments.index', compact('page_title', 'is_filter_enabled', 'is_action_enabled', 'is_submit_enabled'));
    }
    public function apiDocumentList(Request $request)
    {
        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 10;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $m_serviceDocument = new XDocument();
        return response()->json($m_serviceDocument->getList($page, $limit, $start, $search));
    }
    public function setupDocument(Request $request)
    {
        $_id = $request->get('type');
        if ($request->isMethod('post')) {
            //save data
            $response = ['status' => 'error', 'code' => 500, 'message' => "Invalid request"];
            $data = $request->all();
            $data['verify_role_ids'] = !empty($data['verify_role_ids']) ? $data['verify_role_ids'] : null;
            if (empty($data)) {
                return response()->json($response, $response['code'], []);
            }
            $m_x_document = new XDocument();
            $response = $m_x_document->saveOrUpdate(setAuthInfoToData($data, Auth::user()));
            return response()->json($response, $response['code'], []);
        } else {
            //add/edit view
            $m_x_document = [];
            $oldVerifyRoleIds = [];
            if (intval($_id) == 0) {
                $page_title = __("Add Document");
            } else {
                $m_x_document = XDocument::findOrFail($_id);
                $oldVerifyRoleIds = $m_x_document->verify_role_ids;
                $page_title = __("Edit Document: :name", ['name' => $m_x_document->document_title]);
            }
            $entity_type_roles = new EntityTypeRole();
            $x_services = new XService();
            $x_services = $x_services->getOptions();
            $entity_type_roles = $entity_type_roles->getEntityByRoleAndAdmin(SYSTEM_ENTITY_TYPE_ID);
            $is_submit_enabled = true;
            return view('xServiceDocuments.setup', compact('m_x_document', 'x_services', 'oldVerifyRoleIds', 'entity_type_roles', 'page_title', 'is_submit_enabled'));
        }
    }
    public function deleteDocument($id)
    {
        try {
            $xDocument = new XDocument();
            return response()->json($xDocument->deleteDocument($id), 200);
        } catch (\Exception $e) {
            return response()->json(['error' => 'An error occurred while deleting the Service'], 500);
        }
    }
}
