<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;
use PragmaRX\Google2FAQRCode\Google2FA;

class TwoFactorController extends Controller
{
    public function show2faForm()
    {
        $user = auth()->user();
        $google2fa_secret = $user->google2fa_secret;
        $google2fa = new Google2FA();
        $secret = $google2fa->generateSecretKey();

        $QR_Image = $google2fa->getQRCodeInline(
            config('app.name'),
            $user->username,
            $secret
        );
        $page_title = __('Two-factor Authentication');
        return view('2fa.setup', compact('google2fa_secret', 'secret', 'QR_Image', 'page_title'));
    }

    public function enable2fa(Request $request)
    {
        try {
            $data = $request->all();
            $secret = $data['secret'];
            $one_time_password = $data['one_time_password'];

            $auth_user = $this->auth_user;
            $google2fa = new Google2FA();
            $m_user = new User();
            if (empty($secret)) {
                $auth_google2fa_secret = $auth_user['google2fa_secret'];
                $valid = $google2fa->verifyKey($auth_google2fa_secret, $one_time_password);
                if ($valid) {
                    $user_data['id'] = $auth_user['id'];
                    $user_data['google2fa_secret'] = null;
                    $m_user->modifiedSave($user_data, []);
                    return redirect()->route('setup2fa')->withErrors(['status' => RESPONSE_STATUS_SUCCESS, 'message' => __("Two-factor authentication disabled successfully.")]);
                } else {
                    return redirect()->route('setup2fa')->withErrors(['status' => RESPONSE_STATUS_ERROR, 'message' => __("Two-factor authentication disabled failed.")]);
                }
            } else {
                $valid = $google2fa->verifyKey($secret, $one_time_password);
                if ($valid) {
                    $user_data['id'] = $auth_user['id'];
                    $user_data['google2fa_secret'] = $secret;
                    $m_user->modifiedSave($user_data, []);
                    return redirect()->route('setup2fa')->withErrors(['status' => RESPONSE_STATUS_SUCCESS, 'message' => __("Two-factor authentication enabled successfully.")]);
                } else {
                    return redirect()->route('setup2fa')->withErrors(['status' => RESPONSE_STATUS_ERROR, 'message' => __("Two-factor authentication enabled failed.")]);
                }
            }
        } catch (\Exception $e) {
            return redirect()->route('setup2fa')->withErrors(['status' => RESPONSE_STATUS_ERROR, 'message' => __("An error occurred. Please try again.")]);
        }
    }

    public function showVerify2faForm()
    {
        return view('2fa.verify');
    }

    public function verify2fa(Request $request)
    {
        try {
            $user = auth()->user();
            $google2fa = new Google2FA();
            $valid = $google2fa->verifyKey($user->google2fa_secret, $request->input('one_time_password'));
            if ($valid) {
                $request->session()->put('2fa_verified', true);
                return redirect()->route('home');
            }
            return redirect()->route('verify2fa')->withErrors(['status' => RESPONSE_STATUS_ERROR, 'message' => __("Invalid 2fa code. Please try again.")]);
        } catch (\Exception $th) {
            return redirect()->route('verify2fa')->withErrors(['status' => RESPONSE_STATUS_ERROR, 'message' => __("An error occurred. Please try again.")]);
        }
    }
}
