<?php

namespace App\Http\Controllers;

use App\Models\BankBranch;
use Carbon\Carbon;
use App\Models\User;
use App\Models\UserProfile;
use Illuminate\Http\Request;
use App\Models\FileAttachment;
use App\Models\UserEntityRole;
use Illuminate\Support\Facades\Auth;
use Symfony\Component\HttpKernel\Exception\MethodNotAllowedHttpException;

class UsersController extends Controller
{
    public function profile(Request $request, $id = null)
    {
        $m_userProfile = new UserProfile();
        if ($id == null) {
            $user_profile = Auth::user()->profile;
        } else {
            $user_profile = $m_userProfile->getProfile($id);
            $page_title = __($user_profile->full_name ? $user_profile->full_name : '' . ' Profile');
        }
        $profile = $m_userProfile->getTeamProfile($this->auth_user->profile_info->id);
        $type = '';
        $folders = [];
        $entityEmployeeProfile = [];
        $page_title = __('My Profile');
        return view('users.profile', compact('entityEmployeeProfile', 'page_title', 'user_profile', 'folders', 'type', 'profile'));
    }
    public function changePassword(Request $request)
    {
        $page_title = 'Password Change';
        if ($request->isMethod('post')) {
            $response = [
                'status' => 'error',
                'message' => "Invalid request"
            ];
            $data = $request->all();
            if (!empty($data)) {
                if (!isset($data['user_id'])) {
                    $data['user_id'] = Auth::user()->id;
                }
                $response = new User();
                $response = $response->changePassword($data);
                if ($response['status'] == 'success') {
                    return $this->responseSuccess('Password changed successfully.');
                }
            }
            return $this->responseWithError($response['message']);
        }
        $is_filter_enabled = false;
        $is_action_enabled = false;
        $is_submit_enabled = true;
        return view('users.change_password', compact(['page_title', 'is_submit_enabled']));
    }
    public function changePasswordAdmin()
    {
        $user = new User();
        $users = $user->getUserByCreator(Auth::user()->id);
        $page_title = 'Password Change';
        $is_filter_enabled = false;
        $is_action_enabled = false;
        $is_submit_enabled = true;
        return view('users.change_password_admin', compact('page_title', 'is_filter_enabled', 'is_action_enabled', 'is_submit_enabled', 'users'));
    }
    public function changeUsername(Request $request)
    {
        if ($request->isMethod('post')) {
            try {
                $response = [
                    'status' => 'error',
                    'message' => "Invalid request"
                ];
                $data = $request->all();
                if (!isset($data['user_id'])) {
                    $data['user_id'] = Auth::user()->id;
                }
                $data['is_admin'] =  $data['user_id'] == Auth::user()->id ? false : true;
                if ($data['is_admin'] == true) {
                    $request->validate([
                        'username' => "required|string|max:120|unique:users,username,{{$data['user_id']}},id,deleted_at,NULL",
                    ]);
                } else {
                    $request->validate([
                        'username' => "required|string|max:120|unique:users,username,{{$data['user_id']}},id,deleted_at,NULL",
                        'password' => 'required',
                    ]);
                }

                if (!empty($data)) {
                    $response = new User();
                    $response = $response->changeUsername($data);
                    if ($response['status'] == 'success') {
                        return $this->responseSuccess('Login ID changed successfully.');
                    }
                }
                return $this->responseWithError($response['message']);
            } catch (\Exception $ex) {
                return [
                    'status' => 'error',
                    'message' => $ex->getMessage()
                ];
            }
        }
    }
    public function forgetPassword(Request $request)
    {
        if ($request->isMethod('post')) {
            try {
                $rd = $request->all();
                $users = new User();
                $response = $users->checkAndSendEmail($rd);
                if ($response['status'] == 'success') {
                    return $this->responseWithData($response['expiry'], 'Password is sent to your email.');
                }
                return $this->responseWithError($response['message'] ?? 'Invalid request.');
            } catch (\Exception $e) {
                return $this->responseWithError('An error occurred.', $e->getMessage());
            }
        }
    }
    public function verifyEmailCode(Request $request)
    {
        if ($request->isMethod('post')) {
            try {
                $rd = $request->all();
                $users = new User();
                $response = $users->verifyEmailCode($rd);
                if ($response['status'] == 'success') {
                    $username = $response['data']['username'];
                    return $this->responseWithData($response['data']['username'], 'Successfully Verified.');
                } else {
                    return $this->responseWithError('Invalid Code!');
                }
            } catch (\Exception $e) {
                return $this->responseWithError('An error occurred.', $e->getMessage());
            }
        }
    }
    public function autoLogin(Request $request)
    {
        if ($request->isMethod('post')) {
            try {
                $credentials = [
                    'username' => $request->username,
                    'password' => DEFAULT_PASSWORD,
                ];
                if (Auth::attempt($credentials)) {
                    return $this->responseSuccess('Change your password.');
                } else {
                    return $this->responseWithError('Invalid credentials');
                }
            } catch (\Exception $e) {
                return $this->responseWithError('An error occurred.', $e->getMessage());
            }
        }
    }
    public function changeProfileImage(Request $request)
    {
        if (!$request->isMethod('post')) {
            throw new MethodNotAllowedHttpException(['post'], 'Method Not Allowed');
        }
        try {
            $response = ['status' => 'error', 'message' => "Invalid request"];
            $data = $request->all();
            if (!empty($data)) {
                if (!isset($data['table_row_id']) || $data['table_row_id'] == 0) {
                    $data['table_row_id'] = $this->auth_user->profile->id;
                }
                $file_attachment = new FileAttachment();
                $send_data['table_name'] = USER_PROFILE_TABLE_NAME;
                $send_data['table_row_id'] = $data['table_row_id'];
                if (!empty($data['profile_image'])) {
                    $send_data['image'] = $data['profile_image'];
                    $send_data['original_name'] = $data['profile_image_name'] ?? '';
                    $send_data['x_attachment_type_id'] = USER_PROFILE_ATTACHMENT_TYPE_KEY;
                    $response = $file_attachment->base64Upload($send_data);
                }
                if (!empty($data['signature_image'])) {
                    $send_data['image'] = $data['signature_image'];
                    $send_data['original_name'] = $data['signature_image_name'] ?? '';
                    $send_data['x_attachment_type_id'] = USER_SIGNATURE_ATTACHMENT_TYPE_KEY;
                    $response = $file_attachment->base64Upload($send_data);
                }
                if ($response['status'] == 'success') {
                    return $this->responseSuccess('Image changed successfully.');
                }
            }
            return $this->responseWithError($response['message']);
        } catch (\Exception $e) {
            return $this->responseWithError($e->getMessage());
        }
    }
    public function updateStatus(Request $request)
    {
        if (!$request->isMethod('post')) {
            throw new MethodNotAllowedHttpException(['post'], 'Method Not Allowed');
        }
        try {
            $response = [
                'status' => 'error',
                'message' => "Invalid request"
            ];
            $data = $request->all();
            if (!empty($data)) {
                $user = new User();
                $response = $user->statusUpdate($data);
                if ($response['status'] == 'success') {
                    return $this->responseSuccess('Status successfully update.');
                }
            }
            return $this->responseWithError($response['message']);
        } catch (\Exception $e) {
            return $this->responseWithError($e->getMessage());
        }
    }
    public function delete(Request $request)
    {
        if (!$request->isMethod('post')) {
            throw new MethodNotAllowedHttpException(['post'], 'Method Not Allowed');
        }
        try {
            $response = [
                'status' => 'error',
                'message' => "Invalid request"
            ];
            $data = $request->all();
            if (!empty($data)) {
                $user = new User();
                $response = $user->userDelete($data);
                if ($response['status'] == 'success') {
                    return $this->responseSuccess('User successfully delete.');
                }
            }
            return $this->responseWithError($response['message']);
        } catch (\Exception $e) {
            return $this->responseWithError($e->getMessage());
        }
    }

    public function userDetails($key)
    {
        $page_title = 'User Profile';
        $is_admin_action = true;
        $userInfo = new User();
        $user = $userInfo->userDetails($key);
        $userEntity = new UserEntityRole();
        $response = $userEntity->getOrganogramInfo($key);
        $auth_user = [];
        if ($response) {
            $auth_user['current_role'] = !empty($response->entity_type) ? $response->entity_type->role_name : ROLE_ADMIN;
            $auth_user['active_status'] = $user->active_status;
            $auth_user['profile'] = !empty($response->entity_type) ? $response->entity_type->role_name : ROLE_ADMIN;
            $auth_user['supervisor'] = $response->su_profile ? ($response->su_profile->toArray()) : '';
            $employee_profile_id = $response->employee_profile_id ? $response->employee_profile_id : 0;
        }
        return view('users.profile', compact('page_title', 'is_admin_action', 'user', 'auth_user', 'employee_profile_id'));
    }
    public function roleSetup(Request $request)
    {
        try {
            $data = $request->all();
            $role = new UserEntityRole();
            if ($data['status'] == 1) {
                $profile = new UserProfile();
                $profile = $profile->getProfileByUser($data['user_id']);
                $role_data['role_id'] = ENTITYTYPEID_ROLE_MANAGER;
                $role_data['user_id'] = $data['user_id'];
                $role_data['employee_profile_id'] = $profile->id;
                $role_data['entity_type_role_id'] = ENTITYTYPEID_ROLE_MANAGER;
                $role_data['entity_profile_id'] = 0;
                $role_data['is_default_role'] = 1;
                $role_data['is_admin'] = 1;
                $role_data['active_status'] = 0;
                $role_data['created_by'] = \auth()->id();
                $role_data['modified_by'] = \auth()->id();
                $role_data['created'] = Carbon::now();
                $role_data['modified'] = Carbon::now();
                $e_role = $role->saveUserEntityRole($role_data);
                if ($e_role) {
                    return $this->responseSuccess('Role successfully assign.');
                }
            } else {
                $delete_data['user_id'] = $data['user_id'];
                $delete_data['entity_type_role_id'] = ENTITYTYPEID_ROLE_MANAGER;
                if ($role->deleteUserEntityRole($delete_data)) {
                    $role->updateRoleStatus($data['user_id'], ENTITYTYPEID_ROLE_MANAGER, 1);
                    return $this->responseSuccess('Assign Role successfully removed.');
                }
            }
            return $this->responseWithError("An error occurred");
        } catch (\Exception $e) {
            return $this->responseWithError($e->getMessage());
        }
    }
    public function getUserEmail(Request $request)
    {
        $data = $request->all();
        $m_user_profile = new UserProfile();
        $response = $m_user_profile->getUserEmail($data);
        return $response;
    }

    public function userSettings(Request $request)
    {
        if ($request->isMethod('post')) {
            $data = $request->all();
            return $data;
        } else {
            $page_title = __('User Settings');
            return view('ApplicationConfiguration.userSettings.view', compact('page_title'));
        }
    }

    public function userSettingsData(Request $request)
    {
        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 10;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $m_user = new User();
        return response()->json($m_user->getUserSettingList($page, $limit, $start, $search));
    }

    public function userSettingsStatus(Request $request)
    {
        $data = $request->all();
        $m_user = new User();
        $response = $m_user->userStatusUpdate($data);
        return $response;
    }

    public function afUserSettings(Request $request)
    {
        if ($request->isMethod('post')) {
            $data = $request->all();
            return $data;
        } else {
            $page_title = __('Accountancy Firm Setup');
            return view('ApplicationConfiguration.afUserSettings.view', compact('page_title'));
        }
    }

    public function afUserSettingsData(Request $request)
    {
        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 10;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $m_user = new User();
        return response()->json($m_user->getAfUserSettingList($page, $limit, $start, $search));
    }

    ######################
    ##### user setup #####
    ######################
    public function viewUser()
    {
        $page_title = __("Users");
        $is_action_enabled = true;
        return view('users.user.view', compact('page_title', 'is_action_enabled'));
    }
    public function userData(Request $request)
    {
        $page = $request->has('draw') ? $request->get('draw') : 1;
        $limit = $request->has('length') ? $request->get('length') : 10;
        $start = $request->has('start') ? $request->get('start') : 0;
        $search = $request->has('search') ? $request->get('search') : [];
        $model_user = new User();
        return response()->json($model_user->getList($page, $limit, $start, $search));
    }
    public function userSetup(Request $request)
    {
        if ($request->isMethod('post')) {
            $data = $request->all();
            $model_user = new User();
            if ($request->id > 0) {
                $response = $model_user->updateUser($request->id,setAuthInfoToData($data, $this->auth_user));
            }else{
                $response = $model_user->employeeRegister(setAuthInfoToData($data, $this->auth_user));
            }
            return response()->json($response, $response['code'], []);
        }
        $model_bank_branch = new BankBranch();
        $bank_branches = $model_bank_branch->getBankBranches(['id', 'branch_name'])->pluck('branch_name', 'id')->toArray();
        $user = [];
        if ($request->id > 0) {
            $model_user = new User();
            $user = $model_user->getUserSetup($request->id);
            return view('users.user.edit', compact('bank_branches','user'));
        }
        return view('users.user.add', compact('bank_branches','user'));
    }
    public function checkDuplicateUser(Request $request)
    {
        $data = $request->all();
        $username = $data['username'];
        $user_id = $data['user_id'];
        $model_user = new User();
        $response = $model_user->checkDuplicateUsername($username,$user_id);
        return response()->json($response);
    }
}
