<?php

namespace App\Http\Middleware;

use Closure;
use Predis\Client;
use App\RabbitMQService;
use App\Models\ActivityLog;
use App\Jobs\LogUserActivityJob;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redis;

class LogUserActivity
{
    public function handle($request, Closure $next)
    {
        $response = $next($request);
        // Check if Redis is reachable
        try {
            if (class_exists('Redis') && extension_loaded('redis') && Redis::ping()) {
                // Inside the handle method
                if (Auth::check()) {
                    $user = Auth::user();
                    $username = $user->username;
                    $route = $request->route()->getName();

                    // Create the user activity log data
                    $log = [
                        'user_id' => $username,
                        'profile_id' => $user->role->user_profile_id,
                        'device_id' => $request->input('device_id'),
                        'ip_address' => $request->ip(),
                        'user_agent' => $request->header('User-Agent'),
                        'route_name' => $route,
                        'route_url' => $request->fullUrl(),
                        'response_code' => $response->getStatusCode(),
                    ];
                }
            }
            if (ENABLE_RABBIT) {
                if (Auth::check()) {
                    $user = Auth::user();
                    $username = $user->username;
                    $route = $request->route()->getName();

                    // Create the user activity log data
                    $log = [
                        'user_id' => $username,
                        'profile_id' => $user->role->user_profile_id,
                        'device_id' => $request->input('device_id'),
                        'ip_address' => $request->ip(),
                        'user_agent' => $request->header('User-Agent'),
                        'route_name' => $route,
                        'route_url' => $request->fullUrl(),
                        'response_code' => $response->getStatusCode(),
                    ];

                    $rabbit_request_param = ['data' => json_encode($log), 'url' => RABBIT_MQ_ACTIVITY_LOG_URL, 'name' => 'activity_log'];

                    $rabbitMQService = new RabbitMQService('activity_exchange', 'activity_log', 'activity_routing_key');
                    $rabbitMQService->publish(json_encode($rabbit_request_param));
                }
            }
        } catch (\Exception $e) {
        }


        return $response;
    }
}
