<?php

namespace App\Models;

use Carbon\Carbon;
use App\Helpers\APIHelper;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class ActivityLog extends Model
{
    use HasFactory;

    public function saveActivityLog(array $data)
    {
        try {
            $url = config('paths.datawatch_url') . POST_DATA_WATCH_LOG_API;
            $headers = [
                'Content-Type: application/json'
            ];
            $data =
                [
                    'index' => APP_MODE . '_' . USER_ACTIVITY_DATA_WATCH_INDEX,
                    'log_data' => json_encode($data),
                    'request_url' => APP_NAME
                ];
            $apiHelper = new APIHelper();
            $response = $apiHelper->callAPI($url, $headers, 'POST', json_encode($data));
            return ($response['status'] == RESPONSE_STATUS_SUCCESS) ? true : false;
        } catch (\Exception $ex) {
            return false;
        }
    }
    public function getActivityLog($page, $limit, $start, $search, $profile_id)
    {
        if ($profile_id) {
            $search_array['profile_id'] = $profile_id;
            $search_array['*'] = $search['value'];
            $search=json_encode($search_array);
        } else {
            $search = $search['value'];
        }
        $index = APP_MODE . '_' . USER_ACTIVITY_DATA_WATCH_INDEX;
        $user_log = new UserLog();
        $logs = $user_log->getLogByIndex($index, $page, $limit, $start, $search);
        $_total = isset($logs['total_row']) ? $logs['total_row'] : 0;
        $final_data = [];
        $i = 0;
        if (isset($logs['data'])) {
            foreach ($logs['data'] as $log) {
                $index = (++$i) + $start;
                $timestamp = $log["@timestamp"];
                $dateObj = Carbon::createFromTimestamp(strtotime($timestamp));
                $formattedDate = $dateObj->format('M d, Y');
                $formattedTime = $dateObj->format('h:i A');
                $formattedTimestamp = $formattedDate . ', ' . $formattedTime;
                $response_code = (isset($log['log_data']['response_code'])) ? $log['log_data']['response_code'] : 500;
                $status = '<span class="badge badge-light-danger">500 ERR</span>';
                if ($response_code == 400) {
                    $status = '<span class="badge badge-light-warning">404 WRN</span>';
                } elseif ($response_code == 200) {
                    $status = '<span class="badge badge-light-success">200 OK</span>';
                }
                $url = isset($log['log_data']['route_url']) ? $log['log_data']['route_url'] : 'Not Found';
                $url = ($url !== 'Not Found') ? (parse_url($url, PHP_URL_SCHEME) ?? '') . '://' . (parse_url($url, PHP_URL_HOST) ?? '') . (parse_url($url, PHP_URL_PATH) ?? '') : 'Not Found';
                $row = [
                    'sl' => $index,
                    'id' => $log['id'],
                    'url' => $url,
                    'status' => $status,
                    'time' => $formattedTimestamp
                ];
                $final_data[] = $row;
            }
        }
        return ['draw' => $page, 'recordsTotal' => $_total, 'recordsFiltered' => $_total, 'data' => $final_data];
    }
}
