<?php

namespace App\Models;

use DateTime;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Customer extends AppModel
{
    use HasFactory;
    protected $casts = [
        'acc_opn_dt' => 'date:F j, Y',
        'updated_at' => 'date:F j, Y, g:i A',
        'created_at' => 'date:F j, Y, g:i A',
    ];

    private function prepareSearchQuery($query, $request)
    {
        $search_keys = ['id'];
        foreach ($search_keys as $key) {
            if (isset($request[$key])) {
                $query->whereIn($key, is_array(($request[$key])) ? $request[$key] : [$request[$key]]);
            }
        }

        if (isset($request['search_string']) && strlen($request['search_string']) > 0) {
            $searchTerm = $request['search_string'];
            $query->where('ac_name', 'like', '%' . $searchTerm . '%')
                ->orWhere('ac_number', 'like', '%' . $searchTerm . '%');
        }
        return $query;
    }

    public function getList($page, $limit, $start, $search)
    {
        $query = $this::select(['*']);
        $query = $this->prepareSearchQuery($query, ['search_string' => $search['value']]);
        $_total = $query->count();
        if ($limit != '-1') {
            $query->limit($limit)->offset($start);
        }
        $customers = $query->latest('id')->get()->toArray();
        $final_data = [];
        $i = 0;
        foreach ($customers as $item) {
            $index = (++$i) + $start;
            $row['sl'] = $index;
            $row['id'] = $item['id'];
            $row['cust_id'] = $item['cust_id'];
            $row['ac_name'] = $item['ac_name'];
            $row['ac_number'] = $item['ac_number'];
            $row['branch_name'] = $item['branch_name'];
            $row['email'] = $item['email'];
            $row['father_name'] = $item['father_name'];
            $row['action'] = '<a href="/customer/profile/' . $item['id'] . '" class="btn btn-info btn-active-light-info btn-sm btn-icon rounded-0 btn_view"><i class="fa-solid fa-eye"></i></a>';

            $final_data[] = $row;
        }
        return ['draw' => $page, 'recordsTotal' => $_total, 'recordsFiltered' => $_total, 'data' => $final_data];
    }

    public function getCustomer($id, $select = ['*'])
    {
        $query = $this->select($select);
        return $this->prepareSearchQuery($query, ['id' => $id])->first();
    }

    public function getShowCustomer($request_data)
    {
        try {
            if (!isset($request_data['customer_id']) || empty($request_data['customer_id'])) {
                return $this->responseNotFound(__("Invalid Request!"))->original;
            }
            $customer_id = $request_data['customer_id'];
            $customer = $this->getCustomer($customer_id);
            if (empty($customer)) {
                return $this->responseNotFound(__("Customer not found!"))->original;
            }
            $customer = $customer->toArray();
            return $this->responseWithData($customer, __("Customer profile data."))->original;
        } catch (\Exception $e) {
            return $this->responseWithError($e->getMessage(), ['line' => $e->getLine()])->original;
        }
    }
}
