<?php

namespace App\Models;

use Illuminate\Validation\Rule;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Validator;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class EntityType extends AppModel
{
    use HasFactory;
    protected $connection = 'mysql';
    protected $table = 'entity_types';
    public $timestamps = false;
    /**
     * The model's default values for attributes.
     * @var array
     */
    protected $attributes = ['id' => 0];
    /**
     * The attributes that aren't mass assignable.
     * @var array
     */
    protected $guarded = ['type'];
    protected $validation_rules = [
        'name' => 'required|string|max:64',
        'description' => 'required|string|max:255',
        'entity_type_level' => 'required|integer',
    ];
    public function uniqueValidationCheck(array $data)
    {
        $validator = Validator::make($data, [
            'name' => Rule::unique('entity_types', 'name')->ignore($data['id']),
        ]);

        if ($validator->fails()) {
            return [
                'status' => 'error', 'code' => 422,
                'errors' => $validator->errors()->toArray(),
                'message' => __("Validation Error Occurred")
            ];
        }
    }
    public function xServices()
    {
        return $this->hasMany(XService::class, 'entity_type_id');
    }

    public function getEntityTypes()
    {
        return $this->pluck('name', 'id')->toArray();
    }
    public function getEntityTypeOptions()
    {
        return $this->pluck('name', 'id')->toArray();
    }
    public function getEntityTypeList($page, $limit, $start, $search)
    {
        $search = $search['value'];
        $roles = $this::when($search, function ($query) use ($search) {
                return $query->where('name', 'like', "%" . $search . "%")->orWhere('description', 'like', "%" . $search . "%");
            })
            ->limit($limit)
            ->offset($start)
            ->get()
            ->toArray();
        $_total = $this::count();
        $final_data = [];
        $i = 0;
        foreach ($roles as $role) {
            $index = (++$i) + $start;
            $row = [
                'sl' => $index,
                'id' => $role['id'],
                'name' => $role['name'],
                'description' => $role['description'],
                'entity_type_level' => $role['entity_type_level'],
                'action' => '',
            ];
            $final_data[] = $row;
        }
        return ['draw' => $page, 'recordsTotal' => $_total, 'recordsFiltered' => $_total, 'data' => $final_data];
    }
    public function saveOrUpdate(array $data)
    {
        $check = $this->uniqueValidationCheck($data);
        if ($check) {
            return $check;
        }
        return $this->modifiedSave($data, $this->validation_rules);
    }
    public function deleteEntityType($id)
    {
        $entity_type = $this::findOrFail($id);
        $response = ['message' => __('Invalid Request'), 'status' => 'error'];
        if ($entity_type->delete()) {
            $response = ['message' => __('Deleted Successfully'), 'status' => 'success'];
        }
        return $response;
    }
}
