<?php

namespace App\Models;

use Carbon\Carbon;
use App\Helpers\APIHelper;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class ErrorLog extends Model
{

    public function createErrorLog(array $data)
    {
        try {
            $url = config('paths.datawatch_url') . POST_DATA_WATCH_LOG_API;
            $headers = [
                'Content-Type: application/json'
            ];
            $data =
                [
                    'index' => APP_MODE . '_' . ERROR_LOGS_DATA_WATCH_INDEX,
                    'log_data' => json_encode($data),
                    'request_url' => APP_NAME
                ];
            $apiHelper = new APIHelper();
            $response = $apiHelper->callAPI($url, $headers, 'POST', json_encode($data));
            return ($response['status'] == RESPONSE_STATUS_SUCCESS) ? true : false;
        } catch (\Exception $ex) {
            return false;
        }
    }

    public function getErrorLog($page, $limit, $start, $search)
    {
        $search = $search['value'];
        $index = APP_MODE . '_' . ERROR_LOGS_DATA_WATCH_INDEX;
        $user_log = new UserLog();
        $logs = $user_log->getLogByIndex($index, $page, $limit, $start, $search);
        $_total = isset($logs['total_row']) ? $logs['total_row'] : 0;
        $final_data = [];
        $i = 0;
        if (isset($logs['data'])) {
            foreach ($logs['data'] as $log) {
                $index = (++$i) + $start;
                $timestamp = $log["@timestamp"];
                $dateObj = Carbon::createFromTimestamp(strtotime($timestamp));
                $formattedDate = $dateObj->format('M d, Y');
                $formattedTime = $dateObj->format('h:i A');
                $formattedTimestamp = $formattedDate . ', ' . $formattedTime;
                $row = [
                    'sl' => $index,
                    'id' => $log['id'],
                    'user_id' => isset($log['log_data']['user_id']) ? $log['log_data']['user_id'] : 'Not Found',
                    'error_message' => isset($log['log_data']['error_message']) ? $log['log_data']['error_message'] : 'Not Found',
                    'time' => $formattedTimestamp,
                    'laction' => '',
                ];
                $final_data[] = $row;
            }
        }
        return ['draw' => $page, 'recordsTotal' => $_total, 'recordsFiltered' => $_total, 'data' => $final_data];
    }
}
