<?php

namespace App\Models;

use Carbon\Carbon;
use App\Helpers\APIHelper;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Validator;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class LoginLog extends Model
{

    public function createLoginLog(array $data)
    {
        try {
            $url = DATA_WATCH_URL . POST_DATA_WATCH_LOG_API;
            $headers = [
                'Content-Type: application/json'
            ];
            $data =
                [
                    'index' => APP_MODE . '_' . LOGIN_LOGS_DATA_WATCH_INDEX,
                    'log_data' => json_encode($data),
                    'request_url' => APP_NAME
                ];
            $apiHelper = new APIHelper();
            $response = $apiHelper->callAPI($url, $headers, 'POST', json_encode($data));
            return ($response['status'] == RESPONSE_STATUS_SUCCESS) ? true : false;
        } catch (\Exception $ex) {
            return false;
        }
    }
    public function getLoginLog($page, $limit, $start, $search, $profile_id)
    {
        if ($profile_id) {
            $search_array['profile_id'] = $profile_id;
            $search_array['*'] = $search['value'];
            $search = json_encode($search_array);
        } else {
            $search = $search['value'] ?? '';
        }
        $index = APP_MODE . '_' . LOGIN_LOGS_DATA_WATCH_INDEX;
        $user_log = new UserLog();
        $logs = $user_log->getLogByIndex($index, $page, $limit, $start, $search);
        $_total = isset($logs['total_row']) ? $logs['total_row'] : 0;
        $final_data = [];
        $i = 0;
        if (isset($logs['data'])) {
            foreach ($logs['data'] as $log) {
                $index = (++$i) + $start;
                $timestamp = $log["@timestamp"];
                $dateObj = Carbon::createFromTimestamp(strtotime($timestamp));
                $formattedDate = $dateObj->format('M d, Y');
                $formattedTime = $dateObj->format('h:i A');
                $formattedTimestamp = $formattedDate . ', ' . $formattedTime;
                $row = [
                    'sl' => $index,
                    'id' => $log['id'],
                    'user_id' => isset($log['log_data']['user_id']) ? $log['log_data']['user_id'] : 'Not Found',
                    'device' => isset($log['log_data']['user_agent']) ? $log['log_data']['user_agent'] : 'Not Found',
                    'ip_address' => isset($log['log_data']['ip_address']) ? $log['log_data']['ip_address'] : 'Not Found',
                    'status' => (isset($log['log_data']['is_logged_in']) && $log['log_data']['is_logged_in']) || (isset($log['log_data']['is_logged_out']) && $log['log_data']['is_logged_out']) ? '<span class="badge badge-light-success fs-7 fw-bold">OK</span>' : '<span class="badge badge-light-danger fs-7 fw-bold">Not OK</span>',
                    'action' => (isset($log['log_data']['is_logged_in']) && $log['log_data']['is_logged_in']) ? 'Login' : 'Logout',
                    'timestamp' => $formattedTimestamp,
                    'laction' => $formattedTimestamp,
                ];
                $final_data[] = $row;
            }
        }
        return ['draw' => $page, 'recordsTotal' => $_total, 'recordsFiltered' => $_total, 'data' => $final_data];
    }
}
