<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class News extends Model
{
    use HasFactory;

    protected $table="news";

    private function prepareSearchQuery($query, $request)
    {
        if (isset($request['search_string']) && strlen($request['search_string']) > 0) {
            $searchTerm = $request['search_string'];
            $query->where('name_of_person_entity', 'like', '%' . $searchTerm . '%')
                ->orWhere('news_title', 'like', '%' . $searchTerm . '%')
                ->orWhere('profession_designation', 'like', '%' . $searchTerm . '%')
                ->orWhere('location_of_incident', 'like', '%' . $searchTerm . '%')
                ->orWhere('predicate_offence_type', 'like', '%' . $searchTerm . '%')
                ->orWhere('entity_owner_name', 'like', '%' . $searchTerm . '%')
                ->orWhere('publish_date', 'like', '%' . $searchTerm . '%');
        }
        return $query;
    }

    public function getList($page, $limit, $start, $search)
    {
        $query = $this::select(['*']);
        $query = $this->prepareSearchQuery($query, ['search_string' => $search['value']]);
        $_total = $query->count();
        if ($limit != '-1') {
            $query->limit($limit)->offset($start);
        }
        $customers = $query->latest('id')->get()->toArray();
        $final_data = [];
        $i = 0;
        foreach ($customers as $item) {
            $index = (++$i) + $start;
            $row['sl'] = $index;
            $row['id'] = $item['id'];
            $row['name_of_person_entity'] = $item['name_of_person_entity'];
            $row['news_title'] = $item['news_title'];
            $row['profession_designation'] = $item['profession_designation'];
            $row['location_of_incident'] = $item['location_of_incident'];
            $row['address'] = $item['address'];
            $row['predicate_offence_type'] = $item['predicate_offence_type'];
            $row['news_source'] = $item['news_source'];
            $row['publish_date'] = $item['publish_date'];
            $row['entity_owner_name'] = $item['entity_owner_name'];
            $final_data[] = $row;
        }
        return ['draw' => $page, 'recordsTotal' => $_total, 'recordsFiltered' => $_total, 'data' => $final_data];
    }
}
