<?php

namespace App\Models;

use App\Helpers\JaroWinkler;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class NewsData extends Model
{
    use HasFactory;

    protected $table = "news_data";

    private function prepareSearchQuery($query, $request)
    {
        if (isset($request['search_string']) && strlen($request['search_string']) > 0) {
            $searchTerm = $request['search_string'];
            $query->where('Nameofperson_English', 'like', '%' . $searchTerm . '%')
                ->orWhere('News_Title_English', 'like', '%' . $searchTerm . '%')
                ->orWhere('Profession_English', 'like', '%' . $searchTerm . '%')
                ->orWhere('LocationOfIncident_English', 'like', '%' . $searchTerm . '%')
                ->orWhere('PredicateOffenceType_English', 'like', '%' . $searchTerm . '%')
                ->orWhere('NameoftheowneroftheEntity', 'like', '%' . $searchTerm . '%')
                ->orWhere('PublishDate', 'like', '%' . $searchTerm . '%');
        }
        return $query;
    }

    public function getNewsData($id)
    {
        return $this->findOrFail($id);
    }

    public function getList($page, $limit, $start, $search)
    {
        $query = $this::select(['*']);
        $query = $this->prepareSearchQuery($query, ['search_string' => $search['value']]);
        $_total = $query->count();
        if ($limit != '-1') {
            $query->limit($limit)->offset($start);
        }
        $customers = $query->latest('id')->get()->toArray();
        $final_data = [];
        $i = 0;
        foreach ($customers as $item) {
            $index = (++$i) + $start;
            $row['sl'] = $index;
            $row['id'] = $item['id'];
            $row['name_of_person_entity'] = $item['Nameofperson_English'];
            $row['news_title'] = $item['News_Title_English'];
            $row['profession_designation'] = $item['Profession_English'];
            $row['location_of_incident'] = $item['LocationOfIncident_English'];
            $row['address'] = $item['PresentAddress'];
            $row['predicate_offence_type'] = $item['PredicateOffenceType_English'];
            $row['news_source'] = '<a target="_blank" href="' . $item['NewsLink'] . '" class=" btn-active-light-info   ">' . $item['News_Source_English'] . '</a>';
            $row['publish_date'] = $item['PublishDate'];
            $row['entity_owner_name'] = $item['NameoftheowneroftheEntity'];
            $row['action'] = '<a href="/download-news/' . $item['id'] . '" class="btn btn-info btn-active-light-info btn-sm btn-icon rounded-0 "><i class="fa-solid fa-download"></i></a>';
            $final_data[] = $row;
        }
        return ['draw' => $page, 'recordsTotal' => $_total, 'recordsFiltered' => $_total, 'data' => $final_data];
    }


    private function prepareSearchQueryBn($query, $request)
    {
        if (isset($request['search_string']) && strlen($request['search_string']) > 0) {
            $searchTerm = $request['search_string'];
            $query->where('Nameofperson_Bangla', 'like', '%' . $searchTerm . '%')
                ->orWhere('News_Title_Bangla', 'like', '%' . $searchTerm . '%')
                ->orWhere('Profession_Bangla', 'like', '%' . $searchTerm . '%')
                ->orWhere('LocationOfIncident_Bangla', 'like', '%' . $searchTerm . '%')
                ->orWhere('PredicateOffenceType_Bangla', 'like', '%' . $searchTerm . '%')
                ->orWhere('NameoftheowneroftheEntity', 'like', '%' . $searchTerm . '%')
                ->orWhere('PublishDate', 'like', '%' . $searchTerm . '%');
        }
        return $query;
    }

    public function getListBn($page, $limit, $start, $search)
    {
        $query = $this::select(['*']);
        $query = $this->prepareSearchQueryBn($query, ['search_string' => $search['value']]);
        $_total = $query->count();
        if ($limit != '-1') {
            $query->limit($limit)->offset($start);
        }
        $customers = $query->latest('id')->get()->toArray();
        $final_data = [];
        $i = 0;
        foreach ($customers as $item) {
            $index = (++$i) + $start;
            $row['sl'] = $index;
            $row['id'] = $item['id'];
            $row['name_of_person_entity'] = $item['Nameofperson_Bangla'];
            $row['news_title'] = $item['News_Title_Bangla'];
            $row['profession_designation'] = $item['Profession_Bangla'];
            $row['location_of_incident'] = $item['LocationOfIncident_Bangla'];
            $row['address'] = $item['PresentAddress'];
            $row['predicate_offence_type'] = $item['PredicateOffenceType_Bangla'];
            $row['news_source'] = '<a target="_blank" href="' . $item['NewsLink'] . '" class=" btn-active-light-info   ">' . $item['News_Source_Bangla'] . '</a>';
            $row['publish_date'] = $item['PublishDate'];
            $row['entity_owner_name'] = $item['NameoftheowneroftheEntity'];
            $row['action'] = '<a href="/download-news/' . $item['id'] . '" class="btn btn-info btn-active-light-info btn-sm btn-icon rounded-0 "><i class="fa-solid fa-download"></i></a>';
            $final_data[] = $row;
        }
        return ['draw' => $page, 'recordsTotal' => $_total, 'recordsFiltered' => $_total, 'data' => $final_data];
    }

    public function getNewsAgainstProminentPersonData()
    {
        $customers = Customer::get()->toArray();
        $jarwikler = new JaroWinkler();

        $select = ['id', 'Nameofperson_English', 'PublishDate', 'News_Title_Bangla', 'News_Source_Bangla', 'NewsLink', 'NewsContent_Bangla'];
        $yesterday = date("Y-m-d", strtotime('-1 days'));

        $formattedYesterday = formatDateWithSuffix($yesterday);
        $news_datas = $this->select($select)->where('PublishDate', $formattedYesterday)->limit(5)->get()->toArray();

        foreach ($news_datas as &$news_data) {
            $highest_score = 0;
            $email = null;
            $cust_id = null;

            foreach ($customers as $customer) {
                if (!empty($news_data['Nameofperson_English'])) {
                    $score = $jarwikler->getSimilarity($customer['ac_name'], $news_data['Nameofperson_English']) * 100;
                    if ($score > $highest_score) {
                        $highest_score = $score;
                        $email = $customer['email'];
                        $cust_id = $customer['cust_id'];
                    }
                }
            }

            $news_data['email'] = $email;
            $news_data['cust_id'] = $cust_id;
            $news_data['highest_score'] = $highest_score;
        }
        usort($news_datas, function ($a, $b) {
            return $b['highest_score'] <=> $a['highest_score'];
        });
        return $news_datas;
    }

    public function othersMatching($Nameofperson_English, $customers)
    {
        $jarwikler = new JaroWinkler();
        $scored_customers = [];
        $idealScore= 80;
        foreach ($customers as $customer) {
            if (!empty($customer['ac_name'])) {
                $score = $jarwikler->getSimilarity($customer['ac_name'], $Nameofperson_English) * 100;
                if( $score >= $idealScore){
                    $scored_customers[] = [
                        'score' => $score,
                        'id' => $customer['id'],
                        'email' => $customer['email'],
                        'cust_id' => $customer['cust_id'],
                        'ac_name' => $customer['ac_name'],
                        'spouse_name' => $customer['spouse_name'] ?? '-',
                        'father_name' => $customer['father_name'],
                        'mother_name' => $customer['mother_name'],
                        'ac_number' => $customer['ac_number'],
                        'branch_name' => $customer['branch_name'],
                    ];
                }

            }
        }
        usort($scored_customers, function ($a, $b) {
            return $b['score'] <=> $a['score'];
        });
        $top_five_customers = array_slice($scored_customers, 1, 5);
        return $top_five_customers;
    }

    public  function getNewsDataSummary() {
        // Retrieve all NewsData records
        $select = ['id', 'PredicateOffenceType_English', 'PublishDate', 'News_Title_Bangla', 'News_Source_Bangla', 'NewsLink', 'NewsContent_English'];
        $yesterday = date("Y-m-d", strtotime('-1 days'));
        $formattedYesterday = formatDateWithSuffix($yesterday);
        $newsData = $this->select($select)->where('PublishDate', $formattedYesterday)->get()->toArray();


        // Initialize an empty array to hold category counts
        $categoriesCount = [];

        // Iterate over each record to process the `PredicateOffenceType_English` column
        foreach ($newsData as $data) {
            // Split the `PredicateOffenceType_English` field into an array of categories
            $categories = explode(',', $data['PredicateOffenceType_English']);

            // Iterate over each category and count occurrences
            foreach ($categories as $category) {
                $category = trim($category); // Remove any extra spaces
                if (isset($categoriesCount[$category])) {
                    $categoriesCount[$category] += 1; // Increment count if category already exists
                } else {
                    $categoriesCount[$category] = 1; // Otherwise, set the count to 1
                }
            }
        }

        // Now you have the categories and their counts
        // Build the summary array (e.g., this can be passed to a view)
        $summeryData = [
            'total_news' => count($newsData),
            'categories' => $categoriesCount,
            'news_data' => $newsData
        ];
        return  $summeryData;
    }
}
