<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Prunable;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;

class NotificationType extends AppModel
{
    use HasFactory, Prunable, SoftDeletes;
    protected $connection = 'mysql';
    protected $with = [];
    protected $attributes = ['id' => 0];
    protected $guarded = ['type'];
    protected $dateFormat = 'Y-m-d H:i:s';
    protected $dates = [];
    public static function rules($id = null)
    {
        return [
            'type_name' => [
                'required',
                'string',
                'max:64',
                Rule::unique('notification_types', 'type_name')->ignore($id),
            ],
        ];
    }

    protected $casts = [
        'created_at' => 'date:d-m-Y',
        'updated_at' => 'date:d-m-Y',
    ];

    public function prunable(): Builder
    {
        return static::where('id', '=', -100000000);
    }

    private function prepareSearchQuery($query, $request)
    {
        $search_keys = ['id','type_status'];
        foreach ($search_keys as $key) {
            if (isset($request[$key]) && intval($request[$key]) > 0) {
                $query->whereIn($key, is_array(($request[$key])) ? $request[$key] : [$request[$key]]);
            }
        }
        if (isset($request['search_string']) && strlen($request['search_string']) > 0) {
            $query->where('type_name', 'like', "%" . $request['search_string'] . "%");
        }
        return $query;
    }

    private function typeDeletionRoles($query)
    {
        return true;
    }

    public function getNotificatonType($id)
    {
        return $this->findOrFail($id);
    }

    public function getList($page, $limit, $start, $search)
    {
        $query = $this::select(['id','type_name','type_description','type_status']);
        $query = $this->prepareSearchQuery($query, ['search_string' => $search['value']]);
        $_total = $query->count();
        $notificationTypes = $query->limit($limit)->offset($start)->get()->toArray();
        $final_data = [];
        $i = 0;
        foreach ($notificationTypes as $notificationType) {
            $index = (++$i) + $start;
            $row = [
                'sl' => $index,
                'id' => $notificationType['id'],
                'type_name' => $notificationType['type_name'],
                'type_description' => $notificationType['type_description'],
                // 'type_status' => $notificationType['type_status'],
                'action' => '',
            ];
            $final_data[] = $row;
        }
        return ['draw' => $page, 'recordsTotal' => $_total, 'recordsFiltered' => $_total, 'data' => $final_data];
    }

    public function getOptions($request = null)
    {
        try {
            $query = $this::select('id', 'type_name');
            return $this->prepareSearchQuery($query, ['search_string' => $request['value'] ?? ""])->pluck('type_name','id');
        } catch (\Exception $e) {
            return [];
        }
    }

    public function saveOrUpdate(array $data)
    {
        return $this->modifiedSave($data, []);
    }

    public function deleteNotificationType($id)
    {
        $query = $this->findOrFail($id);
        $delete_role = $this->typeDeletionRoles($query);
        if ($delete_role === true) {
            $query->delete();
            return ['message' => __('Deleted Successfully'), 'status' => 'success'];
        } else {
            return ['message' => __($delete_role), 'status' => 'error'];
        }
    }

}
