<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Support\Facades\Http;
use Ntfy\Auth\User;
use Ntfy\Client;
use Ntfy\Message;
use Ntfy\Server;

class PushNotification extends AppModel
{
    use HasFactory;

    public function sendSms(array $data)
    {
        try {
            if (!empty($data)) {
                if (empty($data['mobile_number'])) {
                    $response['message'] = "Mobile number required!";
                }
                if (empty($data['sms_content'])) {
                    $response['message'] = "Sms content required!";
                }
                if (!empty($data['mobile_number']) && !empty($data['sms_content'])) {
                    $response['message'] = "Sms configuration not set!";
                }
            } else {
                $response['message'] = "Required data missing!";
            }
            return $this->responseWithError($response['message']);
        } catch (\Exception $e) {
            return $this->responseWithError($e->getMessage());
        }
    }
    public function sendEmail($request_data)
    {
        try {
            if (empty($request_data)) {
                return $this->responseWithError(__("Required data missing!"));
            }
            $request_data['user_id'] = 0;
            if ($request_data['profile_id'] == 0) {
                $request_data['profile_id'] = $request_data['current_profile_id'];
            }
            if (isset($request_data['profile_id']) && $request_data['profile_id'] > 0) {
                $m_user_profile = new UserProfile();
                $profile = $m_user_profile->getProfile($request_data['profile_id']);
                $request_data['user_id'] = $profile['user_id'] ?? 0;
            }
            $m_email_service = new EmailService();
            $response = $m_email_service->prepareSendEmailData($request_data);
            if ($response['status'] == 'success') {
                return $this->responseSuccess(__('Email successfully send.'));
            } else {
                return $this->responseWithError(__("Failed to send email"));
            }
        } catch (\Exception $e) {
            return $this->responseWithError($e->getMessage());
        }
    }
    public function sendPushNotification($request_data)
    {
        try {
            if (empty($request_data)) {
                return $this->responseWithError(__("Required data missing!"));
            }
            $user_id = 0;
            if ($request_data['profile_id'] == 0) {
                $request_data['profile_id'] = $request_data['current_profile_id'];
            }
            if (isset($request_data['profile_id']) && $request_data['profile_id'] > 0) {
                $m_user_profile = new UserProfile();
                $profile = $m_user_profile->getProfile($request_data['profile_id']);
                $user_id = $profile['user_id'] ?? 0;
            }
            if (empty($request_data['notify_title'])) {
                return $this->responseWithError(__("Notification title required!"));
            }
            if (empty($request_data['notify_message'])) {
                return $this->responseWithError(__("Notification message required!"));
            }
            $m_notification_event = new NotificationEvent();
            $notification_event = $m_notification_event->findByName(USER_NOTIFICATION_EVENT)->toArray();
            if (empty($notification_event)) {
                return $this->responseWithError(__("Notification event not found!"));
            }
            $response_notify = $this->sendNotificationApi($user_id, 0, '', $notification_event['id'], $request_data['notify_message']);
            if ($response_notify['status'] == RESPONSE_STATUS_SUCCESS) {
                return $this->responseSuccess('Notification successfully sent.');
            } else {
                return $this->responseWithError(__("Failed to send notification"));
            }
        } catch (\Exception $e) {
            return $this->responseWithError($e->getMessage());
        }
    }
    public function userNotify($user_id, $title, $body, $url = "javascript:void(0)")
    {
        $m_notification_event = new NotificationEvent();
        $notification_event = $m_notification_event->findByName(USER_NOTIFICATION_EVENT);
        if ($notification_event) {
            $notification_message = new NotificationMessage();
            if ($notification_message->saveNotificationDataPrepare($user_id, $notification_event->id, $body, $url, 0)) {
                $server = new Server(config('push_notify.url'));
                $message = new Message();
                $message->topic('base_' . $user_id);
                $message->title($title);
                $message->body($body);
                $message->clickAction($url);
                $message->priority(Message::PRIORITY_HIGH);
                $auth = new User(config('push_notify.username'), config('push_notify.password'));
                $client = new Client($server, $auth);
                $client->send($message);
                return true;
            }
        }
        return false;
    }
    public function sendNotificationApi($user_id, $client_profile_id, $client_name, $notification_event_id, $body)
    {
        if (DATA_WATCH_ENABLE) {
            return $this->sendFirebasePushNotification($user_id, $client_profile_id, $client_name, $notification_event_id, $body, $url = "javascript:void(0)");
        } else {
            return $this->saveNotificationData($user_id, $client_profile_id, $client_name, $notification_event_id, $body);
        }
    }

    public function saveNotificationData($user_id, $client_profile_id, $client_name, $notification_event_id, $body, $url = "javascript:void(0)")
    {
        $user_configure = new UserNotificationConfiguration();
        //check user are allowed or not this event
        if ($user_configure->checkNotificationUserAreAllowed($user_id, $notification_event_id)) {
            $notification_message = new NotificationMessage();
            if ($notification_message->saveNotificationDataPrepare($user_id, $notification_event_id, $body, $url, $client_profile_id)) {
                $notification_event = new NotificationEvent();
                $notification_event = $notification_event->find($notification_event_id);
                $title = $notification_event->notificationType->type_description ?? $notification_event->name;
                return $this->dispatchToNotify($title, $body, $user_id, $url);
                // $this->dispatchToNtfy($title, $body, $user_id, $url);

            }
        }
    }

    public function dispatchToNotify($title, $body, $user_id, $url = "javascript:void(0)")
    {
        $m_user_register_device = new UserRegisteredDevice();
        $firebaseToken = $m_user_register_device->getUserRegisterDeviceToken($user_id)->toArray();
        if (empty($firebaseToken)) {
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => __('Device registered not found!')];
        }
        $data = [
            "registration_ids" => $firebaseToken,
            "notification" => [
                "title" => $title,
                "body" => $body,
            ]
        ];
        $dataString = json_encode($data);
        $headers = [
            'Authorization: key=' . FIREBASE_SERVER_KEY,
            'Content-Type: application/json',
        ];
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, STATIC_CURLPORT_URL);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $dataString);
        $response = curl_exec($ch);
        if ($response !== false) {
            return ['status' => RESPONSE_STATUS_SUCCESS, 'message' => json_decode($response)];
        } else {
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => __('Failed to dispatch notification.')];
        }
    }

    public function initNtfy()
    {
        return Http::withoutVerifying()->withBasicAuth(config('push_notify.username'), config('push_notify.password'));
    }

    public function dispatchToNtfy($title, $message, $recipient, $click_action = 'javascript:void(0)')
    {
        try {
            $domain = config('push_notify.url') . '/base_' . $recipient;
            $dispatch = $this->initNtfy()->withHeaders([
                'Title' => $title,
                'Click' => $click_action
            ])->post($domain, [
                'content' => $message
            ]);
            if ($dispatch->successful()) {
                return $dispatch->json();
            } else {
                return ['status' => RESPONSE_STATUS_ERROR, 'message' => __('Failed to dispatch notification.')];
            }
        } catch (\Exception $e) {
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => $e->getMessage()];
        }
    }

    public function dispatchToNotifytoUser($request_data)
    {
        if (!isset($request_data['title']) || empty($request_data['title'])) {
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => __('Title is required')];
        } elseif (!isset($request_data['body']) || empty($request_data['body'])) {
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => __('Message Body is required')];
        } elseif (!isset($request_data['user_id']) || empty($request_data['user_id'])) {
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => __('User Id is required')];
        }
        return $this->dispatchToNotify($request_data['title'], $request_data['body'], $request_data['user_id']);
    }

    // ** START DATA WATCH NOTIFICATION **
    public function sendFirebasePushNotification($user_id, $client_profile_id, $client_name, $notification_event_id, $body, $url = "javascript:void(0)")
    {
        $m_user_notification_configuration = new UserNotificationConfiguration();
        if ($m_user_notification_configuration->checkNotificationUserAreAllowed($user_id, $notification_event_id)) {
            $m_notification_message = new NotificationMessage();
            if ($m_notification_message->saveDataWatchNotification($user_id, $notification_event_id, $body, $url, $client_profile_id, $client_name)) {
                $notification_event = new NotificationEvent();
                $notification_event = $notification_event->find($notification_event_id);
                $title = $notification_event->notificationType->type_description ?? $notification_event->name;
                return $this->dispatchToNotify($title, $body, $user_id, $url);
                // $this->dispatchToNtfy($title, $body, $user_id, $url);

            }
        }
    }
    // ** END DATA WATCH NOTIFICATION **
}
