<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Prunable;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class SelfAssessmentReport extends AppModel
{
    use HasFactory, Prunable, SoftDeletes;
    protected $guarded = [];
    protected $casts = [
        'for_half_year_ended' => 'date:d-M-Y',
        'created_at' => 'date:d-M-Y H:i A',
        'updated_at' => 'date:d-M-Y',
    ];
    public function prunable()
    {
        return static::where('id', '=', -100000000);
    }
    public function bank_branch()
    {
        return $this->belongsTo(BankBranch::class, 'bank_branch_id');
    }
    private function prepareSearchQuery($query, $request)
    {
        $search_keys = ['id', 'user_profile_name'];
        foreach ($search_keys as $key) {
            if (isset($request[$key])) {
                $query->whereIn($key, is_array(($request[$key])) ? $request[$key] : [$request[$key]]);
            }
        }
        if (isset($request['search_string']) && strlen($request['search_string']) > 0) {
            $query->where('user_profile_name', 'like', "%" . $request['search_string'] . "%");
        }
        return $query;
    }
    public function saveOrUpdate($request_data)
    {
        $data['id'] = $request_data['id'] ?? 0;
        $data['user_profile_id'] = $request_data['bamlco_id'] ?? 0;
        $data['user_profile_name'] = $request_data['bamlco_name'] ?? '';
        $data['bank_branch_id'] = $request_data['bank_branch_id'] ?? 0;
        $data['branch_type'] = $request_data['branch_type'] ?? '';
        $data['for_half_year_ended'] = $request_data['for_half_year_ended'] ?? null;
        $data['created_by'] = $request_data['created_by'] ?? null;
        return $this->modifiedSave($data, []);
    }
    public function getList($page, $limit, $start, $search)
    {
        $query = $this::select(['*']);
        $query = $this->prepareSearchQuery($query, ['search_string' => $search['value']])->with('bank_branch');
        $_total = $query->count();
        if ($limit != '-1') {
            $query->limit($limit)->offset($start);
        }
        $self_assessment_reports = $query->latest('id')->get()->toArray();
        $final_data = [];
        $i = 0;
        foreach ($self_assessment_reports as $self_assessment_report) {
            $branch_type = '';
            if ($self_assessment_report['branch_type'] == 'ad_branch') {
                $branch_type = __("AD Branch");
            } elseif ($self_assessment_report['branch_type'] == 'non_ad_branch') {
                $branch_type = __("Non AD Branch");
            }
            $index = (++$i) + $start;
            $row['sl'] = $index;
            $row['id'] = $self_assessment_report['id'];
            $row['user_profile_id'] = $self_assessment_report['user_profile_id'];
            $row['user_profile_name'] = $self_assessment_report['user_profile_name'];
            $row['user_profile_name'] = $self_assessment_report['user_profile_name'];
            $row['bank_branch_id'] = $self_assessment_report['bank_branch_id'];
            $row['bank_branch_name'] = $self_assessment_report['bank_branch']['branch_name'] ?? null;
            $row['branch_type'] = $branch_type;
            $row['for_half_year_ended'] = $self_assessment_report['for_half_year_ended'];
            $row['created_at'] = $self_assessment_report['created_at'];
            $row['action'] = '';
            $final_data[] = $row;
        }
        return ['draw' => $page, 'recordsTotal' => $_total, 'recordsFiltered' => $_total, 'data' => $final_data];
    }
    public function getSelfAssessmentReport($id, $select = ['*'])
    {
        $query = $this->select($select);
        $self_assessment_report = $this->prepareSearchQuery($query, ['id' => $id])->with('bank_branch')->first();
        if (empty($self_assessment_report)) {
            return $this->responseNotFound(__('Self Assessment not found!'))->original;
        }
        $self_assessment_report = $self_assessment_report->toArray();
        $data['id'] = $self_assessment_report['id'];
        $data['user_profile_id'] = $self_assessment_report['user_profile_id'];
        $data['user_profile_name'] = $self_assessment_report['user_profile_name'];
        $data['bank_branch_id'] = $self_assessment_report['bank_branch_id'];
        $data['bank_branch_name'] = $self_assessment_report['bank_branch']['branch_name'] ?? null;
        $data['branch_type'] = $self_assessment_report['branch_type'];
        $data['for_half_year_ended'] = $self_assessment_report['for_half_year_ended'];
        return $this->responseWithData($data, __("Self Assessment data."))->original;
    }
}
