<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Prunable;
use Illuminate\Database\Eloquent\SoftDeletes;

class UserActivationCode extends AppModel
{
    use HasFactory, Prunable, SoftDeletes;
    protected $connection = 'mysql';
    protected $with = [];
    /**
     * The model's default values for attributes.
     * @var array
     */
    protected $attributes = ['id' => 0];
    /**
     * The attributes that aren't mass assignable.
     * @var array
     */
    protected $guarded = ['type'];
    /**
     * Get the prunable model query.
     */
    public function prunable(): Builder
    {
        return static::where('expiry', '<=', now()->subMonth());
    }
    /**
     * Date parameter setup.
     */
    protected $dateFormat = 'Y-m-d H:i:s';
    protected $casts = [];
    /**
     * Rule parameter setup.
     */
    public function rules()
    {
        return [];
    }
    /**
     * Relation Setup
     */
    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }
    /**
     * Virtual Fields setup.
     */
    protected $appends = [];
    /**
     * private functions
     * Add all private functions here
     */
    private function prepareSearchQuery($query, $request)
    {
        $search_keys = ['id', 'user_id', 'username', 'email', 'activation_type', 'activation_code', 'is_active', 'expiry'];
        foreach ($search_keys as $key) {
            if (isset($request[$key])) {
                $query->whereIn($key, is_array($request[$key]) ? $request[$key] : [$request[$key]]);
            }
        }
        if (isset($request['search_string']) && strlen($request['search_string']) > 0) {
            $search_string = $request['search_string'];
            $query = $query->where(function ($query) use ($search_string) {
                $query->where('username', 'like', '%' . $search_string . '%')
                    ->orWhere('email', 'like', '%' . $search_string . '%');
            });
        }

        return $query;
    }
    /**
     * public functions
     * Add all public functions here
     */
    public function saveOrUpdate($data)
    {
        return $this->modifiedSave($data, []);
    }
    public function getList($page, $limit, $start, $search)
    {
        $result = $this::all();
        $final_data = [];
        return ['draw' => $page, 'recordsTotal' => $result['total'], 'recordsFiltered' => $result['total'], 'data' => $final_data];
    }
    public function getOptions($options = [])
    {
        $_data_options = $this->all()->pluck('id', 'id');
        return $_data_options;
    }

    public function getUserActivationData($condition, $select = ['*'])
    {
        $query = $this->select($select);
        return $this->prepareSearchQuery($query, $condition);
    }
}
