<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Prunable;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;

class UserEntityRole extends AppModel
{
    use HasFactory, Prunable, SoftDeletes;
    protected $connection = 'mysql';
    protected $with = [];
    protected $attributes = ['id' => 0];
    protected $guarded = ['type'];
    protected $dateFormat = 'Y-m-d H:i:s';
    protected $casts = [];
    public function rules()
    {
        return [];
    }
    public function prunable()
    {
        return static::where('id', '=', -100000000);
    }
    /*** Relation Setup */
    public function entity_type()
    {
        return $this->belongsTo(EntityTypeRole::class, 'entity_type_role_id');
    }
    public function profile()
    {
        return $this->belongsTo(UserProfile::class, 'user_profile_id');
    }
    public function supervisor()
    {
        return $this->belongsTo(UserProfile::class, 'supervisor_user_profile_id');
    }
    /**
     * Virtual Fields setup.
     */
    protected $appends = [];
    /**
     * private functions
     */
    function prepareSearchQuery($query, $request)
    {
        $search_keys = ['id', 'user_id', 'user_profile_id', 'supervisor_user_profile_id', 'entity_type_role_id', 'entity_profile_id'];
        foreach ($search_keys as $key) {
            if (isset($request[$key])) {
                $query->whereIn($key, is_array(($request[$key])) ? $request[$key] : [$request[$key]]);
            }
        }
        return $query;
    }
    /**
     * public functions
     */
    public function getList($page, $limit, $start, $search)
    {
        $result = $this::all();
        $final_data = [];
        return ['draw' => $page, 'recordsTotal' => $result['total'], 'recordsFiltered' => $result['total'], 'data' => $final_data];
    }
    public function getOptions($options = [])
    {
        $_data_options = $this->all()->pluck('id', 'id');
        return $_data_options;
    }

    // Formatting Ends Here

    public function findByUserId($user_id)
    {
        return $this->where('user_id', $user_id)->first();
    }

    public function findByProfileId($user_profile_id)
    {
        return $this->where('user_profile_id', $user_profile_id)->whereNotIn('entity_type_id', [SYSTEM_ADMIN_ENTITY_TYPE_ID, SYSTEM_ENTITY_TYPE_ID])->first();
    }

    public function loadManagers($entity_profile_id = 0)
    {
        $query = $this->with('profile');
        if ($entity_profile_id > 0) {
            return $this->prepareSearchQuery($query, ['entity_type_role_id' => ENTITYTYPEID_ROLE_MANAGER, 'entity_profile_id' => $entity_profile_id])->get();
        }
        return $this->prepareSearchQuery($query, ['entity_type_role_id' => ENTITYTYPEID_ROLE_MANAGER])->get();
    }

    public function getColleagues($manager_profile_id, $current_user_role)
    {
        $colleages = $this->loadColleaguesManagerWise($manager_profile_id);
        $profile = [];
        foreach ($colleages as $colleage) {
            $profile[$colleage->profile ? $colleage->profile->id : ""] = $colleage->profile ? $colleage->profile->full_name : "";
        }
        return $profile;
    }

    public function responsiblePersonOptions($request_data)
    {
        $colleages = $this->with('profile')->where('entity_type_role_id', ENTITYTYPEID_ROLE_COLLEAGUE)->get();
        foreach ($colleages as $colleage) {
            $profile[$colleage->profile ? $colleage->profile->id : ""] = $colleage->profile ? $colleage->profile->full_name : "";
        }
        return $profile;
    }

    public function loadColleagues()
    {
        return $this->with('profile')->where('entity_type_role_id', ENTITYTYPEID_ROLE_COLLEAGUE)
            ->where('supervisor_user_profile_id', 0)->get();
    }
    public function countColleague($manager_profile_id)
    {
        return $this->where('entity_type_role_id', ENTITYTYPEID_ROLE_COLLEAGUE)
            ->where('supervisor_user_profile_id', $manager_profile_id)->count();
    }

    public function loadColleagueList($rd)
    {
        return $this->with('profile')->where('supervisor_user_profile_id', $rd)->get();
    }

    public function saveUserEntity($data, $cp_ids)
    {
        $managerProfileId = $data['manager_p_id'];
        $managerUserId = $this->where('user_profile_id', $managerProfileId)->pluck('user_id')->first();
        return $this->whereIn('user_profile_id', $cp_ids)->update([
            'supervisor_user_id' => $managerUserId,
            'supervisor_user_profile_id' => $managerProfileId,
        ]);
    }

    public function getOrganogramInfo($user_id)
    {
        DB::enableQueryLog();
        $response = $this->with('su_profile', 'entity_type')->where('user_id', $user_id)->first();
        return $response;
    }

    public function deleteEntityProfile($id)
    {
        $userInfoByEnitity = $this->where('entity_profile_id', $id)->select('user_id', 'user_profile_id')->first();
        if ($userInfoByEnitity) {
            $this->where('entity_profile_id', $id)->delete();
            if (!empty($userInfoByEnitity->user_id)) {
                $userTable = new User();
                $userTable->deleteUser($userInfoByEnitity->user_id);
            }
            if (!empty($userInfoByEnitity->user_profile_id)) {
                $userProfileTable = new UserProfile();
                $userProfileTable->deleteUserProfile($userInfoByEnitity->user_profile_id);
            }
            return true;
        } else {
            return false;
        }
    }

    public function loadColleaguesManagerWise($manager_profile_id, $select = ['*'])
    {
        $query = $this->select($select);
        $colleages = $this->prepareSearchQuery($query, ['entity_type_role_id' => ENTITYTYPEID_ROLE_COLLEAGUE, 'supervisor_user_profile_id' => $manager_profile_id])->get();
        return $colleages;
    }
    public function deleteUserEntityRole($data)
    {
        $user = new User();
        $user = $user->find($data['user_id']);
        if ($user->other_role) {
            $userInfoByEnitity = $this->where('user_id', $data['user_id'])->where('entity_type_role_id', $data['entity_type_role_id'])->first();
            if ($userInfoByEnitity) {
                $userInfoByEnitity->delete();
                return true;
            }
        }
        return false;
    }

    public function roleSwitch($user_id, $current_role_id, $update_role_id)
    {
        $user = new User();
        $user = $user->find($user_id);
        if ($user->other_role) {
            $current = $this->where('user_id', $user_id)->where('entity_type_role_id', $current_role_id)->first();
            $update = $this->where('user_id', $user_id)->where('entity_type_role_id', $update_role_id)->first();
            if ($current && $update) {
                $current->update(['active_status' => 0]);
                $update->update(['active_status' => 1]);
                return true;
            }
        }
        return false;
    }

    public function updateRoleStatus($user_id, $role_id, $status = 0)
    {
        $role = $this->where('user_id', $user_id)->where('entity_type_role_id', $role_id)->first();
        if ($role) {
            $role->update(['active_status' => $status]);
            return true;
        }
        return false;
    }
    /********************** Formatting Starts Here::  */
    function getRolesByProfileIds($pro_ids)
    {
        return $this->with('entity_type')->whereIn('user_profile_id', $pro_ids)->get();
    }
    public function getColleagueProfileIds($sup_id = -1)
    {
        if ($sup_id == 0) {
            return $this->where('entity_type_role_id', ENTITYTYPEID_ROLE_COLLEAGUE)->where('supervisor_user_profile_id', 0)->get(); //supervisor is not assigned
        } else if ($sup_id == -1) {
            return $this->where('entity_type_role_id', ENTITYTYPEID_ROLE_COLLEAGUE)->get(); //all
        } else if ($sup_id == -2) {
            return $this->where('entity_type_role_id', ENTITYTYPEID_ROLE_COLLEAGUE)->where('supervisor_user_profile_id', '>', 0)->get(); //supervisor assigned
        } else {
            return $this->where('entity_type_role_id', ENTITYTYPEID_ROLE_COLLEAGUE)->where('supervisor_user_profile_id', $sup_id)->get(); // for specific supervisor
        }
    }
    public function getManagerProfileIds()
    {
        return $this->select('user_profile_id', 'id')->where('entity_type_role_id', ENTITYTYPEID_ROLE_MANAGER)->get();
    }
    public function getSupervisorId($colleague_profile_id)
    {
        return $this->select('supervisor_user_profile_id')->where('entity_type_role_id', ENTITYTYPEID_ROLE_COLLEAGUE)->where('user_profile_id', $colleague_profile_id)->get()->first();
    }
    public function assignColleague($data)
    {
        if (count($data['colleague_pro_ids']) <= 0) {
            return ['status' => 'error', 'message' => __('No Colleague has found to assign')];
        }
        $manager = $this->getRolesByProfileIds([0 => $data['manager_pro_id']])->toArray();
        $colleagues = $this->getRolesByProfileIds($data['colleague_pro_ids'])->toArray();
        $colleagues_map_id = [];
        foreach ($colleagues as $colleage) {
            $colleagues_map_id[] = $colleage['id'];
        }
        $query = $this->whereIn('id', $colleagues_map_id);
        if ($query->update(['supervisor_user_id' => $manager[0]['user_id'], 'supervisor_user_profile_id' => $manager[0]['user_profile_id']])) {
            return true;
        }
        return false;
    }
    public function saveUserEntityRole($data)
    {
        try {
            if (isset($data['role_id'])) {
                $m_entity_type_role = new EntityTypeRole();
                $entity_type_role = $m_entity_type_role->getEntityById($data['role_id']);
                if (!empty($entity_type_role)) {
                    $data['entity_type_role_id'] = $entity_type_role->id;
                    $data['entity_type_id'] = $entity_type_role->entity_type_id;
                }
            }
            return $this->modifiedSave($data, []);
        } catch (\Exception $e) {
            $response = [
                'status' => 'error',
                'message' => 'An error occurred while saving user role.',
                'error' => $e->getMessage()
            ];
        }
        return $response;
    }
    public function clientWiseTotalUsers($client_profile_id)
    {
        return $this->where('entity_profile_id', $client_profile_id)
            ->whereNotIn('entity_type_id', [SYSTEM_ADMIN_ENTITY_TYPE_ID, SYSTEM_ENTITY_TYPE_ID])
            ->get();
    }
    ######################
    ##### user setup #####
    ######################
    public function bank_branch()
    {
        return $this->belongsTo(BankBranch::class, 'bank_branch_id');
    }
    public function prepareSaveUserEntityRole($request_data)
    {
        try {
            $exists_role = $this->select('id', 'user_id', 'user_profile_id')
                ->where('user_id', $request_data['user_id'])
                ->where('user_profile_id', $request_data['user_profile_id'])
                ->first();
            $role_data['id'] = $exists_role->id ?? 0;
            $role_data['user_id'] = $request_data['user_id'];
            $role_data['user_profile_id'] = $request_data['user_profile_id'];
            $role_data['bank_branch_id'] = $request_data['bank_branch_id'];
            $role_data['branch_type'] = $request_data['branch_type'];
            $role_data['entity_type_id'] = 1002; //employee = 1002
            $role_data['entity_type_role_id'] = 2; //employee = 2
            $role_data['email'] = $request_data['email'];
            if(array_key_exists('created_by',$request_data)){
                $role_data['created_by'] = $request_data['created_by'];
            }
            DB::beginTransaction();
            $user_entity_role = $this->modifiedSave($role_data, []);
            if ($user_entity_role['status'] == RESPONSE_STATUS_ERROR) {
                DB::rollBack();
                return $user_entity_role;
            }
            DB::commit();
            return $user_entity_role;
        } catch (\Exception $e) {
            return $this->responseWithError($e->getMessage())->original;
        }
    }
}
