<?php

namespace App\Models;

use Carbon\Carbon;
use App\Helpers\APIHelper;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Prunable;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Query\Builder;

class UserLog extends AppModel
{
    use HasFactory, Prunable, SoftDeletes;
    protected $dateFormat = 'Y-m-d H:i:s';
    protected $with = [];
    protected $attributes = ['id' => 0];
    protected $guarded = ['type'];

    public function prunable(): Builder
    {
        return static::where('id', '=', -100000000);
    }
    protected $casts = [];
    public function rules()
    {
        return [];
    }
    /**
     * Relation Setup
     */
    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }
    /**
     * Virtual Fields setup.
     */
    protected $appends = [];
    /**
     * private functions
     */
    function prepareSearchQuery($query, $request)
    {
        $search_keys = ['user_id', 'id'];
        foreach ($search_keys as $key) {
            if (isset($request[$key]) && intval($request[$key]) > 0) {
                $query->whereIn($key, is_array(($request[$key])) ? $request[$key] : [$request[$key]]);
            }
        }
        return $query;
    }
    /**
     * public functions
     * Add all public functions here
     */
    public function saveOrUpdate($data)
    {
        return $this->modifiedSave($data, []);
    }
    public function getList($page, $limit, $start, $search)
    {
        $result = $this::all();
        $final_data = [];
        return ['draw' => $page, 'recordsTotal' => $result['total'], 'recordsFiltered' => $result['total'], 'data' => $final_data];
    }
    public function getOptions($options = [])
    {
        $_data_options = $this->all()->pluck('id', 'id');
        return $_data_options;
    }
    //Formatting Ends

    public function passwordResetLog($entity)
    {
        $user_data = [
            'name' => $entity->profile ? $entity->profile->name : "",
            'username' => $entity->username,
        ];
        $data['log_type'] = "password reset";
        $data['log_data'] = "";
        $data['user_id'] = $entity->id;
        $data['user_data'] = json_encode($user_data);
        $data['created_by'] = $entity->profile ? $entity->profile->id : "";
        $data['created_by_data'] = $entity->profile ? $entity->profile->name : "";
        $data['created'] = Carbon::now();
        return $this->create($data);
    }

    public function saveUserLog(array $data)
    {
        try {
            if (empty($data['log_type']) || empty($data['user_id']) || empty($data['user_data'])) {
                throw new \Exception('Invalid request!');
            }
            $data['created_by'] = auth()->user()->id;
            $data['created_by_data'] = auth()->user()->profile->name ?? '';
            $data['created'] = Carbon::now();
            return $this->create($data);
        } catch (\Exception $ex) {
            return false;
        }
    }
    public function logCreate(array $data)
    {
        try {
            $url = DATA_WATCH_URL . POST_DATA_WATCH_LOG_API;
            $headers = ['Content-Type: application/json'];
            $log = [
                'index' => APP_MODE . '_' . USER_LOG_DATA_WATCH_INDEX,
                'log_data' => json_encode($data),
                'request_url' => APP_NAME
            ];
            $apiHelper = new APIHelper();
            $response = $apiHelper->callAPI($url, $headers, 'POST', json_encode($log));
            if ($response['status'] == RESPONSE_STATUS_SUCCESS) {
                return true;
            } else {
                return $this->saveUserLog($data);
            }
        } catch (\Exception $ex) {
            return $this->saveUserLog($data);
        }
    }
    public function getUserLog($index, $page, $limit, $start, $search, $from = '', $to = '')
    {
        $index = APP_MODE . '_' . USER_LOG_DATA_WATCH_INDEX;
        return $this->getLogByIndex($index, $page, $limit, $start, $search, $from = '', $to = '');
    }
    public function getLogByIndex($index, $page, $limit, $start, $search, $from = '', $to = '')
    {
        try {
            $url = DATA_WATCH_URL . GET_DATA_WATCH_LOG_API;
            $headers = ['Content-Type: application/json'];
            $start = ($start / $limit) + 1;
            // Assign validated values from $request to $data array
            $data = [
                'index' => $index,
                'length' => $limit,
                'page' => $start,
                'order' => 'desc',
                'from' => $from,
                'to' => $to,
                'search_keyword' => $search,
            ];
            $apiHelper = new APIHelper();
            $response = $apiHelper->callAPI($url, $headers, 'POST', json_encode($data));
            return ['status' => $response['status'], 'data' => $response['data'], 'total_row' => $response['total_row']];
        } catch (\Exception $ex) {
            return false;
        }
    }
}
