<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Prunable;
use Illuminate\Database\Eloquent\SoftDeletes;

class UserNotificationConfiguration extends AppModel
{
    use HasFactory, Prunable, SoftDeletes;
    protected $connection = 'mysql';
    protected $with = [];
    protected $attributes = ['id' => 0];
    protected $guarded = ['type'];
    protected $dateFormat = 'Y-m-d H:i:s';
    protected $casts = [];
    public function rules()
    {
        return [
            'user_id' => 'required',
            'notification_events' => 'required',
        ];
    }
    public function prunable(): Builder
    {
        return static::where('id', '=', -100000000);
    }
    /*** Relation Setup */
    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }
    /**
     * Virtual Fields setup.
     */
    protected $appends = [];
    /**
     * private functions
     */
    function prepareSearchQuery($query, $request)
    {
        $search_keys = ['user_id', 'user_profile_id', 'supervisor_user_profile_id', 'entity_type_role_id'];
        foreach($search_keys as $key) {
            if (isset($request[$key]) && intval($request[$key]) > 0) {
                $query->whereIn($key, is_array(($request[$key])) ? $request[$key] : [$request[$key]]);
            }
        }
        return $query;
    }
    /**
     * public functions
     */
    public function checkNotificationUserAreAllowed($user_id,$notification_event_id)
    {
        $user_configure = $this->where('user_id',$user_id)->first();
        if ($user_configure) {
            if (!empty($user_configure->notification_events)) {
                $notification_events = json_decode($user_configure->notification_events, true);
                return in_array($notification_event_id, $notification_events);
            }
        }
        return true;
    }
    public function getConfiguration($user_id)
    {
        return $this->where('user_id',$user_id)->first();
    }
    public function saveOrUpdate(array $data)
    {
        return $this->modifiedSave($data, []);
    }
    public function getList($page, $limit, $start, $search)
    {
        $result = $this::all();
        $final_data = [];
        return ['draw' => $page, 'recordsTotal' => $result['total'], 'recordsFiltered' => $result['total'], 'data' => $final_data];
    }
    public function getOptions($options = [])
    {
        $_data_options = $this->all()->pluck('id', 'id');
        return $_data_options;
    }
}
