<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Prunable;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\DB;

class UserRegisteredDevice extends AppModel
{
    use HasFactory, Prunable, SoftDeletes;
    protected $connection = 'mysql';
    protected $with = [];
    protected $attributes = ['id' => 0];
    protected $guarded = ['status'];
    protected $dateFormat = 'Y-m-d H:i:s';
    protected $dates = [];
    public static function rules()
    {
        return [
            'user_id' => 'required|integer|max:20',
            'device' => 'required|string|max:255',
            'token' => 'required',
        ];
    }

    private function prepareSearchQuery($query, $request)
    {
        $search_keys = ['id', 'user_id', 'token', 'device'];
        foreach ($search_keys as $key) {
            if (isset($request[$key])) {
                $query->whereIn($key, is_array($request[$key]) ? $request[$key] : [$request[$key]]);
            }
        }
        return $query;
    }

    public function saveOrUpdate(array $request_data)
    {
        if (!isset($request_data['token']) || empty($request_data['token'])) {
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => __('Token is required')];
        } elseif (!isset($request_data['user_id']) || empty($request_data['user_id'])) {
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => __('User Id is required')];
        } elseif (!isset($request_data['device']) || empty($request_data['device'])) {
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => __('Device is required')];
        }
        $m_user = new User();
        $user = $m_user->userDetails($request_data['user_id']);
        if (empty($user)) {
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => __('Invalid User Id.')];
        }
        try {
            $data = [
                'user_id' => $request_data['user_id'],
                'device' => $request_data['device'],
                'token' => $request_data['token'],
                'created_by' => $request_data['created_by'] ?? 0,
                'updated_by' => $request_data['updated_by'] ?? 0,
                'created_at' => now(),
                'updated_at' => now(),
            ];
            DB::beginTransaction();
            $this->updateOrCreate(['device' => $data['device'], 'user_id' => $data['user_id']], $data);
            DB::commit();
            return ['status' => RESPONSE_STATUS_SUCCESS, 'code' => 200, 'message' => __("Saved successfully")];
        } catch (\Exception $e) {
            DB::rollBack();
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => $e->getMessage()];
        }
    }

    public function getUserRegisterDeviceToken($user_id)
    {
        $query = $this->select(['token']);
        return $this->prepareSearchQuery($query, ['user_id' => $user_id])->pluck('token');
    }

    public function storeWebToken($request_data)
    {
        if (!isset($request_data['token']) || empty($request_data['token'])) {
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => __('Token is required')];
        } elseif (!isset($request_data['device']) || empty($request_data['device'])) {
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => __('Device is required')];
        }
        $request_data['user_id'] = $request_data['updated_by'];
        return $this->saveOrUpdate($request_data);
    }

    public function checkDeviceToken($request_data)
    {
        try {
            $query = $this->select(['id', 'device', 'user_id']);
            $exists = $this->prepareSearchQuery($query, ['user_id' => $request_data['current_profile_id'], 'device' => $request_data['device']])->exists();
            if ($exists) {
                return ['status' => RESPONSE_STATUS_ERROR, 'message' => __('This device already registered.')];
            }
            return ['status' => RESPONSE_STATUS_SUCCESS, 'action' => true, 'message' => __('This device not registered.')];
        } catch (\Exception $e) {
            return ['status' => RESPONSE_STATUS_ERROR, 'message' => $e->getMessage()];
        }
    }
}
