<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Prunable;
use Illuminate\Database\Eloquent\SoftDeletes;

class XAttachmentType extends AppModel
{
    use HasFactory, Prunable, SoftDeletes;
    protected $connection = 'mysql';
    protected $with = [];
    protected $attributes = ['id' => 0];
    protected $guarded = ['type'];
    protected $dateFormat = 'Y-m-d H:i:s';
    protected $dates = [];
    public static function rules()
    {
        return [
            'name' => 'required|string|max:255',
            'attachment_group' => 'required|string'
        ];
    }

    protected $casts = [
        'created_at' => 'date:d-m-Y',
        'updated_at' => 'date:d-m-Y',
    ];

    public function prunable(): Builder
    {
        return static::where('id', '=', -100000000);
    }

    private function prepareSearchQuery($query, $request)
    {
        $search_keys = ['id'];
        foreach ($search_keys as $key) {
            if (isset($request[$key]) && intval($request[$key]) > 0) {
                $query->whereIn($key, is_array(($request[$key])) ? $request[$key] : [$request[$key]]);
            }
        }
        if (isset($request['search_string']) && strlen($request['search_string']) > 0) {
            $query->where('name', 'like', "%" . $request['search_string'] . "%");
        }
        return $query;
    }

    private function typeDeletionRoles($query)
    {
        return true;
    }

    public function getAttachmentType($id)
    {
        return $this->findOrFail($id);
    }

    public function getList($page, $limit, $start, $search)
    {
        $query = $this::select(['id','name','attachment_group']);
        $query = $this->prepareSearchQuery($query, ['search_string' => $search['value']]);
        $x_attachments = $query->limit($limit)->offset($start)->get()->toArray();
        $_total = $query->count();
        $final_data = [];
        $i = 0;
        foreach ($x_attachments as $x_attachment) {
            $index = (++$i) + $start;
            $row = [
                'sl' => $index,
                'id' => $x_attachment['id'],
                'name' => $x_attachment['name'],
                'attachment_group' => $x_attachment['attachment_group'],
                'action' => '',
            ];
            $final_data[] = $row;
        }
        return ['draw' => $page, 'recordsTotal' => $_total, 'recordsFiltered' => $_total, 'data' => $final_data];
    }

    public function saveOrUpdate(array $data)
    {
        return $this->modifiedSave($data, []);
    }

    public function deleteAttachment($id)
    {
        $query = $this->getAttachmentType($id);
        $delete_role = $this->typeDeletionRoles($query);
        if ($delete_role === true) {
            $query->delete();
            return ['message' => __('Deleted Successfully'), 'status' => 'success'];
        } else {
            return ['message' => __($delete_role), 'status' => 'error'];
        }
    }

    public function getOptions($request = null)
    {
        try {
            $query = $this::select('id', 'name');
            return $this->prepareSearchQuery($query, ['search_string' => $request['value']])->pluck('name','id');
        } catch (\Exception $e) {
            return [];
        }
    }

}
