<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Prunable;
use Illuminate\Database\Eloquent\SoftDeletes;

class XHoliday extends AppModel
{
    use HasFactory, Prunable, SoftDeletes;
    protected $connection = 'mysql';
    protected $with = [];
    protected $attributes = ['id' => 0];
    protected $guarded = ['type'];
    protected $dateFormat = 'Y-m-d H:i:s';
    protected $dates = ['date'];
    public static function rules()
    {
        return [
            'holiday_type' => 'required|string|max:32',
            'date' => 'required',
            'year' => 'required',
        ];
    }

    protected $casts = [
        'date' => 'date:d-M-Y',
        'created_at' => 'date:d-m-Y',
        'updated_at' => 'date:d-m-Y',
    ];

    public function prunable(): Builder
    {
        return static::where('id', '=', -100000000);
    }

    private function prepareSearchQuery($query, $request)
    {
        $search_keys = ['id','year'];
        foreach ($search_keys as $key) {
            if (isset($request[$key]) && intval($request[$key]) > 0) {
                $query->whereIn($key, is_array(($request[$key])) ? $request[$key] : [$request[$key]]);
            }
        }
        if (isset($request['search_string']) && strlen($request['search_string']) > 0) {
            $query->where('name', 'like', "%" . $request['search_string'] . "%");
        }
        return $query;
    }

    private function holidayDeletionRoles($query)
    {
        return true;
    }

    public function getHoliday($id)
    {
        return $this->findOrFail($id);
    }

    public function getList($page, $limit, $start, $search)
    {
        $query = $this::select(['id','holiday_type','date','year']);
        $query = $this->prepareSearchQuery($query, ['search_string' => $search['value']]);
        $x_holidays = $query->limit($limit)->offset($start)->get()->toArray();
        $_total = $query->count();
        $final_data = [];
        $i = 0;
        foreach ($x_holidays as $x_holiday) {
            $index = (++$i) + $start;
            $row = [
                'sl' => $index,
                'id' => $x_holiday['id'],
                'holiday_type' => $x_holiday['holiday_type'],
                'date' => $x_holiday['date'],
                'year' => $x_holiday['year'],
                'action' => '',
            ];
            $final_data[] = $row;
        }
        return ['draw' => $page, 'recordsTotal' => $_total, 'recordsFiltered' => $_total, 'data' => $final_data];
    }

    public function saveOrUpdate(array $data)
    {
        return $this->modifiedSave($data, []);
    }

    public function deleteHoliday($id)
    {
        $query = $this->getHoliday($id);
        $delete_role = $this->holidayDeletionRoles($query);
        if ($delete_role === true) {
            $query->delete();
            return ['message' => __('Deleted Successfully'), 'status' => 'success'];
        } else {
            return ['message' => __($delete_role), 'status' => 'error'];
        }
    }

    public function getOptions($request = null)
    {
        try {
            $query = $this::select('id', 'holiday_type');
            return $this->prepareSearchQuery($query, ['search_string' => $request['value']])->pluck('holiday_type','id');
        } catch (\Exception $e) {
            return [];
        }
    }
}
