<?php

namespace App;

use PhpAmqpLib\Connection\AMQPStreamConnection;
use PhpAmqpLib\Message\AMQPMessage;

class RabbitMQService
{
    protected $connection;
    protected $channel;
    protected $exchange;
    protected $queue;
    protected $routingKey;

    public function __construct($exchange, $queue, $routingKey)
    {
        $this->exchange = $exchange;
        $this->queue = $queue;
        $this->routingKey = $routingKey;

        $this->connection = new AMQPStreamConnection(
            env('RABBITMQ_HOST'),
            env('RABBITMQ_PORT'),
            env('RABBITMQ_USER'),
            env('RABBITMQ_PASSWORD'),
            env('RABBITMQ_VHOST')
        );

        $this->channel = $this->connection->channel();

        $this->channel->exchange_declare($this->exchange, 'direct', false, true, false);
        $this->channel->queue_declare($this->queue, false, true, false, false);
        $this->channel->queue_bind($this->queue, $this->exchange, $this->routingKey);
    }

    public function publish($message)
    {
        try {
            $msg = new AMQPMessage($message);
            $this->channel->basic_publish($msg, $this->exchange, $this->routingKey);
            return true;
        } catch (\Exception $e) {
            return false;
        }
    }

    public function consume($callback)
    {
        $queues = ['error_log', 'login_log', 'activity_log'];

        foreach ($queues as $queue) {
            echo "Consuming messages from $queue\n";
            $this->channel->basic_consume($queue, '', false, true, false, false, function ($msg) use ($callback) {
                $callback($msg->body);
            });
        }

        while (count($this->channel->callbacks)) {
            $this->channel->wait();
        }
    }

    public function __destruct()
    {
        $this->channel->close();
        $this->connection->close();
    }
}
