<?php

namespace App\Traits;

use Illuminate\Http\Response as HttpResponse;

trait RequestResponse
{
    public $status_code = HttpResponse::HTTP_OK;

    public function getStatusCode()
    {
        return $this->status_code;
    }

    public function setStatusCode($status_code)
    {
        $this->status_code = $status_code;
        return $this;
    }

    public function requestResponse($data, $header = [])
    {
        return response()->json($data, $this->getStatusCode(), $header);
    }

    public function responseWithData($data, $message = null)
    {
        return $this->requestResponse([
            'status' => RESPONSE_STATUS_SUCCESS,
            'data' => $data,
            'message' => $message,
        ]);
    }

    public function responseWithError($message, $details = [])
    {
        return $this->requestResponse([
            'status' => RESPONSE_STATUS_ERROR,
            'message' => $message,
            'details' => $details,
        ]);
    }

    public function respondUnauthorized($message)
    {
        return $this->setStatusCode(HttpResponse::HTTP_UNAUTHORIZED)->requestResponse([
            'status' => RESPONSE_STATUS_ERROR,
            'message' => $message,
        ]);
    }

    public function respondBadRequest($message)
    {
        return $this->setStatusCode(HttpResponse::HTTP_BAD_REQUEST)->requestResponse([
            'status' => RESPONSE_STATUS_ERROR,
            'message' => $message,
        ]);
    }

    public function responseNotFound($message = 'Not found!')
    {
        return $this->setStatusCode(HttpResponse::HTTP_NOT_FOUND)->responseWithError($message);
    }


    public function responseInternalError($message = 'Internal server error!', $details = [])
    {
        return $this->setStatusCode(HttpResponse::HTTP_INTERNAL_SERVER_ERROR)->responseWithError($message, $details);
    }

    public function responseCreated($message, $data = null)
    {
        return $this->setStatusCode(HttpResponse::HTTP_CREATED)->requestResponse([
            'status' => RESPONSE_STATUS_SUCCESS,
            'data' => $data,
            'message' => $message,
        ]);
    }

    public function responseSuccess($message)
    {
        return $this->requestResponse([
            'status' => RESPONSE_STATUS_SUCCESS,
            'success' => true,
            'message' => $message,
        ]);
    }

    public function responseDeleted($message)
    {
        return $this->requestResponse([
            'status' => RESPONSE_STATUS_SUCCESS,
            'message' => $message,
        ]);
    }

    public function responseInvalidRequest($message = 'Sorry! Required field is missing')
    {
        return $this->setStatusCode(HttpResponse::HTTP_FORBIDDEN)->responseWithError($message);
    }
}
