<?php

use App\Models\ClientDomain;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\File;
use Tymon\JWTAuth\Facades\JWTAuth;
use Tymon\JWTAuth\Facades\JWTFactory;

if (!function_exists('wwec')) {
    // write data with empty checking
    function wwec($value)
    {
        if (empty($value)) {
            return '-';
        }
        return $value;
    }
}

if (!function_exists('convert_to_seconds')) {
    function convert_to_seconds($duration)
    {
        $now = new DateTime();
        $future = clone $now;
        $future->modify('+' . $duration);

        $diff = date_diff($now, $future);
        return $diff->s + ($diff->i * 60) + ($diff->h * 3600);
    }
}

if (!function_exists('getTimeAgo')) {
    function getTimeAgo($timestamp)
    {
        $currentTimestamp = time();
        $timeDifference = $currentTimestamp - $timestamp;
        $minutesAgo = floor($timeDifference / 60);
        $hoursAgo = floor($timeDifference / (60 * 60));
        $daysAgo = floor($timeDifference / (60 * 60 * 24));
        if ($minutesAgo < 1) {
            $time = 'Just now';
        } else if ($minutesAgo < 60) {
            $time = $minutesAgo . " minute" . ($minutesAgo !== 1 ? 's' : '') . " ago";
        } else if ($hoursAgo < 24) {
            $time = $hoursAgo . " hour" . ($hoursAgo !== 1 ? 's' : '') . " ago";
        } else {
            $time = $daysAgo . " day" . ($daysAgo !== 1 ? 's' : '') . " ago";
        }
        return $time;
    }
}

if (!function_exists('FolderTotalFileCounts')) {
    function FolderTotalFileCounts($id)
    {
        $now = new \App\Models\XFolder();
        return $now->getAllChildFileCounts($id);
    }
}

if (!function_exists('filterTotalFileCounts')) {
    function filterTotalFileCounts($column, $id, $status = false)
    {
        $document = new \App\Models\ClientServiceDocument();
        $client = new \App\Models\ClientProfile();
        $client_profile_ids = $client->getClientIdsByUser();
        if ($status == false) {
            $total = $document->whereIn('client_profile_id', $client_profile_ids)->where($column, $id)->select($column)->count();
        } else {
            $total = $document->whereIn('client_profile_id', $client_profile_ids)->with('file_attachment')
                ->join('file_attachments', 'file_attachments.id', '=', 'document_service_mappings.file_attachment_id')
                ->select('file_attachments.attachment_type', 'file_attachments.id')->where('file_attachments.' . $column, $id)->count();
        }
        return $total;
    }
}
if (!function_exists('makeDirectory')) {
    function makeDirectory($directoryInfo, $mode = 0755)
    {
        if (!empty($directoryInfo)) {
            if (!File::isDirectory($directoryInfo)) {
                File::makeDirectory($directoryInfo, $mode, true, true);
            }
        }
        return false;
    }
}
if (!function_exists('imageUnlink')) {
    function imageUnlink($path)
    {
        if (file_exists(storage_path($path))) {
            unlink(storage_path($path));
            return true;
        }
        return false;
    }
}
if (!function_exists('setAuthInfoToData')) {
    function setAuthInfoToData($data, $user)
    {
        if (!isset($data['id'])) {
            $data['id'] = 0;
        }
        if (intval($data['id']) < 1) {
            $data['created_by'] = isset($user->id) ? $user->id : 0;
        }
        $data['modified_by'] = isset($user->id) ? $user->id : 0;
        $data['updated_by'] = isset($user->id) ? $user->id : 0;
        $data['current_role'] = isset($user->current_role) ? $user->current_role : '';
        $data['current_profile_id'] = isset($user->role->user_profile_id) ? $user->role->user_profile_id : 0;
        $data['entity_profile_id'] = isset($user->role->entity_profile_id) ? $user->role->entity_profile_id : 0;
        if (strtolower($data['current_role']) != ROLE_CLIENT && $data['entity_profile_id'] == 0) {
            $data['entity_profile_id'] = 1;
        }
        return $data;
    }
}

///save button
if (!function_exists('getSaveButton')) {
    function getSaveButton($options)
    {
        echo '<button
                type="button"
                title="' . (isset($options['_title']) ? $options['_title'] : "Save") . '"
                data-action="' . (isset($options['data_action']) ? $options['data_action'] : "") . '"
                data-key="' . (isset($options['data_key']) ? $options['data_key'] : "") . '"
                data-option="' . (isset($options['data_option']) ? $options['data_option'] : "") . '"
                id="' . (isset($options['suffix']) ? "btn_submit" . $options['suffix'] : "btn_submit") . '"
                class="' . (isset($options['optional_class']) ? $options['optional_class'] : "btn btn-sm btn-primary btn-active-light-primary") . ' rounded-0 fw-bold btn_submit ' . (isset($options['suffix']) ? $options['suffix'] : "") . '">
                    <i class="fa-solid ' . (isset($options['_icon']) ? $options['_icon'] : "fa-floppy-disk") . '"></i>
                    <span class="ms-1">' . (isset($options['display_text']) ? $options['display_text'] : "Save") . '</span>
                </button>';
    }
}

///save icon button
if (!function_exists('getSaveIconButton')) {
    function getSaveIconButton($options)
    {
        echo '<button
                type="button"
                title="' . (isset($options['_title']) ? $options['_title'] : "Save") . '"
                data-action="' . (isset($options['data_action']) ? $options['data_action'] : "") . '"
                data-key="' . (isset($options['data_key']) ? $options['data_key'] : "") . '"
                id="' . (isset($options['suffix']) ? "btn_submit" . $options['suffix'] : "btn_submit") . '"
                class="btn btn-dark btn-active-light-dark btn-sm btn-icon rounded-0 btn_submit' . (isset($options['suffix']) ? $options['suffix'] : "") . '">
                    <i class="fa-solid ' . (isset($options['_icon']) ? $options['_icon'] : "fa-floppy-disk") . '"></i>
                </button>';
    }
}

///cancel button
if (!function_exists('getCancelButton')) {
    function getCancelButton($options)
    {
        $_suffix = isset($options['_suffix']) ? $options['_suffix'] : "Reject";
        $_title = isset($options['_title']) ? $options['_title'] : "Button";
        $_class = isset($options['_class']) ? $options['_class'] : "";
        $_btn_icon = isset($options['_icon']) ? $options['_icon'] : "<i class='fa-solid fa-arrows-rotate'></i>";
        $_display_text = isset($options['_text']) ? $options['_text'] : "Cancel";
        $_data_options = isset($options['_data_options']) ? $options['_data_options'] : "";
        $_id = (strlen($_suffix) > 0) ? 'btn_cancel' . $_suffix  : 'btn_cancel';
        $_class = (strlen($_class) > 0) ? $_class  : 'btn_cancel';
        $_data_key = isset($options['data_key']) ? $options['data_key'] : "";
        echo '<button data-' . $_data_key . ' title="' . $_title . '" type="button" class="btn btn-sm btn-danger btn-active-light-danger rounded-0 fw-bold  ' . $_class . '" id="' . $_id . '" ' . $_data_options . ' >' . $_btn_icon . '<span class="ms-1">' . $_display_text . '</button>';
    }
}
///reset button
if (!function_exists('getResetButton')) {
    function getResetButton($options)
    {
        $_suffix = isset($options['_suffix']) ? $options['_suffix'] : "btn_reset";
        $_title = isset($options['_title']) ? $options['_title'] : "Reset";
        $_class = isset($options['_class']) ? $options['_class'] : "";
        $_btn_icon = isset($options['_icon']) ? $options['_icon'] : "<i class='fa-solid fa-arrows-rotate'></i>";
        $_display_text = isset($options['_text']) ? $options['_text'] : "Reset";
        $_data_options = isset($options['_data_options']) ? $options['_data_options'] : "";
        $_id = (strlen($_suffix) > 0) ? 'btn_reset' . $_suffix  : 'btn_reset';
        $_class = (strlen($_class) > 0) ? $_class  : 'btn_reset';
        $_data_key = isset($options['data_key']) ? $options['data_key'] : "";
        echo '<button data-' . $_data_key . ' title="' . $_title . '" type="button" class="btn btn-sm btn-danger btn-active-light-danger rounded-0 fw-bold ' . $_class . '" id="' . $_id . '" ' . $_data_options . ' >' . $_btn_icon . '<span class="ms-1">' . $_display_text . '</button>';
    }
}
///delete button
if (!function_exists('getDeleteButton')) {
    function getDeleteButton($options)
    {
        $_suffix = isset($options['_suffix']) ? $options['_suffix'] : "";
        $_title = isset($options['_title']) ? $options['_title'] : "Delete";
        $_class = isset($options['_class']) ? $options['_class'] : "";
        $_btn_icon = isset($options['_icon']) ? $options['_icon'] : "<i class='fs-3 fa-solid fa-trash-can'></i>";
        $_display_text = isset($options['_text']) ? $options['_text'] : "Delete";
        $_data_options = isset($options['_data_options']) ? $options['_data_options'] : "";
        $_id = (strlen($_suffix) > 0) ? 'btn_delete' . $_suffix  : 'btn_delete';
        $_class = (strlen($_class) > 0) ? $_class  : 'btn_delete';
        $_data_key = isset($options['data_key']) ? $options['data_key'] : "";
        $_data_action = isset($options['data_action']) ? $options['data_action'] : "";
        echo '<button data-action="' . ($_data_action) . '" data-key="' . ($_data_key) . '" title="' . $_title . '" type="button" class="btn btn-sm btn-danger btn-active-light-danger rounded-0 fw-bold ' . $_class . '" id="' . $_id . '" ' . $_data_options . ' >' . $_btn_icon . '<span class="ms-1">' . $_display_text . '</button>';
    }
}

if (!function_exists('getDeleteIconButton')) {
    function getDeleteIconButton($options)
    {
        echo '<button
                type="button"
                data-toggle="confirmation"
                title="' . (isset($options['_title']) ? $options['_title'] : "Delete") . '"
                data-action="' . (isset($options['data_action']) ? $options['data_action'] : "") . '"
                data-key=' . (isset($options['data_key']) ? $options['data_key'] : '') . ' ""
                id="' . (isset($options['suffix']) ? "btn_delete" . $options['suffix'] : "btn_delete") . '"
                class="btn btn-sm btn-icon btn-danger btn-active-light-danger rounded-0 btn_delete ' . (isset($options['suffix']) ? "btn_delete" . $options['suffix'] : "") . '">
                    <i class="fs-3 fa-solid ' . (isset($options['_icon']) ? $options['_icon'] : "fa-trash-can") . '"></i>
                </button>';
    }
}
///edit button
if (!function_exists('getEditButton')) {
    function getEditButton($options)
    {
        $_suffix = isset($options['_suffix']) ? $options['_suffix'] : "";
        $_title = isset($options['_title']) ? $options['_title'] : "Edit";
        $_class = isset($options['_class']) ? $options['_class'] : "";
        $_btn_icon = isset($options['_icon']) ? $options['_icon'] : '<i class="fa-solid fa-pen-to-square"></i>';
        $_display_text = isset($options['_text']) ? $options['_text'] : "Delete";
        $_data_options = isset($options['_data_options']) ? $options['_data_options'] : "";
        $_data_key = isset($options['data_key']) ? $options['data_key'] : "";
        $_id = (strlen($_suffix) > 0) ? 'btn_edit' . $_suffix  : 'btn_edit';
        $_class = (strlen($_class) > 0) ? $_class  : 'btn_edit';
        echo '<button data-' . $_data_key . ' title="' . $_title . '" type="button" class="btn btn-sm btn-dark btn-active-light-dark rounded-0 fw-bold ' . $_class . '" id="' . $_id . '" ' . $_data_options . ' >' . $_btn_icon . '<span class="ms-1">' . $_display_text . '</button>';
    }
}
//edit icon button
if (!function_exists('getEditIconButton')) {
    function getEditIconButton($options)
    {
        echo '<button
                type="button"
                title="' . (isset($options['_title']) ? $options['_title'] : "Edit") . '"
                data-action="' . (isset($options['data_action']) ? $options['data_action'] : "") . '"
                data-key="' . (isset($options['data_key']) ? $options['data_key'] : "") . '"
                id="' . (isset($options['suffix']) ? "btn_edit" . $options['suffix'] : "btn_edit") . '"
                class="btn btn-warning btn-active-light-warning btn-sm btn-icon rounded-0 btn_edit ' . (isset($options['suffix']) ? "btn_edit" . $options['suffix'] : "") . '">
                    <i class="fa-solid ' . (isset($options['_icon']) ? $options['_icon'] : "fa-edit") . '"></i>
                </button>';
    }
}
//upload icon button
if (!function_exists('getUploadIconButton')) {
    function getUploadIconButton($options)
    {
        echo '<button
                type="button"
                title="' . (isset($options['title']) ? $options['title'] : "Upload") . '"
                data-contract-id="' . (isset($options['data_contract_id']) ? $options['data_contract_id'] : 0) . '"
                data-document-id="' . (isset($options['data_document_id']) ? $options['data_document_id'] : 0) . '"
                data-service-id="' . (isset($options['data_service_id']) ? $options['data_service_id'] : 0) . '"
                data-owner-id="' . (isset($options['data_owner_id']) ? $options['data_owner_id'] : 0) . '"
                data-auth-profile-id="' . (isset($options['data_auth_profile_id']) ? $options['data_auth_profile_id'] : 0) . '"
                data-key="' . (isset($options['data_key']) ? $options['data_key'] : 0) . '"
                data-client-id="' . (isset($options['data_client_id']) ? $options['data_client_id'] : 0) . '"
                id="' . (isset($options['suffix']) ? "btn_upload" . $options['suffix'] : "btn_upload") . '"
                class="btn-sm btn-icon rounded-0 btn_upload ' . (isset($options['class']) ? "btn_upload" . $options['class'] : "") . '">
                    <i class="fa-solid ' . (isset($options['icon']) ? $options['icon'] : "fs-3 fa-file-upload") . '"></i>
                </button>';
    }
}
//upload button
if (!function_exists('getUploadButton')) {
    function getUploadButton($options)
    {
        $_suffix = isset($options['_suffix']) ? $options['_suffix'] : "";
        $_title = isset($options['_title']) ? $options['_title'] : "Upload";
        $_class = isset($options['_class']) ? $options['_class'] : "";
        $_btn_icon = isset($options['_icon']) ? $options['_icon'] : '<i class="fa-solid fa-upload"></i>';
        $_display_text = isset($options['_text']) ? $options['_text'] : "Upload";
        $_data_options = isset($options['_data_options']) ? $options['_data_options'] : "";
        $_id = (strlen($_suffix) > 0) ? 'btn_upload' . $_suffix  : 'btn_upload';
        $_class = (strlen($_class) > 0) ? $_class  : 'btn_upload';
        $_data_key = isset($options['data_key']) ? $options['data_key'] : "";
        echo '<button data-key="' . ($_data_key) . '" title="' . $_title . '" type="button" class="btn btn-sm btn-primary btn-active-light-primary rounded-0 ' . $_class . '" id="' . $_id . '" ' . $_data_options . ' >' . $_btn_icon . '<span class="ms-1">' . $_display_text . '</button>';
    }
}
///view button
if (!function_exists('getViewButton')) {
    function getViewButton($options)
    {
        $_suffix = isset($options['_suffix']) ? $options['_suffix'] : "";
        $_title = isset($options['_title']) ? $options['_title'] : "View";
        $_class = isset($options['_class']) ? $options['_class'] : "";
        $_btn_icon = isset($options['_icon']) ? $options['_icon'] : '<i class="fa-solid fa-book-open"></i>';
        $_display_text = isset($options['_text']) ? $options['_text'] : "View";
        $_data_options = isset($options['_data_options']) ? $options['_data_options'] : "";
        $_id = (strlen($_suffix) > 0) ? 'btn_view' . $_suffix  : 'btn_view';
        $_class = (strlen($_class) > 0) ? $_class  : 'btn_view';
        $_data_key = isset($options['data_key']) ? $options['data_key'] : "";
        echo '<button data-key="' . ($_data_key) . '" title="' . $_title . '" type="button" class="btn btn-sm btn-primary btn-active-light-primary rounded-0 ' . $_class . '" id="' . $_id . '" ' . $_data_options . ' >' . $_btn_icon . '<span class="ms-1">' . $_display_text . '</button>';
    }
}
//view icon button
if (!function_exists('getViewIconButton')) {
    function getViewIconButton($options)
    {
        echo '<button
                type="button"
                title="' . (isset($options['_title']) ? $options['_title'] : "View") . '"
                data-action="' . (isset($options['data_action']) ? $options['data_action'] : "") . '"
                data-key="' . (isset($options['data_key']) ? $options['data_key'] : "") . '"
                id="' . (isset($options['suffix']) ? "btn_view" . $options['suffix'] : "btn_view") . '"
                class="btn btn-primary btn-active-light-primary btn-sm btn-icon rounded-0 btn_view ' . (isset($options['suffix']) ? "btn_view" . $options['suffix'] : "") . '">
                ' . (isset($options['_icon']) ? $options['_icon'] : "fs-3 fa-book-open") . '
                </button>';
    }
}
///filter button
if (!function_exists('getFilterButton')) {
    function getFilterButton($options)
    {
        $_suffix = isset($options['_suffix']) ? $options['_suffix'] : "";
        $_title = isset($options['_title']) ? $options['_title'] : "Filter";
        $_class = isset($options['_class']) ? $options['_class'] : "";
        $_btn_icon = isset($options['_icon']) ? $options['_icon'] : '<i class="ki-duotone ki-filter fs-6 text-white btn-active-color-primary me-1"><span class="path1"></span><span class="path2"></span></i>';
        $_display_text = isset($options['_text']) ? $options['_text'] : "Filter";
        $_data_options = isset($options['_data_options']) ? $options['_data_options'] : "";
        $_id = (strlen($_suffix) > 0) ? 'btn_filter' . $_suffix  : 'btn_filter';
        $_class = (strlen($_class) > 0) ? $_class  : 'btn_filter';
        $_data_key = isset($options['data_key']) ? $options['data_key'] : "";
        echo '<button data-' . $_data_key . ' title="' . $_title . '" type="button" class="btn btn-sm btn-dark btn-active-light-dark rounded-0 fw-bold ' . $_class . '" id="' . $_id . '" ' . $_data_options . ' >' . $_btn_icon . '<span class="ms-1">' . $_display_text . '</button>';
    }
}
///modify button
if (!function_exists('getDefaultButton')) {
    function getDefaultButton($options)
    {
        $_suffix = isset($options['_suffix']) ? $options['_suffix'] : "";
        $_title = isset($options['_title']) ? $options['_title'] : "Default";
        $_class = isset($options['_class']) ? $options['_class'] : "";
        $_btn_icon = isset($options['_icon']) ? $options['_icon'] : '<i class="fa-solid fa-book-open"></i>';
        $_display_text = isset($options['_text']) ? $options['_text'] : "Default";
        $_data_options = isset($options['_data_options']) ? $options['_data_options'] : "";
        $_data_key = isset($options['data_key']) ? $options['data_key'] : "";
        $_id = (strlen($_suffix) > 0) ? 'btn_default' . $_suffix  : 'btn_default';
        $_class = (strlen($_class) > 0) ? $_class  : 'btn-secondary btn-active-light-secondary btn_default';
        echo '<button data-' . $_data_key . ' title="' . $_title . '" type="button" class="' . $_class . '" id="' . $_id . '" ' . $_data_options . ' >' . $_btn_icon . '<span class="ms-1">' . $_display_text . '</button>';
    }
}
///modify button
if (!function_exists('getDefaultIconButton')) {
    function getDefaultIconButton($options)
    {
        echo '<button
                type="button"
                title="' . (isset($options['_title']) ? $options['_title'] : "Default") . '"
                data-action="' . (isset($options['data_action']) ? $options['data_action'] : "") . '"
                data-key="' . (isset($options['data_key']) ? $options['data_key'] : "") . '"
                data-group="' . (isset($options['data_group']) ? $options['data_group'] : 0) . '"
                data-status="' . (isset($options['data_status']) ? $options['data_status'] : 0) . '"
                data-auth-profile-id="' . (isset($options['data_auth_profile_id']) ? $options['data_auth_profile_id'] : 0) . '"
                data-owner-id="' . (isset($options['data_owner_id']) ? $options['data_owner_id'] : 0) . '"
                data-contract-id="' . (isset($options['data_contract_id']) ? $options['data_contract_id'] : 0) . '"
                data-service-id="' . (isset($options['data_service_id']) ? $options['data_service_id'] : 0) . '"
                data-client-profile-id="' . (isset($options['data_client_profile_id']) ? $options['data_client_profile_id'] : "") . '"
                id="' . (isset($options['suffix']) ? "btn" . $options['suffix'] : "btn_default") . '"
                class="btn ' . (isset($options['_class']) ? $options['_class'] : 'btn-secondary') . ' btn-icon btn-sm rounded-0 btn_default ' . (isset($options['suffix']) ? "btn" . $options['suffix'] : "") . '">
                    <i class=" fs-3 fa-solid ' . (isset($options['_icon']) ? $options['_icon'] : "fa-plus") . '"></i>
                </button>';
    }
}
///modify button
//if (!function_exists('getDefaultButton')) {
//    function getDefaultButton($options)
//    {
//        echo '<button
//                type="button"
//                title="' . (isset($options['_title']) ? $options['_title'] : "Default") . '"
//                data-action="' . (isset($options['data_action']) ? $options['data_action'] : "") . '"
//                data-key="' . (isset($options['data_key']) ? $options['data_key'] : "") . '"
//                id="' . (isset($options['suffix']) ? "btn" . $options['suffix'] : "btn_default") . '"
//                class="btn rounded-0 fw-bold btn-secondary btn-active-light-secondary btn_default ' . (isset($options['suffix']) ? "btn" . $options['suffix'] : "") . '">
//                    <i class="fa-solid ' . (isset($options['_icon']) ? $options['_icon'] : "fa-edit") . '"></i>
//                    <span class="ms-1">' . (isset($options['display_text']) ? $options['display_text'] : "Default") . '</span>
//                </button>';
//    }
//}
///confirmation icon button
if (!function_exists('getConfirmationIconButton')) {
    function getConfirmationIconButton($options)
    {
        echo '<button
                type="button"
                title="' . (isset($options['_title']) ? $options['_title'] : "Default") . '"
                data-action="' . (isset($options['data_action']) ? $options['data_action'] : "") . '"
                data-key="' . (isset($options['data_key']) ? $options['data_key'] : "") . '"
                id="' . (isset($options['suffix']) ? "btn_confirmation" . $options['suffix'] : "btn_confirmation") . '"
                class="' . (isset($options['_class']) ? $options['_class'] : "") . ' ' . (isset($options['suffix']) ? $options['suffix'] : "") . '">
                ' . (isset($options['_icon']) ? $options['_icon'] : "") . '
                </button>';
    }
}
///confirmation text button
if (!function_exists('getConfirmationTextButton')) {
    function getConfirmationTextButton($options)
    {
        $_suffix = isset($options['_suffix']) ? $options['_suffix'] : "";
        $_title = isset($options['_title']) ? $options['_title'] : "Confirmation";
        $_class = isset($options['_class']) ? $options['_class'] : "";
        $_btn_icon = isset($options['_icon']) ? $options['_icon'] : '<i class="fa fa-trash" aria-hidden="true"></i>';
        $_display_text = isset($options['_text']) ? $options['_text'] : "Button Confirmation";
        $_data_options = isset($options['_data_options']) ? $options['_data_options'] : "";
        $_data_key = isset($options['data_key']) ? $options['data_key'] : "";
        $_id = (strlen($_suffix) > 0) ? 'btn_confirmation' . $_suffix  : 'btn_confirmation';
        $_class = (strlen($_class) > 0) ? $_class  : 'btn_confirmation';
        echo '<button data-' . $_data_key . ' data-toggle="confirmation" title="' . $_title . '" type="button" class="btn btn-sm btn-primary btn-active-light-primary rounded-0 fw-bold ' . $_class . '" id="' . $_id . '" ' . $_data_options . ' >' . $_btn_icon . '<span class="ms-1">' . $_display_text . '</button>';
    }
}
//confirmation text button
if (!function_exists('getFileViewButton')) {
    function getFileViewButton($classname = "", $icon = '<i class="fa fa-eye p-0"></i>', $url = "javascript:void(0)", $extension = null, $name = 'File')
    {
        $class = (strlen($classname) > 0) ? 'rounded-0 fw-bold ' . $classname  : 'btn btn-icon btn-sm rounded-0 fw-bold btn-primary btn-active-light-primary';
        $icon = (!empty($icon)) ? $icon : 'View';
        if (!empty($extension) && isExcelFile($extension)) {
            $icon = ($icon == 'View') ? 'Download' : '<i class="fa fa-download p-0"></i>';
            echo '<a title="' . $name . '" href="' . $url . '" class="' . $class . '">' . $icon . '</a>';
        } else {
            echo '<a title="' . $name . '" href="' . $url . '" class="' . $class . '" data-fancybox data-caption="' . $name . '">' . $icon . '</a>';
        }
    }
}

if (!function_exists('getFileIconButton')) {
    function getFileIconButton($options)
    {
        echo '<a
                href = "' . $options['_url'] . '"
                title="' . (isset($options['_title']) ? $options['_title'] : "Default") . '"
                id="' . (isset($options['_suffix']) ? "link" . $options['_suffix'] : "link_file_view") . '"
                class="' . (isset($options['_class']) ? $options['_class'] : "") . ' ' . (isset($options['_suffix']) ? $options['_suffix'] : "") . '" data-fancybox data-caption="' . $options['_file_name'] . '"> <i class="
                ' . (isset($options['_icon']) ? $options['_icon'] : "") . '"></i>
                </a>';
    }
}
///create button
if (!function_exists('getCreateButton')) {
    function getCreateButton($options)
    {
        $_suffix = isset($options['_suffix']) ? $options['_suffix'] : "";
        $_title = isset($options['_title']) ? $options['_title'] : "Create";
        $_class = isset($options['_class']) ? $options['_class'] : "";
        $_btn_icon = isset($options['_icon']) ? $options['_icon'] : '<i class="ki-outline ki-plus fs-2"></i>';
        $_display_text = isset($options['_text']) ? $options['_text'] : "Create";
        $_data_options = isset($options['_data_options']) ? $options['_data_options'] : "";
        $_data_key = isset($options['data_key']) ? $options['data_key'] : "";
        $_id = (strlen($_suffix) > 0) ? 'btn_create' . $_suffix  : 'btn_create';
        $_class = (strlen($_class) > 0) ? $_class  : 'btn_create';
        echo '<button data-' . $_data_key . ' title="' . $_title . '" type="button" class="btn btn-sm btn-primary btn-active-light-primary rounded-0 fw-bold ' . $_class . '" id="' . $_id . '" ' . $_data_options . ' >' . $_btn_icon . '<span class="ms-1">' . $_display_text . '</button>';
    }
}
if (!function_exists('isExcelFile')) {
    function isExcelFile($extension)
    {
        $excelExtensions = array('xlsx', 'xlsb', 'xlsm', 'xls', 'pptx', 'ppt', 'doc', 'docx', 'sheet', 'csv', 'odt');
        return in_array(strtolower($extension), $excelExtensions);
    }
}

if (!function_exists('getValueFromOptionKey')) {
    function getValueFromOptionKey($data, $key)
    {
        $array = explode('_', $data);
        $result = [];
        if (count($array) === 1) {
            return $data;
        }
        foreach ($array as $part) {
            $keyValuePair = explode(':', $part);
            if (count($keyValuePair) === 2) {
                $result[$keyValuePair[0]] = $keyValuePair[1];
            }
        }
        if (isset($result[$key])) {
            return $result[$key];
        } else {
            return 0;
        }
    }

    if (!function_exists('addressToJson')) {
        function addressToJson($data)
        {
            $address = [];
            if (isset($data['address_line_1'])) {
                $address['address_line_1'] = $data['address_line_1'];
            }
            if (isset($data['address_line_2'])) {
                $address['address_line_2'] = $data['address_line_1'];
            }
            return json_encode($address);
        }
    }
    if (!function_exists('displayAddress')) {
        function displayAddress($data)
        {
            $parts = [];
            if ($data['info'] !== null) {
                $parts = array_filter(array_merge($data['info'], ['area' => wwec($data['area']), 'post_code' => wwec($data['post_code'])]));
            } else {
                $parts[] = wwec($data['area']);
                $parts[] = wwec($data['post_code']);
                $parts = array_filter($parts);
            }
            return implode(', ', $parts);
        }
    }

    if (!function_exists('customGenerateToken')) {
        function customGenerateToken($custom_payload = [], $encryptable = '')
        {
            try {
                $token = '';
                $encrypt_string = makeEncryptedData($encryptable);
                $custom_payload = $custom_payload + ['enctypt_data' => $encrypt_string];
                $payload = JWTFactory::sub('token')->data($custom_payload)->make();
                $token = JWTAuth::encode($payload)->get();
                return $token;
            } catch (\Exception $e) {
                return 'Error generating token: ' . $e->getMessage();
            }
        }
    }

    if (!function_exists('customDecodeToken')) {
        function customDecodeToken($token = '')
        {
            $payload = '';
            $tokenParts = explode(".", $token);
            $tokenPayload = base64_decode($tokenParts[1]);
            $payload = json_decode($tokenPayload, true);
            if (isset($payload['data']['enctypt_data'])) {
                $dectypt_sting = getDecryptedData($payload['data']['enctypt_data']);
                $payload['data']['enctypt_data'] = $dectypt_sting;
            }
            return $payload;
        }
    }
}

if (!function_exists('makeEncryptedData')) {
    function makeEncryptedData($string = '', $options = [])
    {
        try {
            $cipher = !empty($options['method']) ? $options['method'] : 'AES-128-CBC';
            $key = !empty($options['key']) ? $options['key'] : SECRET_KEY;
            $ivlen = openssl_cipher_iv_length($cipher);
            $iv = openssl_random_pseudo_bytes($ivlen);
            $ciphertext_raw = openssl_encrypt($string, $cipher, $key, $options = OPENSSL_RAW_DATA, $iv);
            $hmac = hash_hmac('sha256', $ciphertext_raw, $key, $as_binary = true);
            $ciphertext = base64_encode($iv . $hmac . $ciphertext_raw);
            return $ciphertext;
        } catch (\Exception $ex) {
        }
        return '';
    }
}
if (!function_exists('getDecryptedData')) {
    function getDecryptedData($encrypt_string = '', $options = [])
    {
        try {
            $cipher = !empty($options['method']) ? $options['method'] : 'AES-128-CBC';
            $key = !empty($options['key']) ? $options['key'] : SECRET_KEY;
            $c = base64_decode($encrypt_string);
            $ivlen = openssl_cipher_iv_length($cipher);
            $iv = substr($c, 0, $ivlen);
            $hmac = substr($c, $ivlen, $sha2len = 32);
            $ciphertext_raw = substr($c, $ivlen + $sha2len);
            $original_plaintext = openssl_decrypt($ciphertext_raw, $cipher, $key, OPENSSL_RAW_DATA, $iv);
            $calcmac = hash_hmac('sha256', $ciphertext_raw, $key, true);
            if (hash_equals($hmac, $calcmac)) {
                return $original_plaintext;
            }
        } catch (\Exception $ex) {
        }

        return '';
    }
}

if (!function_exists('getBrowser')) {
    function getBrowser($user_agent)
    {
        if (preg_match('/MSIE/i', $user_agent) && !preg_match('/Opera/i', $user_agent)) {
            $bname = 'Internet Explorer';
            $ub = "mise";
        } elseif (preg_match('/Firefox/i', $user_agent)) {
            $bname = 'Mozilla Firefox';
            $ub = "firefox";
        } elseif (preg_match('/Chrome/i', $user_agent)) {
            $bname = 'Google Chrome';
            $ub = "chrome";
        } elseif (preg_match('/Safari/i', $user_agent)) {
            $bname = 'Apple Safari';
            $ub = "safari";
        } elseif (preg_match('/Opera/i', $user_agent)) {
            $bname = 'Opera';
            $ub = "opera";
        } elseif (preg_match('/Netscape/i', $user_agent)) {
            $bname = 'Netscape';
            $ub = "netscape";
        } else {
            $bname = 'Others';
            $ub = "others";
        }
        return $ub;
    }
}

if (!function_exists('isPast')) {
    function isPast($time)
    {
        return (strtotime($time) < time());
    }
}

if (!function_exists('isFuture')) {
    function isFuture($time)
    {
        return (strtotime($time) > time());
    }
}

if (!function_exists('formatDateWithSuffix')) {
    function formatDateWithSuffix($date) {
        $day = date('j', strtotime($date));
        $suffix = '';

        if ($day % 10 == 1 && $day != 11) {
            $suffix = 'st';
        } elseif ($day % 10 == 2 && $day != 12) {
            $suffix = 'nd';
        } elseif ($day % 10 == 3 && $day != 13) {
            $suffix = 'rd';
        } else {
            $suffix = 'th';
        }

        return date('j', strtotime($date)) . $suffix . ' ' . date('F Y', strtotime($date));
    }
}

