"use strict";
var BaseAppAjax = function () {
    var jqxhr;
    return {
        errorPrompt: function (eText) {
            Swal.fire({
                icon: 'error',
                position: 'top-end',
                confirmButtonColor: '#009ef7',
                confirmButtonText: 'Close',
                title: 'Oops...',
                text: eText,
                footer: '<a href="/">Support Center</a>'
            })
        },
        ajaxStart: function (elem) {
            setBtnLoader($(elem));
        },
        ajaxStop: function (elem) {
            resetBtnLoader($(elem));
        },
        formSubmit: function (target_elem, success_callback, error_callback) {
            $(target_elem).find('.invalid-feedback').remove();
            var myform = $(target_elem);
            var disabled = myform.find(':input:disabled').removeAttr('disabled');
            var serialized_data = myform.serialize();
            disabled.attr('disabled','disabled');
            jqxhr = $.post($(target_elem).attr('action'), serialized_data, function (jqxhr) {
                success_callback(jqxhr);
            }, 'json')
                .done(function () { })
                .fail(function (jqxhr) {
                    if (jqxhr.status == 404) {
                        BaseAppAjax.errorPrompt('The requested URL was not found on this server.');
                    }
                    if (jqxhr.status == 500) {
                        var response = jqxhr.responseJSON;
                        if (isJSON(response))
                            BaseAppAjax.errorPrompt(response.message);
                        else if (jqxhr.statusText.length > 0)
                            BaseAppAjax.errorPrompt(jqxhr.statusText);
                        else
                            BaseAppAjax.errorPrompt('Sorry, looks like there are some errors detected, please try again.');
                    }
                    if (jqxhr.status == 422) {
                        var response = jqxhr.responseJSON;
                        if (isJSON(response))
                            BaseAppAjax.errorPrompt(response.message);
                        $.each(response.errors, function (name, messages) {
                            $('[name="' + name + '"]').parent('div').append('<div class="fv-plugins-message-container invalid-feedback">' + messages[0] + '</div>')
                        })
                    }
                    error_callback(jqxhr);
                })
                .always(function () { });
        },
        ajaxDeleteData: function (csrf_token, target_elem, data, success_callback) {
            //target_element = button
            var data_url = $(target_elem).data('action');
            var data_id = $(target_elem).data('key');
            data_url = data_url.replace(":id", data_id);
            data["_token"] = csrf_token;
            $.ajax({
                method: "DELETE",
                url: data_url,
                datatype: 'json',
                data:data,
                beforeSend: function (jqxhr) {
                    BaseAppAjax.ajaxStart(target_elem);
                },
                error: function (jqxhr, textStatus, errorThrown) {
                    BaseAppAjax.ajaxStop(target_elem);
                    BaseAppAjax.errorPrompt(jqxhr.statusText);
                },
                success: function (result) {
                    BaseAppAjax.ajaxStop(target_elem);
                    if (result.status && result.status == 'success') {
                        toastr.success(result.message);
                        success_callback(result);
                    }
                    else {
                        toastr.error(result.message);
                    }
                }
            });
        },
        ajaxGetData: function (csrf_token, target_elem, data_url, req_data, success_callback, data_type = 'json') {
            if (typeof req_data === 'object') {
                var data = req_data;
            } else {
                var data = {};
                data_url = data_url.replace(":id", req_data);
            }
            $.ajax({
                method: "GET",
                url: data_url,
                datatype: data_type,
                data:data,
                beforeSend: function (jqXHR) {
                    BaseAppAjax.ajaxStart(target_elem);
                },
                error: function (jqXHR, textStatus, errorThrown) {
                    BaseAppAjax.errorPrompt(jqXHR.statusText);
                },
                success: function (result) {
                    BaseAppAjax.ajaxStop(target_elem);
                    if (result.data) {
                        success_callback(result.data);
                    } else {
                        success_callback(result);
                    }
                }
            });
        },
        ajaxSelect2AutoCompleteSearching: function (options) {
            return {
                ajax: {
                    url: options.url,
                    dataType: 'json',
                    delay: 250,
                    data: function (params) {
                        return {
                            search_string: params.term,
                            page: params.page
                        };
                    },
                    processResults: function (data) {
                        return {
                            results: $.map(data.data, function (value, key) {
                                return { id: key, text: value };
                            })
                        };
                    },
                    cache: true
                },
                autocomplete: true,
                minimumInputLength: options.minimumInputLength || 4
            };
        },
        ajaxPostData: function (csrf_token, target_elem, data, success_callback) {
            //target_element = button
            var data_url = $(target_elem).data('action');
            var data_id = $(target_elem).data('key');
            if(data_id){
                data_url = data_url.replace(":id", data_id);
            }
            data["_token"] = csrf_token;
            $.ajax({
                method: "POST",
                url: data_url,
                datatype: 'json',
                data:data,
                beforeSend: function (jqxhr) {
                    BaseAppAjax.ajaxStart(target_elem);
                },
                error: function (jqxhr, textStatus, errorThrown) {
                    if (jqxhr.status == 404) {
                        BaseAppAjax.errorPrompt('The requested URL was not found on this server.');
                    }
                    if (jqxhr.status == 500) {
                        var response = jqxhr.responseJSON;
                        if (isJSON(response))
                            BaseAppAjax.errorPrompt(response.message);
                        else if (jqxhr.statusText.length > 0)
                            BaseAppAjax.errorPrompt(jqxhr.statusText);
                        else
                            BaseAppAjax.errorPrompt('Sorry, looks like there are some errors detected, please try again.');
                    }
                    BaseAppAjax.ajaxStop(target_elem);
                },
                success: function (result) {
                    BaseAppAjax.ajaxStop(target_elem);
                    success_callback(result);
                }
            });
        },
        ajaxLoadCascadingDropdownData: function (filter_options, target_elem, url, current_select_value = '', success_callback) {
            target_elem.empty();
            $.ajax({
                url: url,
                method: 'GET',
                data: filter_options,
                beforeSend: function (jqXHR) {
                    BaseAppAjax.ajaxStart(target_elem);
                },
                success: function (response) {
                    BaseAppAjax.ajaxStop(target_elem);
                    if (response.status === 'success') {
                        target_elem.append($('<option>', {
                            value: '0',
                            text: '---Select---'
                        }));
                        $.each(response.data, function (key, value) {
                            target_elem.append($('<option>', {
                                value: key,
                                text: value
                            }));
                        });
                        // Set the selected option
                        if (current_select_value !== '') {
                            target_elem.val(current_select_value);
                        } else {
                            target_elem.val('0');
                        }
                        target_elem.trigger('change');
                        success_callback(response);
                    }
                },
                error: function (error) {
                    console.error(error);
                }
            });
        },
        ajaxLoadView: function (src, url, data, container_id, callback) {
            $.ajax({
                method: "GET",
                url: url,
                datatype: 'html',
                data: data,
                beforeSend: function (jqxhr) {
                    BaseAppAjax.ajaxStart(container_id);
                },
                error: function (jqxhr, textStatus, errorThrown) {
                    BaseAppAjax.errorPrompt(jqxhr.statusText);
                },
                success: function (result) {
                    BaseAppAjax.ajaxStop(container_id);
                    $(container_id).html(result);
                    initiateFormControl();
                    datePickerUiReInit();
                    if (typeof callback === 'function') {
                        callback(result);
                    }
                }
            });
        },
        init: function () {

        },
    }
}();
KTUtil.onDOMContentLoaded((function () {
    BaseAppAjax.init()
}));
