var Holidays = (function () {
    var initTable = function (list_url) {
        base_datatable.table_id = "#holidays_list_table";
        base_datatable.table_ajax_url = list_url;
        (base_datatable.columns = [
            { data: "sl" },
            { data: "id" },
            { data: "holiday_type" },
            { data: "date" },
            { data: "year" },
            { data: "action", className: 'text-center' },
        ]),
            base_datatable.reloadTable();
    };
    var is_data_validated = function () {
        // Check if the required fields are filled
        var holidayType = $('select[name="holiday_type"]').val();
        var holidayDate = $('input[name="date"]').val();
        var holidayYear = $('select[name="year"]').val();
        // Validate each field
        if (holidayType === "") {
            toastr.error("Please select the holiday type.");
            return false;
        }

        if (holidayDate.trim() === "") {
            toastr.error("Please select the date of the holiday.");
            return false;
        }
        var currentDate = new Date(); // Get the current date
        var selectedDate = new Date(holidayDate); // Convert the selected date to a Date object

        if (selectedDate < currentDate) {
            toastr.error("Please select a future date for the holiday.");
            return false;
        }
        if (holidayYear === "" || isNaN(holidayYear)) {
            toastr.error("Please select a valid year.");
            return false;
        }
        return true;
    };
    // Public methods
    return {
        deleteHoliday: function (selector) {
            // selector : "#btn_delete"
            BaseAppAjax.ajaxDeleteData(
                Holidays.csrf_token,
                selector,
                { _id: $(selector).data("key") },
                function () {
                    setTimeout(function () {
                        initTable(Holidays.list_url)
                    }, 500);
                },
                function () { }
            );
        },
        init: function (
            csrf_token,
            list_url,
            create_url,
            // view_url,
            edit_url,
            delete_url
        ) {
            // Holidays.view_url = view_url;
            Holidays.edit_url = edit_url;
            Holidays.delete_url = delete_url;
            Holidays.list_url = list_url;
            (Holidays.csrf_token = csrf_token), initTable(list_url, create_url);

            $(document)
                .off("click", ".create-btn")
                .on("click", ".create-btn", function (e) {
                    e.preventDefault();
                    var data_url = create_url;
                    BaseAppAjax.ajaxLoadView(
                        $(this),
                        data_url,
                        {},
                        "#kt_app_main"
                    );
                });
            $(document)
                .off("click", "#btn_edit_holiday")
                .on("click", "#btn_edit_holiday", function (e) {
                    e.preventDefault();
                    var data_url = $(this).data("action");
                    var data_id = $(this).data("key");
                    data_url = data_url.replace(":id", data_id);
                    BaseAppAjax.ajaxLoadView(
                        $(this),
                        data_url,
                        { type: data_id },
                        "#kt_app_main"
                    );
                });
            $(document)
                .off("click", ".btn_submit")
                .on("click", ".btn_submit", function (e) {
                    e.preventDefault();
                    if (!is_data_validated()) {
                        return false;
                    }
                    var _btn = $(this);
                    setBtnLoader(_btn);
                    BaseAppAjax.formSubmit(
                        "#form_holiday",
                        function (response) {
                            resetBtnLoader(_btn);
                            setTimeout(function () {
                                window.location.reload();
                            }, 1000);
                            // Display success message
                            toastr.success(response.message);
                            // Perform any necessary actions on success
                        },
                        function () {
                            resetBtnLoader(_btn);
                        }
                    );
                });
            $(document)
                .off("click", ".btn_reset")
                .on("click", ".btn_reset", function (e) {
                    $("#form_holiday")[0].reset();
                });
            $(document)
                .off("click", ".btn_delete")
                .on("click", ".btn_delete", function (e) {
                    e.preventDefault();
                    _options = { status: "warning" };
                    var _btn_delete = this;
                    initConfirmationDialog(
                        "Are you sure to delete?",
                        function () {
                            Holidays.deleteHoliday(_btn_delete);
                        },
                        function () { },
                        _options
                    );
                });
        },
    };
})();
function getFilterOptions() {
    return [];
}
function renderActionItems(row, data) {
    var _edit = ACTIONBUTTON.getEditIconButton({
        suffix: "_holiday",
        title: "Edit",
        data_key: row["id"],
        data_action: Holidays.edit_url,
    });
    var _delete = ACTIONBUTTON.getDeleteIconButton({
        suffix: "_holiday",
        title: "Delete",
        data_key: row["id"],
        data_action: Holidays.delete_url,
    });
    var action_items =
        `<div class="btn-group">` + `` + _edit + `` + _delete + `</div>`;
    return action_items;
}
