"use strict";
document.addEventListener("DOMContentLoaded", function () {
    const voiceCommandStart = document.getElementById('voice_command_start');
    const subtitleContainer = document.getElementById('subtitle_container');
    const microphoneIcon = document.getElementById('fa-microphone-lines');

    let isRecognitionActive = false;
    let recognition;

    function initSpeechRecognition() {
        try {
            const SpeechRecognition = window.SpeechRecognition || window.webkitSpeechRecognition;
            recognition = new SpeechRecognition();
            recognition.lang = 'en-US';
            recognition.interimResults = false;
            recognition.continuous = true;

            recognition.onresult = function (event) {
                const transcript = event.results[event.resultIndex][0].transcript
                    .replace(/^\s+/g, '')
                    .replace(/\./g, '')
                    .toLowerCase();
                subtitleContainer.innerText = 'Voice Command: ' + transcript;
                VoiceResponse.init(transcript);
                setTimeout(function () {
                    subtitleContainer.innerText = '';
                }, 5000);
            };

            recognition.onend = function () {
                microphoneIcon.classList.remove('fa-microphone-lines');
                microphoneIcon.classList.add('fa-microphone-lines-slash');
                subtitleContainer.innerText = '';
            };

            recognition.onerror = function (event) {
                console.error('Speech recognition error:', event.error);
                console.error('Error message:', event.error.message);
            };

            voiceCommandStart.addEventListener('click', toggleRecognition);
        } catch (error) {
            console.error('Error initializing SpeechRecognition:', error);
        }
    }

    function toggleRecognition() {
        if (isRecognitionActive) {
            recognition.stop();
            isRecognitionActive = false;
            microphoneIcon.classList.remove('fa-microphone-lines');
            microphoneIcon.classList.add('fa-microphone-lines-slash');
            localStorage.setItem('voice', false);
        } else {
            recognition.start();
            isRecognitionActive = true;
            microphoneIcon.classList.remove('fa-microphone-lines-slash');
            microphoneIcon.classList.add('fa-microphone-lines');
            localStorage.setItem('voice', true);
        }
    }

    if ('SpeechRecognition' in window || 'webkitSpeechRecognition' in window) {
        initSpeechRecognition();
    } else {
        console.error('Speech recognition is not supported in this browser.');
    }

    const storedVoice = localStorage.getItem('voice');
    if (storedVoice && JSON.parse(storedVoice)) {
        toggleRecognition();
    }
});

var VoiceResponse = function () {
    return {
        init: function (command) {
            var pre_commands = [];
            if (command.startsWith("send mail to")) {
                var parts = command.split('send mail to');
                var search_string = parts[1].trim();
                $('#btn_send_notification').trigger('click');
                var data = setReceipientInformation(search_string);
                data.then(function (result) {
                    processSendMail(result);
                }).catch(function (error) {
                    console.error("Error:", error);
                });
            } else if (command.startsWith("personal profile of")) {
                var parts = command.split('personal profile of');
                var search_string = parts[1].trim();
                var data = setReceipientInformation(search_string);
                data.then(function (result) {
                    processProfileView(result);
                }).catch(function (error) {
                    console.error("Error:", error);
                });
            } else {
                pre_commands = [{
                    command: 'command start',
                    path: 'voice_command_start',
                    action: 'click'
                }, {
                    command: 'command stop',
                    path: 'voice_command_start',
                    action: 'click'
                }, {
                    command: 'go to home',
                    path: '/',
                    action: 'redirect'
                }, {
                    command: 'go to dashboard',
                    path: '/',
                    action: 'redirect'
                }, {
                    command: 'go to admin dashboard',
                    path: '/',
                    action: 'redirect'
                }, {
                    command: 'go to colleague dashboard',
                    path: '/',
                    action: 'redirect'
                }, {
                    command: 'go to client dashboard',
                    path: '/',
                    action: 'redirect'
                }, {
                    command: 'go to manager dashboard',
                    path: '/',
                    action: 'redirect'
                }, {
                    command: 'go to farm setup',
                    path: '/accounting/firm_profile/view',
                    action: 'redirect'
                }, {
                    command: 'go to from setup',
                    path: '/accounting/firm_profile/view',
                    action: 'redirect'
                }, {
                    command: 'go to firm setup',
                    path: '/accounting/firm_profile/view',
                    action: 'redirect'
                }, {
                    command: 'go to team overview',
                    path: '/team',
                    action: 'redirect'
                }, {
                    command: 'go to team new member',
                    path: '/team_setup?key=member',
                    action: 'redirect'
                }, {
                    command: 'go to manager list',
                    path: '/managers',
                    action: 'redirect'
                }, {
                    command: 'go to colleague list',
                    path: '/colleagues',
                    action: 'redirect'
                }, {
                    command: 'go to colleague and manager mapping',
                    path: '/team_mapping/0',
                    action: 'redirect'
                }, {
                    command: 'go to colleague manager mapping',
                    path: '/team_mapping/0',
                    action: 'redirect'
                }, {
                    command: 'go to client overview',
                    path: '/overview/clients',
                    action: 'redirect'
                }, {
                    command: 'go to register client',
                    path: '/clients/setup',
                    action: 'redirect'
                }, {
                    command: 'go to client register',
                    path: '/clients/setup',
                    action: 'redirect'
                }, {
                    command: 'go to bulk register',
                    path: '/clients/bulk/setup',
                    action: 'redirect'
                }, {
                    command: 'go to bulk client register',
                    path: '/clients/bulk/setup',
                    action: 'redirect'
                }, {
                    command: 'go to pre registered client',
                    path: '/client/pre-register/view',
                    action: 'redirect'
                }, {
                    command: 'go to preregistered client',
                    path: '/client/pre-register/view',
                    action: 'redirect'
                }, {
                    command: 'go to preregistered clients',
                    path: '/client/pre-register/view',
                    action: 'redirect'
                }, {
                    command: 'go to pre register client',
                    path: '/client/pre-register/view',
                    action: 'redirect'
                }, {
                    command: 'go to pre registered clients',
                    path: '/client/pre-register/view',
                    action: 'redirect'
                }, {
                    command: 'go to registered client',
                    path: '/clients',
                    action: 'redirect'
                }, {
                    command: 'go to clients',
                    path: '/clients',
                    action: 'redirect'
                }, {
                    command: 'go to registered clients',
                    path: '/clients',
                    action: 'redirect'
                }, {
                    command: 'go to client user',
                    path: '/team_setup?key=client',
                    action: 'redirect'
                }, {
                    command: 'go to client mapping',
                    path: '/mapping/client',
                    action: 'redirect'
                }, {
                    command: 'go to clients mapping',
                    path: '/clients-mapp',
                    action: 'redirect'
                }, {
                    command: 'go to special engagement letter',
                    path: '/',
                    action: 'redirect'
                }, {
                    command: 'go to mailbox',
                    path: '/',
                    action: 'redirect'
                }, {
                    command: 'go to mail box',
                    path: '/',
                    action: 'redirect'
                }, {
                    command: 'go to contract documents',
                    path: '/contracts/document',
                    action: 'redirect'
                }, {
                    command: 'go to contract document',
                    path: '/contracts/document',
                    action: 'redirect'
                }, {
                    command: 'go to team management',
                    path: 'team_management',
                    action: 'click'
                }, {
                    command: 'go to client management',
                    path: 'client_management',
                    action: 'click'
                }, {
                    command: 'go to payment management',
                    path: 'payment_management',
                    action: 'click'
                }, {
                    command: 'go to ledger',
                    path: 'ledger',
                    action: 'click'
                }, {
                    command: 'go to ledger book',
                    path: '/ledger',
                    action: 'redirect'
                }, {
                    command: 'go to ledger book detail',
                    path: '/ledger_details',
                    action: 'redirect'
                }, {
                    command: 'go to ledger book details',
                    path: '/ledger_details',
                    action: 'redirect'
                }, {
                    command: 'go to invoice',
                    path: 'invoice',
                    action: 'click'
                }, {
                    command: 'go to generate invoice',
                    path: '/invoice/setup',
                    action: 'redirect'
                }, {
                    command: 'go to invoice list',
                    path: '/invoice',
                    action: 'redirect'
                }, {
                    command: 'go to list of invoice',
                    path: '/invoice',
                    action: 'redirect'
                }, {
                    command: 'go to payment',
                    path: 'payment',
                    action: 'click'
                }, {
                    command: 'go to direct debit verification',
                    path: '/direct_debit',
                    action: 'redirect'
                }, {
                    command: 'go to make payment',
                    path: '/deposits/setup',
                    action: 'redirect'
                }, {
                    command: 'go to deposit list',
                    path: '/deposits',
                    action: 'redirect'
                }, {
                    command: 'go to file management',
                    path: 'file_management',
                    action: 'click'
                }, {
                    command: 'go to file overview',
                    path: '/documents',
                    action: 'redirect'
                }, {
                    command: 'go to document setup',
                    path: '/documents/upload',
                    action: 'redirect'
                }, {
                    command: 'go to task management',
                    path: 'task_management',
                    action: 'click'
                }, {
                    command: 'go to task',
                    path: '/tasks',
                    action: 'redirect'
                }, {
                    command: 'go to task note',
                    path: '/task_notes',
                    action: 'redirect'
                }, {
                    command: 'go to mail box settings',
                    path: 'mail_box_settings',
                    action: 'click'
                }, {
                    command: 'go to mailbox settings',
                    path: 'mail_box_settings',
                    action: 'click'
                }, {
                    command: 'go to mail overview',
                    path: '/email/overview',
                    action: 'redirect'
                }, {
                    command: 'go to mailbox overview',
                    path: '/email/overview',
                    action: 'redirect'
                }, {
                    command: 'go to mail box overview',
                    path: '/email/overview',
                    action: 'redirect'
                }, {
                    command: 'go to mail setup',
                    path: '/email/templates',
                    action: 'redirect'
                }, {
                    command: 'go to mail outbox',
                    path: '/mail-box?type=outbox',
                    action: 'redirect'
                }, {
                    command: 'go to mail inbox',
                    path: '/mail-box?type=inbox',
                    action: 'redirect'
                }, {
                    command: 'send mail',
                    path: 'btn_send_notification',
                    action: 'click'
                }, {
                    command: 'go to service settings',
                    path: 'service_settings',
                    action: 'click'
                }, {
                    command: 'go to service overview',
                    path: '/service/overview',
                    action: 'redirect'
                }, {
                    command: 'go to service list',
                    path: '/services',
                    action: 'redirect'
                }, {
                    command: 'go to map service and document',
                    path: '/service-document/map',
                    action: 'redirect'
                }, {
                    command: 'go to map service and state',
                    path: '/service-status/map',
                    action: 'redirect'
                }, {
                    command: 'go to document list',
                    path: '/x-documents',
                    action: 'redirect'
                }, {
                    command: 'go to service state list',
                    path: '/service-status',
                    action: 'redirect'
                }, {
                    command: 'go to service state',
                    path: '/service-status',
                    action: 'redirect'
                }, {
                    command: 'go to service task',
                    path: '/service_tasks',
                    action: 'redirect'
                }, {
                    command: 'go to notification settings',
                    path: 'notification_settings',
                    action: 'click'
                }, {
                    command: 'go to notification type',
                    path: '/notification-type',
                    action: 'redirect'
                }, {
                    command: 'go to notification event',
                    path: '/notification-event',
                    action: 'redirect'
                }, {
                    command: 'go to application settings',
                    path: 'application_settings',
                    action: 'click'
                }, {
                    command: 'go to application overview',
                    path: '/',
                    action: 'redirect'
                }, {
                    command: 'go to business type',
                    path: '/business_types',
                    action: 'redirect'
                }, {
                    command: 'go to user role',
                    path: '/user_roles',
                    action: 'redirect'
                }, {
                    command: 'go to application logs',
                    path: '/logs',
                    action: 'redirect'
                }, {
                    command: 'go to holiday list',
                    path: '/holiday-list',
                    action: 'redirect'
                }, {
                    command: 'go to dispatch job',
                    path: '/job/dispatch',
                    action: 'redirect'
                }, {
                    command: 'close right panel',
                    path: 'kt_overlay_panel_close',
                    action: 'click'
                }, {
                    command: 'send email cancel',
                    path: 'kt_overlay_panel_close',
                    action: 'click'
                }, {
                    command: 'user notify',
                    path: 'btn_send_notification',
                    action: 'click'
                }, {
                    command: 'notify user',
                    path: 'btn_send_notification',
                    action: 'click'
                }, {
                    command: 'trigger send mail',
                    path: 'btn_submit_notification',
                    action: 'click'
                }, {
                    command: 'trigger send email',
                    path: 'btn_submit_notification',
                    action: 'click'
                }, {
                    command: 'trigger send e-mail',
                    path: 'btn_submit_notification',
                    action: 'click'
                }, {
                    command: 'allow admin access',
                    path: 'btn_setup_admin',
                    action: 'click'
                }, {
                    command: 'profile in active',
                    path: 'btn_update_status',
                    action: 'click'
                }, {
                    command: 'profile inactive',
                    path: 'btn_update_status',
                    action: 'click'
                }, {
                    command: 'profile active',
                    path: 'btn_update_status',
                    action: 'click'
                }, {
                    command: 'push notification',
                    path: 'push',
                    action: 'radio'
                }, {
                    command: 'post notification',
                    path: 'push',
                    action: 'radio'
                }, {
                    command: 'send email',
                    path: 'email',
                    action: 'radio'
                }, {
                    command: 'send e-mail',
                    path: 'email',
                    action: 'radio'
                }, {
                    command: 'send sms',
                    path: 'sms',
                    action: 'radio'
                }, {
                    command: 'send an sms',
                    path: 'sms',
                    action: 'radio'
                }, {
                    command: 'default template',
                    path: 'email_template_id',
                    action: 'change',
                    value: 1
                }, {
                    command: 'reset password',
                    path: 'email_template_id',
                    action: 'change',
                    value: 2
                }, {
                    command: 'engagement letter',
                    path: 'email_template_id',
                    action: 'change',
                    value: 3
                }, {
                    command: '64-8 letter',
                    path: 'email_template_id',
                    action: 'change',
                    value: 4
                }, {
                    command: '64 dash letter',
                    path: 'email_template_id',
                    action: 'change',
                    value: 4
                }, {
                    command: 'subject',
                    path: 'compose_subject',
                    action: 'focus',
                }, {
                    command: 'mail body',
                    path: 'email_template_body',
                    action: 'focus',
                }, {
                    command: 'e-mail body',
                    path: 'email_template_body',
                    action: 'focus',
                }, {
                    command: 'email body',
                    path: 'email_template_body',
                    action: 'focus',
                }, {
                    command: 'upload files',
                    path: 'kt_inbox_reply_attachments_select',
                    action: 'click',
                }, {
                    command: 'upload file',
                    path: 'kt_inbox_reply_attachments_select',
                    action: 'click',
                }, {
                    command: 'title',
                    path: 'notify_title',
                    action: 'focus',
                }, {
                    command: 'message',
                    path: 'notify_message',
                    action: 'focus',
                }, {
                    command: 'mobile number',
                    path: 'mobile_number',
                    action: 'focus',
                }, {
                    command: 'sms content',
                    path: 'sms_content',
                    action: 'focus',
                }, {
                    command: 'receiver email',
                    path: 'to_email',
                    action: 'focus',
                }, {
                    command: 'receiver e-mail',
                    path: 'to_email',
                    action: 'focus',
                }, {
                    command: 'recipient email',
                    path: 'to_email',
                    action: 'focus',
                }, {
                    command: 'recipient e-mail',
                    path: 'to_email',
                    action: 'focus',
                }, {
                    command: 'stop',
                    path: 'to_email',
                    action: 'blur',
                }, {
                    command: 'finish',
                    path: 'to_email',
                    action: 'blur',
                }, {
                    command: 'go to voice command',
                    path: '/command/voice',
                    action: 'redirect'
                }
                ];
                for (const pre_command of pre_commands) {
                    if (command.startsWith(pre_command.command) && command === pre_command.command) {
                        switch (pre_command.action) {
                            case 'redirect':
                                window.location.replace(pre_command.path);
                                break;
                            case 'click':
                                $('#' + pre_command.path).trigger('click');
                                break;
                            case 'radio':
                                $('input[value="' + pre_command.path + '"]').prop('checked', true).trigger('change');
                                break;
                            case 'change':
                                $('#' + pre_command.path).val(pre_command.value).trigger('change');
                                break;
                            case 'focus':
                                $('#' + pre_command.path).focus();
                                break;
                            case 'blur':
                                $(document.activeElement).blur();
                                break;
                        }
                        return;
                    }
                }
                setTranscriptAtCursor(command);
            }
        },
    };
}();

function setTranscriptAtCursor(command) {
    const focusedElement = $(document.activeElement);
    if (focusedElement.is('input') || focusedElement.is('textarea')) {
        if (focusedElement.attr('type') === 'number') {
            command = command.replace(/[^0-9]/g, '');
        }
        focusedElement.val(command);
    } else if (focusedElement.is('#email_template_body_ifr')) {
        tinymce.activeEditor.execCommand('mceInsertContent', false, command);
    }
}

function setReceipientInformation(search_string) {
    return new Promise(function (resolve, reject) {
        BaseAppAjax.ajaxGetData('', '', '/user/email/get', { search_string: search_string }, function (data) {
            resolve(data);
        });
    });
}

function processSendMail(data) {
    setTimeout(() => {
        $('#to_email').val(data.email);
        $('#profile_id').val(data.id);
        $('#email_template_id').val(3).trigger('change');
    }, 2000);
}

function processProfileView(data) {
    if ($('#btn_view_profile').length > 0 || $('#btn_view_manager').length > 0 || $('#btn_view_colleague').length > 0) {
        $('.btn_view_profile_' + data.id + '').trigger('click');
    } else {
        window.location.replace('/team/profile/' + data.id);
    }
}
