import requests
from bs4 import BeautifulSoup
from sqlalchemy import create_engine, Table, MetaData, select, insert, update
import datetime
import re

# Database connection
engine = create_engine("mysql+pymysql://root@localhost/adverse_media_db")
metadata = MetaData()
news_table = Table('news', metadata, autoload_with=engine)

# News sources and keywords
news_urls = [
    "https://www.prothomalo.com/",
    # Add other sources as needed
]
keywords = ["প্রতারণা", "দুর্নীতি", "ঘুষ", "চাঁদাবাজি"]  # Bangla keywords for adverse topics

def fetch_news_data(url):
    response = requests.get(url)
    if response.status_code != 200:
        return None
    soup = BeautifulSoup(response.text, 'html.parser')

    # Adjust selector here based on actual page structure
    news_items = soup.find_all("div", class_="news_item_content")  # Update if class names differ per site
    news_data_list = []

    for item in news_items:
        title_tag = item.find("h3",class_="tilte-no-link-parent")
        print("News items found:", title_tag)

        detail_link_tag = item.find("a")

        # Check if both title and detail link are present
        if not title_tag or not detail_link_tag:
            continue  # Skip this item if required elements are missing

        title = title_tag.get_text(strip=True)
        detail_link = detail_link_tag.get("href")

        publish_date = datetime.datetime.now()  # Placeholder until actual date parsing is implemented

        # Attempt to fetch content from the detail link if it exists
        try:
            detail_response = requests.get(detail_link)
            if detail_response.status_code != 200:
                continue  # Skip if detail page cannot be accessed

            detail_soup = BeautifulSoup(detail_response.text, 'html.parser')
            content_tag = detail_soup.find("div", class_="content")  # Update selector if needed

            # Check if content is found
            content = content_tag.get_text(strip=True) if content_tag else "Content not found"

            news_data = {
                "title": title,
                "content": content,
                "publish_date": publish_date,
                "source": url,
            }
            news_data_list.append(news_data)

        except requests.exceptions.RequestException as e:
            print(f"Error fetching detail link: {e}")
            continue  # Skip this item if an error occurs fetching detail page

    return news_data_list

def process_text(content):
    content = re.sub(r"\s+", " ", content)
    truncated_content = content[:200] + "..." if len(content) > 200 else content
    print(f"Processed content: {truncated_content[:50]}...")  # Show first 50 chars for preview
    return truncated_content

def process_and_store(news_data):
    conn = engine.connect()

    for data in news_data:
        title = data["title"]
        source = data["source"]
        content = process_text(data["content"])

        if any(keyword in content for keyword in keywords):
            news_entry = {
                "title": title,
                "source": source,
                "publish_date": data["publish_date"],
                "content_summary": content,
                "predicate_offence_type": "Identified",
            }

            # Check for duplicates
            stmt = select([news_table]).where(
                news_table.c.title == news_entry["title"],
                news_table.c.source == news_entry["source"]
            )
            result = conn.execute(stmt).fetchone()

            if result:
                print(f"Updating existing news entry: {title}")
                update_stmt = (
                    update(news_table)
                    .where(news_table.c.id == result.id)
                    .values(news_entry)
                )
                conn.execute(update_stmt)
            else:
                print(f"Inserting new news entry: {title}")
                insert_stmt = insert(news_table).values(news_entry)
                conn.execute(insert_stmt)
    conn.close()

def main():
    for url in news_urls:
        print(f"Fetching data from: {url}")
        news_data = fetch_news_data(url)
        if news_data:
            print(f"Fetched {len(news_data)} items from {url}")
            process_and_store(news_data)
        else:
            print(f"No data fetched from {url}")

# Run the main function
main()
