@php
    if (strtolower($role_display_name) == ROLE_ADMIN) {
        $boards = [
            'active_task_board',
            'client_board',
            'performace_overview',
            'payment_board',
            'document_review_board',
            'engagement_letter_board',
        ];
    } elseif (strtolower($role_display_name) == ROLE_MANAGER) {
        $boards = ['active_task_board', 'client_board', 'document_review_board', 'engagement_letter_board'];
    } elseif (strtolower($role_display_name) == ROLE_COLLEAGUE) {
        $boards = ['active_task_board', 'client_board', 'document_review_board', 'engagement_letter_board'];
    } else {
        $boards = ['engagement_letter_task'];
    }
@endphp
<div class="d-flex justify-content-between mt-1">
    <div
        class="flex-fill card card-flush bg-primary h-md-0 mb-5 me-5 col-md-4 {{ !in_array('active_task_board', $boards) ? 'd-none' : '' }}">
        <div class="card-header pt-5">
            <div class="card-title d-flex flex-column">
                <span class="fs-2hx fw-bold text-white me-2 lh-1 ls-n2">{{ $total_active_task }}</span>
                <span
                    class="text-white opacity-75 pt-1 fw-semibold fs-6"><?= __('Active Tasks for') . ' ' . date('M\'Y') ?></span>
            </div>
        </div>
        <div class="card-body d-flex align-items-end pt-0">
            <div class="d-flex align-items-center flex-column mt-3 w-100">
                <div class="d-flex justify-content-between fw-bold fs-6 text-white opacity-75 w-100 mt-auto mb-2">
                    <span><?= $total_completed_task ?> <?= __('Pending') ?></span>
                    <span><?= $total_active_task > 0 ? ($total_completed_task * 100) / $total_active_task : 0 ?>%</span>
                </div>

                <div class="h-8px mx-3 w-100 bg-white bg-opacity-50 rounded">
                    <div class="bg-white rounded h-8px" role="progressbar" style="width: 72%;" aria-valuenow="50"
                        aria-valuemin="0" aria-valuemax="100"></div>
                </div>
            </div>
        </div>
    </div>

    <div
        class="flex-fill card card-flush bg-primary bg-opacity-25 h-md-0 mb-5 me-5 col-md-4 {{ !in_array('client_board', $boards) ? 'd-none' : '' }}">
        <div class="card-header pt-5">
            <div class="card-title d-flex flex-column">
                <span class="fs-2hx fw-bold text-dark me-2 lh-1 ls-n2">{{ !empty($clients) ? $total_client : 0 }}</span>
                <span class="text-gray-800 pt-1 fw-bold fs-6">{{ __('Clients') }}</span>
            </div>
        </div>

        <div class="card-body d-flex flex-column justify-content-end pt-0">
            <span class="fs-6 fw-bolder text-gray-800 d-block mb-2"></span>
            @php
                $iterationCount = 0;
                $colors = [
                    '#75BDFB',
                    '#4BABFD',
                    '#39A1FA',
                    '#3197EF',
                    '#2E90E5',
                    '#2B88DA',
                    '#267ECB',
                ];
            @endphp
            <div class="symbol-group symbol-hover flex-nowrap">
                @forelse ($clients as $client)
                    @php
                        $styleClass = $colors[$iterationCount % count($colors)];
                    @endphp
                    <div class="symbol symbol-35px symbol-circle" data-bs-toggle="tooltip"
                        data-bs-original-title="{{ $client['client_name'] }}" data-kt-initialized="1">
                        <span class="symbol-label text-inverse-primary fw-bold" style="background: {{ $styleClass }}">
                            {{ substr($client['client_name'], 0, 1) }}
                        </span>
                    </div>
                    @php
                        $iterationCount++;
                        if ($iterationCount >= 7) {
                            break;
                        }
                    @endphp
                @empty
                @endforelse
                <a href="{{ route('clients.index') }}" class="symbol symbol-35px symbol-circle" data-bs-toggle="modal"
                    data-bs-target="#kt_modal_view_users">
                    @if (!empty($clients) && $total_client - $iterationCount > 0)
                        <span class="symbol-label bg-dark text-gray-300 fs-8 fw-bold">
                            +{{ !empty($clients) ? $total_client - $iterationCount : 0 }}
                        </span>
                    @endif
                </a>
            </div>
        </div>
    </div>
    @if (in_array($auth_user['current_role'], [ROLE_MANAGER, ROLE_COLLEAGUE]))
        <div class="flex-fill card card-flush mb-5 col-md-6 {{ !in_array('document_review_board', $boards) ? 'd-none' : '' }}"
            id="document_review_board">
            @include('element.partials.widgets.cards.document_review_board')
        </div>
    @endif
    <div
        class="flex-fill card card-flush h-md-0 mb-5 col-md-4 {{ !in_array('performace_overview', $boards) ? 'd-none' : '' }}">
        <div class="card-body pt-5">
            <h3 class="card-title text-gray-800 fw-bold">{{ __('Performance Overview') }}</h3>
            <div class="separator separator-dashed my-2"></div>
            <div class="d-flex flex-stack">
                <a href="{{ route('manager.list') }}"
                    class="text-primary fw-semibold fs-6 me-2">{{ __('Manager') }}</a>
                <a href="{{ route('manager.list') }}" type="button"
                    class="btn btn-icon btn-sm h-auto btn-color-gray-400 btn-active-color-primary justify-content-end">
                    <i class="ki-duotone ki-exit-right-corner fs-2"><span class="path1"></span><span
                            class="path2"></span></i> </a>
            </div>
            <div class="separator separator-dashed my-2"></div>
            <div class="d-flex flex-stack">
                <a href="{{ route('colleague.list') }}"
                    class="text-primary fw-semibold fs-6 me-2">{{ __('Colleague') }}</a>
                <a href="{{ route('colleague.list') }}" type="button"
                    class="btn btn-icon btn-sm h-auto btn-color-gray-400 btn-active-color-primary justify-content-end">
                    <i class="ki-duotone ki-exit-right-corner fs-2"><span class="path1"></span><span
                            class="path2"></span></i> </a>
            </div>
            <div class="separator separator-dashed my-2"></div>
            <div class="d-flex flex-stack">
                <a href="{{ route('clients.index') }}"
                    class="text-primary fw-semibold fs-6 me-2">{{ __('Client') }}</a>
                <a href="{{ route('clients.index') }}" type="button"
                    class="btn btn-icon btn-sm h-auto btn-color-gray-400 btn-active-color-primary justify-content-end">
                    <i class="ki-duotone ki-exit-right-corner fs-2"><span class="path1"></span><span
                            class="path2"></span></i> </a>
            </div>
        </div>
    </div>

</div>
<div class="d-flex justify-content-between gap-5">
    @if ($auth_user['current_role'] == ROLE_ADMIN)
        <div class="flex-fill card card-flush mb-5 col-md-6 {{ !in_array('document_review_board', $boards) ? 'd-none' : '' }}"
            id="document_review_board">
            @include('element.partials.widgets.cards.document_review_board')
        </div>
    @endif
    <div class="flex-fill card card-flush mb-5 col-md-6 {{ !in_array('performace_overview', $boards) ? 'd-none' : '' }}"
        id="payment_board">
        @include('element.partials.widgets.cards.payment_board')
    </div>
</div>

<div class="row g-5 mb-5">
    <div
        class="col-md-6 col-lg-6 col-xl-6 col-xxl-6 {{ !in_array('engagement_letter_board', $boards) ? 'd-none' : '' }}">
        <div class="card card-flush h-lg-100">
            <div class="card-header pt-5">
                <h3 class="card-title align-items-start flex-column">
                    <span class="card-label fw-bold text-gray-800">{{ __('Letter Dashboard') }}</span>
                    <span class="text-gray-800 mt-1 fw-semibold fs-6">{{ __('[Engagement Letter & 64-8]') }}</span>
                </h3>
            </div>
            <div class="card-body d-flex align-items-start pt-6" id="engagement_letter_board">

            </div>
        </div>
    </div>
    <div
        class="{{ $auth_user['current_role'] == ROLE_CLIENT ? 'col-md-12 col-lg-12 col-xl-12 col-xxl-12' : 'col-md-6 col-lg-6 col-xl-6 col-xxl-6' }}">
        <div class="card card-flush h-lg-100">
            <div class="card-header pt-5">
                <h3 class="card-title align-items-start flex-column">
                    <span class="card-label fw-bold text-gray-800">{{ __('Payment Monitoring Board') }}</span>
                    <span
                        class="text-gray-800 mt-1 fw-semibold fs-6">{{ __('Currently running payment process summary') }}</span>
                </h3>
            </div>
            <div class="card-body d-flex align-items-start pt-6" id="payment_pending_summary">

            </div>
        </div>
    </div>
</div>
