@extends('layouts.title_ajax')
@section('content')
    <div class="card card-custom border">
        {!! html()->form('POST', route('setup.notification.event'))->id('form_notification_Event')->open() !!}
        @csrf
        <div class="card-body">
            <div class="row mb-2">
                <div class="col-md-2">
                    {!! html()->label('notification_type_id', __('Type of Notification'))->class('col-form-label-lg fw-semibold') !!}
                </div>
                <div class="col-md-9">
                    {!! html()->select('notification_type_id', ['' => 'Select Type'] + $notificationTypeOptions)->class('form-control form-control-solid')->attribute('data-control', 'select2')->value($notificationEvent['notification_type_id'] ?? null) !!}
                </div>
            </div>
            <div class="row mb-2">
                <div class="col-md-2">
                    <label for="name" class=col-form-label-lg fw-semibold required">{{ __('Name') }}</label>
                </div>
                <div class="col-md-9">
                    {!! html()->text('name')->class('form-control form-control-solid')->value($notificationEvent['name'] ?? null) !!}
                </div>
            </div>
            <div class="row mb-2">
                <div class="col-md-2">
                    <label for="title" class=col-form-label-lg fw-semibold required">{{ __('Title') }}</label>
                </div>
                <div class="col-md-9">
                    {!! html()->text('title')->class('form-control form-control-solid')->attribute('required', true)->value($notificationEvent['title'] ?? null) !!}
                </div>
            </div>
            <div class="row mb-2">
                <div class="col-md-2">
                    {!! html()->label(__('Description'))->for('description')->class('col-form-label-lg fw-semibold') !!}
                </div>
                <div class="col-md-9">
                    {!! html()->textarea('description')->class('form-control form-control-solid')->attribute('required', true)->value($notificationEvent['description'] ?? null) !!}
                </div>
            </div>
            <div class="row mb-2">
                <div class="col-md-2">
                    <label for="entity_type_role_ids" class=col-form-label-lg fw-semibold ">{{ __('Map Role & Message') }}
                        {{ getDefaultIconButton(['_title' => __('Add New'), '_class' => 'btn btn-primary btn-sm btn-icon rounded-0 btn_add_new_row', '_icon' => 'fa-solid fa-square-plus']) }}
                    </label>
                </div>
                <div class="col-md-9">
                    <table class="table" id="mapMessageTable" width="100%">
                        @if (isset($messages) && !empty($messages))
                            @foreach ($messages as $key => $value)
                                <tr>
                                    <td>
                                        <select class="form-control form-control-solid user_role" name="user_role[]"
                                            data-control="select2">
                                            <option value="" disabled selected>Select Role</option>
                                            <option value="1" {{ $key == 1 ? 'selected' : '' }}>Admin</option>
                                            <option value="2" {{ $key == 2 ? 'selected' : '' }}>Manager</option>
                                            <option value="3" {{ $key == 3 ? 'selected' : '' }}>Colleague</option>
                                        </select>
                                    </td>
                                    <td>
                                        <input class="form-control form-control-solid" type="text" name="message[]"
                                            value="{{ $value }}" required>
                                    </td>
                                    <td>
                                        {{ getDefaultIconButton(['_title' => __('Delete'), '_class' => 'btn btn-danger btn-sm btn-icon rounded-0 removeRow', '_icon' => 'fa-solid fa-trash-can']) }}
                                    </td>
                                </tr>
                            @endforeach
                        @endif
                        <tr>
                            <td>
                                <select class="form-control form-control-solid user_role" name="user_role[]"
                                    data-control="select2">
                                    <option value="" disabled selected>Select Role</option>
                                    <option value="1">Admin</option>
                                    <option value="2">Manager</option>
                                    <option value="3">Colleague</option>
                                </select>
                            </td>
                            <td>
                                <input class="form-control form-control-solid" type="text" name="message[]" required>
                            </td>
                            <td>
                                {{ getDefaultIconButton(['_title' => __('Delete'), '_class' => 'btn btn-danger btn-sm btn-icon rounded-0 removeRow', '_icon' => 'fa-solid fa-trash-can']) }}
                            </td>
                        </tr>
                    </table>
                </div>
            </div>
        </div>
        @if (!empty($notificationEvent))
            {!! html()->hidden('type', $notificationEvent['id']) !!}
            {!! html()->hidden('id', $notificationEvent['id']) !!}
        @endif
        {!! html()->form()->close() !!}
    </div>
    <script>
        // $(document).ready(function() {
        // Add new row
        $(document).off('click', ".btn_add_new_row").on("click", ".btn_add_new_row", function() {
            $("#mapMessageTable").append(
                '<tr>' +
                '<td>' +
                '<select class="form-control form-control-solid user_role" data-control="select2" name="user_role[]">' +
                '<option value="" disabled selected>Select Role</option>' +
                '<option value="1">Admin</option>' +
                '<option value="2">Manager</option>' +
                '<option value="3">Colleague</option>' +
                '</select>' +
                '</td>' +
                '<td>' +
                '<input class="form-control form-control-solid" type="text" name="message[]" required>' +
                '</td>' +
                '<td>' +
                ACTIONBUTTON.getDefaultIconButton({
                    'title': 'Delete',
                    'icon': 'fa-solid fa-trash-can',
                    'class': 'btn btn-sm btn-icon btn-danger rounded-0 removeRow'
                }) +
                '</td>' +
                '</tr>'
            );
        });

        // Remove row
        $(document).off('click', ".removeRow").on("click", ".removeRow", function() {
            $(this).closest("tr").remove();
        });

        // User role change event
        $(document).off('change', ".user_role").on("change", ".user_role", function() {
            let row = $(this).closest("tr");
            let selectedRole = $(this).val();
            let otherSelects = row.siblings().find("select[name='user_role[]']");

            if (otherSelects.filter(function() {
                    return $(this).val() === selectedRole;
                }).length > 0) {
                $(this).addClass("duplicate-role");
                toastr.error('Duplicate user role in this row.')
                $(this).val('').trigger('change')
            }
        });
        // });
    </script>
@endsection
