<?php

/**
 * @var \App\View\AppView $this
 * @var \App\Model\Entity\User[]|\Cake\Collection\CollectionInterface $users
 */
?>
<div class="users index content">
    <div class="card card-accent-success custom-card">
        <div class="card-header px-0 pt-0 pb-3">
            {{ __('Create New User') }}
        </div>
    </div>
    <div class="column-responsive column-80">
        <div class="users form content row">
            <div class="col-md-7">
                <?= $this->Form->create($user, ['id' => 'user-form']) ?>
                <div class="form form-group">
                    <?php
                    echo $this->Form->control('client_profile_id', ['options' => $clients, 'id' => 'client_profile_id', 'class' => 'form-control form-control-solid mx-2 my-2', 'label' => __('Client'), 'required' => true]);
                    echo $this->Form->control('user_full_name', ['class' => 'form-control form-control-solid mx-2 my-2', 'label' => __('User Full Name'), 'required' => true]);
                    echo $this->Form->control('user_dob', ['class' => 'form-control form-control-solid mx-2 my-2', 'label' => __('Date of Birth'), 'type' => 'date', 'required' => true]);
                    echo $this->Form->control('user_mobile', ['class' => 'form-control form-control-solid mx-2 my-2', 'label' => __('User Mobile'), 'required' => true]);
                    echo $this->Form->control('username', ['class' => 'form-control form-control-solid mx-2 my-2', 'label' => __('User Email'), 'required' => true]);
                    echo $this->Form->control('password', [
                        'class' => 'form-control form-control-solid mx-2 my-2',
                        'label' => __('Password'),
                        'required' => true,
                        'pattern' => '(?=.*\d)(?=.*[a-z])(?=.*[A-Z]).{8,}',
                        'onInput' => 'checkPasswordValidation()',
                    ]);
                    echo $this->Form->control('confirm_password', [
                        'class' => 'form-control form-control-solid mx-2 my-2',
                        'label' => __('Confirm Password'),
                        'required' => true,
                        'type' => 'password',
                        'pattern' => '(?=.*\d)(?=.*[a-z])(?=.*[A-Z]).{8,}',
                        'onInput' => 'checkPasswordValidation()',
                    ]);
                    ?>
                </div>
                <div>
                    {{ __('Password must contain at least one small letter, one capital letter, one number and minimum 8 characters.') }}
                </div>
                <p>&nbsp;</p>
                <?= $this->Form->button(__('Submit'), ['name' => 'btn-submit', 'class' => 'btn btn-primary', 'value' => 'submit', 'type' => 'submit']) ?>
                <?= $this->Form->end() ?>
            </div>
        </div>
    </div>
    <hr>
    <div class="card card-accent-success custom-card">
        <div class="card-header px-0 pt-0 pb-3">
            <?= !empty($page_title) ? __('{0} ({1})', [$page_title, $this->Paginator->counter(__('{{ count }}'))]) : ucwords($this->getRequest()->getParam('action')) ?>
        </div>
    </div>
    <div class="table-responsive">
        <table class="table">
            <thead>
                <tr>
                    <th><?= $this->Paginator->sort('id') ?></th>
                    <th><?= $this->Paginator->sort('username') ?></th>
                    <th><?= $this->Paginator->sort('force_change_pass') ?></th>
                    <th><?= $this->Paginator->sort('active_status', 'Status') ?></th>
                    <th><?= $this->Paginator->sort('created') ?></th>
                    <th><?= $this->Paginator->sort('modified', 'Updated') ?></th>
                    <th class="actions"><?= __('Actions') ?></th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($users as $user) : ?>
                <tr>
                    <td><?= $this->Number->format($user->id) ?></td>
                    <td><?= h($user->username) ?></td>
                    <td><?= $this->Number->format($user->force_change_pass) == 1 ? 'Yes' : 'No' ?></td>
                    <td><?= $user->active_status == 1 ? 'Active' : 'Inactive' ?></td>
                    <td><?= h($user->created) ?></td>
                    <td><?= h($user->modified) ?></td>
                    <td class="actions">
                        <?php /*?> ?> ?> ?> ?> ?>
                        <?= $this->Html->link(__('View'), ['action' => 'view', $user->id]) ?>
                        <?= $this->Html->link(__('Edit'), ['action' => 'edit', $user->id]) ?>
                        <?= $this->Form->postLink(__('Delete'), ['action' => 'delete', $user->id], ['confirm' => __('Are you sure you want to delete # {0}?', $user->id)]) ?>
                        <?php */ ?>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<script>
    $("#client_profile_id").bind('change', function() {
        $("#user-form").submit();
    })

    function checkPasswordValidation() {
        if (checkPassword($('#password').val()) && $('#password').val() == $('#confirm-password').val()) {
            return true;
        }
    }

    function matchPassword() {
        if ($('#password').val() == $('#confirm-password').val()) {
            return true;
        } else {
            alert('Password and confirm password does not match !');
            return false
        }
    }
</script>
