<?php

use App\Http\Controllers\Admin\XAttachmentController;
use App\Http\Controllers\NotificationEventController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\UsersController;
use App\Http\Controllers\EmailsController;
use App\Http\Controllers\ArtisanController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\NotificationController;
use App\Http\Controllers\ServiceConfigurationController;
use App\Http\Controllers\Admin\XHolidayController;
use App\Http\Controllers\ApplicationConfigurationController;
use App\Http\Controllers\NotificationTypeController;
use App\Http\Controllers\SelfAssessmentController;
use App\Http\Controllers\TwoFactorController;
use App\Http\Controllers\CustomerController;
use App\Http\Controllers\NewsController;
use App\Http\Controllers\MatchController;
use App\Http\Controllers\PdfController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
 */

Auth::routes(['register' => false]);

// Artisan  command
Route::get('artisan', [ArtisanController::class, 'index'])->name('artisan');

// Forget password
Route::post('auto/login', [UsersController::class, 'autoLogin'])->name('auto_login');
Route::post('forget/password', [UsersController::class, 'forgetPassword'])->name('forget_password');
Route::post('verify/email/code', [UsersController::class, 'verifyEmailCode'])->name('verify_email_code');

Route::group(['middleware' => 'auth'], function () {
    // Password change
    Route::get('user/change-password', [UsersController::class, 'changePassword'])->name('user.change-password');
    Route::post('user/change-password', [UsersController::class, 'changePassword'])->name('user.change-password.save');

    // 2fa
    Route::get('2fa/setup', [TwoFactorController::class, 'show2faForm'])->name('setup2fa');
    Route::post('2fa/enable', [TwoFactorController::class, 'enable2fa'])->name('enable2fa');
    Route::get('2fa/verify', [TwoFactorController::class, 'showVerify2faForm'])->name('verify2fa');
    Route::post('2fa/verify', [TwoFactorController::class, 'verify2fa'])->name('verify2fa');

    Route::get('/dashboard', [DashboardController::class, 'index'])->name('dashboard');
    Route::post('/confirm-match/{id}', [DashboardController::class, 'confirmMatch'])->name('confirm-match');

});
Route::middleware(['userVerify', '2fa'])->group(function () {
    Route::group(['middleware' => 'auth'], function () {
        // Home
        Route::get('/', [DashboardController::class, 'index'])->name('home');

        // Route::resource('customers', CustomerController::class);

        Route::get('/customers', [CustomerController::class, 'index'])->name('customers.index');
        Route::get('/customers/data', [CustomerController::class, 'data'])->name('customers.data');
        Route::put('/customers/{id}', [CustomerController::class, 'update'])->name('customers.update');
        Route::get('/customers/show', [CustomerController::class, 'show'])->name('customers.show');
        Route::get('/search/customer', [CustomerController::class, 'seachCustomer'])->name('customer.search');
        Route::get('/customer/profile/{id}', [CustomerController::class, 'customerStaticView'])->name('customer.profile');


        Route::get('/news', [NewsController::class, 'index'])->name('news.index');
        Route::get('/news/data', [NewsController::class, 'data'])->name('news.data');


        Route::get('/news-bn', [NewsController::class, 'newsBn'])->name('news.index.bn');
        Route::get('/news-bn/data', [NewsController::class, 'dataBn'])->name('news.data.bn');
        Route::get('/download-news/{id}', [NewsController::class, 'downloadNewsAsPdf'])->name('news.download');

        // User Setup
        Route::get('user/view', [UsersController::class, 'viewUser'])->name('view.user');
        Route::get('user/data', [UsersController::class, 'userData'])->name('data.user');
        Route::any('user/setup', [UsersController::class, 'userSetup'])->name('setup.user');
        Route::get('user/duplicate-check', [UsersController::class,'checkDuplicateUser'])->name('duplicate-check.user');

        // Profile Tabs
        Route::get('notification_team/view', [UsersController::class, 'viewTeamNotification'])->name('view.team.notifications');
        Route::get('log_team/view', [UsersController::class, 'viewTeamLogs'])->name('view.team.logs');
        Route::get('important_team/view', [UsersController::class, 'viewTeamImportant'])->name('view.team.important');
        Route::get('activity_team/view', [UsersController::class, 'viewTeamActivity'])->name('view.team.activities');
        Route::get('team/service/activities', [UsersController::class, 'teamServiceActivites'])->name('activities.service.team');
        Route::get('document_team/view', [UsersController::class, 'viewTeamDocuments'])->name('view.team.team.documents');
        Route::get('client_team/view', [UsersController::class, 'viewTeamClients'])->name('view.team.clients');
        Route::get('recent/activity/details', [UsersController::class, 'recentActivityDetails'])->name('details.activity.recent');

        // Mail templates
        Route::get('email/overview', [EmailsController::class, 'dashboard'])->name('email.overview');
        Route::get('email/templates', [EmailsController::class, 'index'])->name('email_templates');
        Route::post('email/resend/{id}', [EmailsController::class, 'reSend'])->name('resend.email');

        // Email
        Route::get('email_template/view', [EmailsController::class, 'viewTemplate'])->name('view.email_template');
        Route::any('template/populate_data', [EmailsController::class, 'prepareTemplateData'])->name('populate_data.template');

        // Mail Box
        Route::get('mail-box', [EmailsController::class, 'viewMailBoxes'])->name('mail.box.list');
        Route::get('mail-box/data', [EmailsController::class, 'apiMailBoxList'])->name('data.mail.box');
        Route::get('mail-box/view', [EmailsController::class, 'viewMailBox'])->name('view.mail.box');

        // Mail Resend
        Route::any('template/email/resend', [EmailsController::class, 'resendEmailTemplate'])->name('resend.email.template');

        // Notification
        Route::get('notifications', [NotificationController::class, 'index'])->name('notifications');
        Route::get('notifications/data', [NotificationController::class, 'apiNotificationList'])->name('data.notification');

        // Notify user
        Route::get('notifications/type', [NotificationController::class, 'typeNotification'])->name('type.notification');
        Route::any('notifications/send', [NotificationController::class, 'sendNotification'])->name('send.notification');

        // Notification
        Route::get('notifications/list', [NotificationController::class, 'viewNotification'])->name('list.notification');
        Route::any('notifications/notifier', [NotificationController::class, 'apiNotificationNotifier'])->name('notifier.notification');
        Route::any('notifications/configuration', [NotificationController::class, 'configurationNotification'])->name('configuration.notification');
        Route::get('notifications/seen', [NotificationController::class, 'seenNotification'])->name('seen.notification');

        // Firebase Notification
        Route::post('token/store', [NotificationController::class, 'storeToken'])->name('store.token');
        Route::post('token/device/check', [NotificationController::class, 'checkDeviceToken'])->name('check.device.token');

        // Service Documents
        Route::get('x-documents', [ServiceConfigurationController::class, 'viewDocuments'])->name('x-document.list');
        Route::get('x-documents/data', [ServiceConfigurationController::class, 'apiDocumentList'])->name('x-data.document');
        Route::any('x-documents/setup', [ServiceConfigurationController::class, 'setupDocument'])->name('x-setup.document');
        Route::delete('/x-documents/delete/{id}', [ServiceConfigurationController::class, 'deleteDocument'])->name('x-delete.document');

        // Notification Type
        Route::get('notification-type', [NotificationTypeController::class, 'viewNotificationType'])->name('notification.type.list');
        Route::get('notification-type/data', [NotificationTypeController::class, 'apiNotificationTypeList'])->name('data.notification.type');
        Route::any('notification-type/setup', [NotificationTypeController::class, 'setupNotificationType'])->name('setup.notification.type');
        Route::delete('notification-type/delete/{id}', [NotificationTypeController::class, 'deleteNotificationType'])->name('delete.notification.type');

        // Notification Event
        Route::get('notification-event', [NotificationEventController::class, 'viewNotificationEvent'])->name('notification.event.list');
        Route::get('notification-event/data', [NotificationEventController::class, 'apiNotificationEventList'])->name('data.notification.event');
        Route::any('notification-event/setup', [NotificationEventController::class, 'setupNotificationEvent'])->name('setup.notification.event');
        Route::delete('notification-event/delete/{id}', [NotificationEventController::class, 'deleteNotificationEvent'])->name('delete.notification.event');

        // Holiday
        Route::get('holiday-list', [XHolidayController::class, 'holidayList'])->name('holiday.list');
        Route::get('holiday-list/data', [XHolidayController::class, 'apiHolidayList'])->name('data.holiday');
        Route::any('holiday-list/setup', [XHolidayController::class, 'setupHoliday'])->name('setup.holiday');
        Route::post('holiday/save', [XHolidayController::class, 'saveHoliday'])->name('save.holiday');
        Route::delete('holiday/delete/{holiday_id}', [XHolidayController::class, 'deleteHoliday'])->name('delete.holiday');

        // XAttachments
        Route::get('x_attachment-list', [XAttachmentController::class, 'viewXAttachments'])->name('list.x_attachment');
        Route::get('x_attachment/data', [XAttachmentController::class, 'apiXAttachmentList'])->name('data.x_attachment');
        Route::any('x_attachment/setup', [XAttachmentController::class, 'setupXAttachment'])->name('setup.x_attachment');
        Route::delete('x_attachment/delete/{id}', [XAttachmentController::class, 'deleteXAttachment'])->name('delete.x_attachment');

        // Application Logs
        Route::get('logs', [ApplicationConfigurationController::class, 'applicationLog'])->name('application.logs');
        Route::get('logs/view', [ApplicationConfigurationController::class, 'viewLogs'])->name('view.logs');

        // Log Data
        Route::get('get/login/log', [ApplicationConfigurationController::class, 'getLoginLog'])->name('data.login.log');
        Route::get('get/activity/log', [ApplicationConfigurationController::class, 'getRecentActivity'])->name('data.activity.log');
        Route::get('get/error/log', [ApplicationConfigurationController::class, 'getErrorLog'])->name('data.error.log');

        // Run Job
        Route::any('command/voice', [ApplicationConfigurationController::class, 'voiceCommand'])->name('voice.command');

        // User Role
        Route::get('user_roles', [ApplicationConfigurationController::class, 'viewUserRoles'])->name('list.user.role');
        Route::get('user_roles/data', [ApplicationConfigurationController::class, 'apiUserRoleList'])->name('data.user.role');
        Route::any('user_roles/setup', [ApplicationConfigurationController::class, 'setupUserRole'])->name('setup.user.role');
        Route::delete('user_roles/delete/{id}', [ApplicationConfigurationController::class, 'deleteUserRole'])->name('delete.user.role');

        // User Settings
        Route::get('profile/{id?}', [UsersController::class, 'profile'])->name('profile');
        Route::any('user/settings', [UsersController::class, 'userSettings'])->name('settings.user');
        Route::get('user/settings/data', [UsersController::class, 'userSettingsData'])->name('data.settings.user');
        Route::post('user/settings/status', [UsersController::class, 'userSettingsStatus'])->name('status.settings.user');

        // Self Assesstment
        Route::get('self-assessment/report', [SelfAssessmentController::class, 'selfAssessmentReport'])->name('report.self-assessment');
        Route::any('self-assessment/report/setup', [SelfAssessmentController::class, 'selfAssessmentSetup'])->name('setup.self-assesment');
        Route::get('self-assessment/report/data', [SelfAssessmentController::class, 'selfAssessmentData'])->name('data.self-assesment');

        // Self Assessment Report
        Route::any('report/setup', [SelfAssessmentController::class, 'setupReport'])->name('setup.report');
        Route::get('report/question', [SelfAssessmentController::class, 'getReportQuestion'])->name('question.report');

        // News Against Prominent Person
        Route::get('news/against-prominent-person', [DashboardController::class, 'newsAgainstProminentPerson'])->name('against-prominent-person.news');
        Route::get('view/against-prominent-person', [DashboardController::class, 'viewAgainstProminentPerson'])->name('against-prominent-person.view');

    });
});




Route::get('/customer-search', [MatchController::class, 'customerSearch'])->name('match.customerSearch');
Route::get('/customer-search-from-news', [MatchController::class, 'customerSearchFromNews'])->name('match.customerSearchFromNews');
Route::post('/match', [MatchController::class, 'match'])->name('match.submit');
Route::post('/customer-search-match-result', [MatchController::class, 'customerSearchMatch'])->name('customersearch.submit');

//pdf

Route::get('upload-pdf', [PdfController::class, 'showUploadForm'])->name('upload.form');
Route::post('upload-pdf', [PdfController::class, 'uploadPdf'])->name('upload.pdf');
